<?php return array(
    'root' => array(
        'name' => 'codeinwp/neve',
        'pretty_version' => 'v4.1.4',
        'version' => '4.1.4.0',
        'reference' => '74d9cbf7cf005ff6ac2c5db0cff56ade28c5fc26',
        'type' => 'wordpress-theme',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => false,
    ),
    'versions' => array(
        'codeinwp/neve' => array(
            'pretty_version' => 'v4.1.4',
            'version' => '4.1.4.0',
            'reference' => '74d9cbf7cf005ff6ac2c5db0cff56ade28c5fc26',
            'type' => 'wordpress-theme',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'codeinwp/themeisle-sdk' => array(
            'pretty_version' => '3.3.48',
            'version' => '3.3.48.0',
            'reference' => '0727d2cf2fc9bfb81b42968aeaf2bf4e340f021e',
            'type' => 'library',
            'install_path' => __DIR__ . '/../codeinwp/themeisle-sdk',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'wptt/webfont-loader' => array(
            'pretty_version' => 'dev-master',
            'version' => 'dev-master',
            'reference' => '68c93e1dc8f6e438f93e81ebdf632e6243e43e0f',
            'type' => 'package',
            'install_path' => __DIR__ . '/../wptt/webfont-loader',
            'aliases' => array(
                0 => '9999999-dev',
            ),
            'dev_requirement' => false,
        ),
    ),
);
