"use strict";(self.webpackChunkneve=self.webpackChunkneve||[]).push([[841],{841:(e,t,n)=>{n.r(t),n.d(t,{default:()=>o});var a=n(196),s=n.n(a),l=n(941),i=n(609),r=n(540),c=n(736),d=n(307),m=n(926);const o=({items:e})=>{const{builder:t,actions:n,dragging:a}=(0,d.useContext)(m.Z),{onDragStart:o,onDragEnd:u,setSidebarItems:p}=n,b=window.NeveReactCustomize.HFG[t].items;return s().createElement("div",{className:"neve-builder-sidebar-content"},s().createElement("span",{className:"customize-control-title"},(0,c.__)("Available Components","neve")),e&&e.length>0&&s().createElement("div",{className:"sidebar-items droppable-wrap"},s().createElement(l._O,{onEnd:u,animation:0,group:t,className:"droppable",disabled:a,onStart:o,list:e,setList:e=>{const t=e.map((e=>({id:e.id}))).sort(((e,t)=>e.id<t.id?-1:1));p(t)}},e.map((e=>{const{name:t}=b[e.id];return s().createElement("div",{className:"builder-item",key:e.id},s().createElement(i.Icon,{className:"handle",icon:r.Z,size:15}),s().createElement("span",null,t))})))),!e.length&&s().createElement("div",{className:"no-components"},s().createElement("span",null,(0,c.__)("All available components are used inside the builder","neve"))))}}}]);