.customize-control-hfg-responsive-spacing {
	/* Unit Screen wrap */
}
.customize-control-hfg-responsive-spacing .customize-control-title{
    margin-bottom: 0;
}

.customize-control-hfg-responsive-spacing .customize-control-title {
	display: inline-block;
}

.customize-control-hfg-responsive-spacing .hfg-spacing-responsive-outer-wrapper {
	display: flex;
	position: relative;
}

.hfg-spacing-header {
	display: flex;
	align-items: center;
	margin-bottom: 5px;
    margin-bottom: 10px;
}

.customize-control-hfg-responsive-spacing .hfg-spacing-responsive-btns {
	text-align: center;
	display: flex;
	align-items: center;
	justify-content: center;
	line-height: 2;
	border-radius: 50%;
	width: 20px;
	height: 20px;
	margin-left: 10px;
    background-color: #13aff0;
}

.customize-control-hfg-responsive-spacing .hfg-spacing-responsive-btns > li {
	margin-bottom: 0;
	display: none;
}

.customize-control-hfg-responsive-spacing .hfg-spacing-responsive-btns > li.active {
	display: inline-block;
}

.customize-control-hfg-responsive-spacing .hfg-spacing-responsive-btns button[type="button"] {
	padding: 0;
	cursor: pointer;
	background: none;
	border: none;
	outline: none;
    display: flex;
    align-items: center;
}

.customize-control-hfg-responsive-spacing .hfg-spacing-responsive-btns button[type="button"] > i {
	width: 12px;
	height: 12px;
	font-size: 12px;
    color: #fff;
}

.customize-control-hfg-responsive-spacing .hfg-spacing-responsive-units {
	font-size: 11px;
	text-transform: uppercase;
	display: none;
}

.hfg-units-wrap {
    margin-left: auto;
}

.customize-control-hfg-responsive-spacing .hfg-spacing-responsive-units.active {
	display: flex;
}

.customize-control-hfg-responsive-spacing .hfg-spacing-responsive-units li.single-unit {
	display: inline-block;
	margin-left: 6px;
	text-align: center;
	user-select: none;
	opacity: 0.7;
	margin-bottom: 0;
}

.customize-control-hfg-responsive-spacing .hfg-spacing-responsive-units li.single-unit.active {
	text-decoration: underline;
	opacity: 1;
}

.customize-control-hfg-responsive-spacing .input-wrapper .hfg-spacing-wrapper {
	display: none;
}

.customize-control-hfg-responsive-spacing .input-wrapper .hfg-spacing-wrapper li {
	text-align: center;
	-webkit-box-flex: 1;
	-ms-flex: auto;
	flex: auto;
}

.customize-control-hfg-responsive-spacing .input-wrapper .hfg-spacing-wrapper li input.hfg-spacing-input {
	text-align: center;
}

.customize-control-hfg-responsive-spacing .input-wrapper .hfg-spacing-wrapper.active {
	display: flex;
}

.customize-control-hfg-responsive-spacing .input-wrapper .hfg-spacing-wrapper span.hfg-spacing-title {
	text-transform: uppercase;
	font-size: 10px;
	opacity: .75;
}

.customize-control-hfg-responsive-spacing .input-wrapper .hfg-spacing-wrapper .hfg-spacing-input-item-link .hfg-spacing-connected {
	display: none;
}

.customize-control-hfg-responsive-spacing .input-wrapper .hfg-spacing-wrapper .hfg-spacing-input-item-link.disconnected .hfg-spacing-disconnected {
	display: none;
}

.customize-control-hfg-responsive-spacing .input-wrapper .hfg-spacing-wrapper .hfg-spacing-input-item-link.disconnected .hfg-spacing-connected {
	display: block;
}

.customize-control-hfg-responsive-spacing .input-wrapper .hfg-spacing-wrapper .hfg-spacing-input-item-link span {
	width: 28px;
	height: 26px;
	line-height: 26px;
	font-size: 14px;
	border: 1px solid #ddd;
	border-right: 0;
}

.customize-control-hfg-responsive-spacing .input-wrapper .hfg-spacing-wrapper .hfg-spacing-input-item-reset span {
	width: 25px;
	height: 25px;
	line-height: 26px;
	font-size: 14px;
    text-align: right;
}

.customize-control-hfg-responsive-spacing .input-wrapper .hfg-spacing-wrapper .hfg-spacing-input-item-reset:hover span {
	color: #ff7f5f;
}
