<?php return array('chunks' => array('7e5613fb2e01e74b5136.js', 'fe894d5b402cd5535eb1.js', 'fe21e704398fee9da3e4.js', 'bd47bef6f3c92f884605.js', 'c8e135098e958bb39090.js', '7adc2a9468881a2ef53b.js'),'dependencies' => array('lodash', 'neve-components', 'react', 'react-dom', 'wp-components', 'wp-element', 'wp-i18n', 'wp-media-utils', 'wp-primitives'), 'version' => '49b2af4e86278b708a14c5ed1ef96ded');