.neve-mega-menu > .sub-menu {
  cursor: default;
  width: var(--container);
  max-width: 100%;
}

.neve-mega-menu .sub-menu .sub-menu {
  max-height: none;
  width: 100%;
}
.neve-mega-menu .neve-mm-col {
  cursor: default;
  flex: 1;
}
.neve-mega-menu .neve-mm-col .sub-menu .sub-menu {
  left: 0;
  top: 100%;
}
.neve-mega-menu li.neve-mm-divider {
  height: 1px;
  margin: 10px auto;
  width: 100%;
  background-color: currentColor;
}
.neve-mega-menu .neve-mm-heading > span {
  cursor: default;
}

.neve-mm-description {
  padding: 0 0 15px;
  text-transform: none;
  font-size: 0.8em;
  display: flex;
}

.neve-mm-heading > span,
.neve-mm-heading > .wrap > a {
  font-weight: 700;
  text-transform: uppercase;
  font-size: 1.1em;
  display: flex;
  align-items: center;
}

.header-menu-sidebar-inner .neve-mega-menu .neve-mm-col > .sub-menu {
  display: block;
}

.header--row .builder-item.has-nav {
  position: static;
}

@media (min-width: 960px) {
  .header--row .nv-nav-wrap .primary-menu-ul .neve-mega-menu > .sub-menu {
    left: 50% !important;
    right: unset !important;
    transform: translateX(-50%) !important;
    position: absolute;
    padding: 20px 10px;
    top: auto;
  }
  .header--row .nv-nav-wrap .primary-menu-ul .neve-mega-menu > .sub-menu:not(.dropdown-open) {
    pointer-events: none;
  }
  .header--row .nv-nav-wrap .primary-menu-ul .neve-mega-menu:hover > .sub-menu,
  .header--row .nv-nav-wrap .primary-menu-ul .neve-mega-menu:focus > .sub-menu {
    display: flex;
    opacity: 1;
    visibility: visible;
    pointer-events: all;
  }
  .header--row .nv-nav-wrap .primary-menu-ul .neve-mega-menu {
    position: unset;
  }
  .header--row .nv-nav-wrap .primary-menu-ul .neve-mega-menu .neve-mm-col > .sub-menu {
    visibility: visible;
    position: relative;
    left: initial;
    right: initial;
    opacity: 1;
    box-shadow: none;
    display: flex;
    flex-direction: column;
    text-align: left;
    width: 100%;
  }
  .header--row .nv-nav-wrap .primary-menu-ul .neve-mega-menu .neve-mm-col > .sub-menu a {
    white-space: normal;
    display: flex;
  }
  .header--row .nv-nav-wrap .primary-menu-ul .neve-mega-menu .neve-mm-col > .sub-menu li:not(.neve-mm-divider) {
    border: 0;
  }
  .header--row .nv-nav-wrap .primary-menu-ul .neve-mega-menu .neve-mm-col {
    padding: 0 10px;
    align-items: flex-start;
    border: 0;
  }
  .header--row .nv-nav-wrap .primary-menu-ul .neve-mm-heading > span {
    padding: 10px 20px;
  }
  .header--row .nv-nav-wrap .primary-menu-ul .neve-mm-description {
    padding: 0 20px 10px;
  }
  .header--row .nv-nav-wrap .primary-menu-ul .neve-mega-menu .neve-mm-col:not(:last-child) {
    border-right: 1px solid currentColor;
  }
}

/*# sourceMappingURL=mega-menu.css.map */