/* Customize Preview */
.edit-row-action {
  top: 0;
  width: 26px;
  height: 26px;
  position: absolute;
  right: 0;
  background: #0073aa;
  fill: #FFFFFF;
  font-size: 0;
  display: none;
  cursor: pointer;
}

.customize-previewing {
  overflow-x: hidden;
}
.customize-previewing.is-menu-sidebar .customize-partial-refreshing {
  opacity: 1;
  transition: none;
}
.customize-previewing.is-menu-sidebar .customize-partial-refreshing #header-menu-sidebar #header-menu-sidebar-inner {
  opacity: 0.5;
  transition: opacity 0.25s;
}
.customize-previewing .has-nav .builder-item-focus.item--inner .item--preview-name {
  top: unset;
}
.customize-previewing .builder-item-focus.item--inner, .customize-previewing .builder-item-focus.row--wrapper {
  position: relative;
}
.customize-previewing .builder-item-focus.item--inner.has_menu, .customize-previewing .builder-item-focus.row--wrapper.has_menu {
  position: unset;
}
.customize-previewing .builder-item-focus.item--inner.has_menu .item--preview-name, .customize-previewing .builder-item-focus.row--wrapper.has_menu .item--preview-name {
  left: auto;
}
.customize-previewing .builder-item-focus .item--preview-name {
  position: absolute;
  top: 100%;
  left: 0;
  background: #0073aa;
  color: #fff !important;
  padding: 5px !important;
  font-size: 12px !important;
  font-weight: 600 !important;
  line-height: 14px !important;
  letter-spacing: normal !important;
  cursor: pointer;
  border-radius: 0;
  display: none;
}
.customize-previewing .builder-item-focus:hover.item--inner, .customize-previewing .builder-item-focus:hover.row--wrapper {
  transition-delay: 0s !important;
  outline: 1px solid #0073aa;
  outline-offset: -1px;
}
.customize-previewing .builder-item-focus:hover.item--inner > .item--preview-name, .customize-previewing .builder-item-focus:hover.item--inner > .edit-row-action, .customize-previewing .builder-item-focus:hover.row--wrapper > .item--preview-name, .customize-previewing .builder-item-focus:hover.row--wrapper > .edit-row-action {
  display: block;
  z-index: 9999999;
}
.customize-previewing .header--row .customize-partial-edit-shortcut,
.customize-previewing .header-menu-sidebar .customize-partial-edit-shortcut {
  display: none;
}
.customize-previewing .footer--row .builder-item-focus:hover.item--inner {
  position: relative;
}
.customize-previewing .footer--row .builder-item-focus:hover.item--inner .item--preview-name {
  top: unset;
  bottom: 0;
  left: 0 !important;
}
.customize-previewing .footer--row .builder-item-focus:hover.item--inner .item--preview-name .dashicons {
  color: #fff !important;
}

/* Customizer Shortcut */
#header-menu-sidebar .customize-partial-edit-shortcut {
  display: none;
}

.header-menu-sidebar-inner .item--preview-name {
  bottom: 0 !important;
  top: unset !important;
}

/*# sourceMappingURL=customizer-preview.css.map */