.control-wrap {
	width: 100%;
}

.has-media-queries .control-wrap {
	display: none;
	width: 100%;
}

.has-media-queries .control-wrap.active {
	display: block;
}

#customize-theme-controls .customize-pane-child.accordion-section-content {
	height: 100%;
}
#customize-theme-controls .accordion-section-title button.accordion-trigger {
    max-height: fit-content;
}

.nv-upsell-feat-container {
	font-family: sans-serif;
	display: flex;
	flex-direction: column;
}

.nv-upsell-feat-container a:is(.button-primary, .button-link) {
	text-align: center;
	font-size: 16px;
}

.nv-upsell-feat-container a.button-link {
	text-decoration: none;
	margin-top: 10px;
}

.nv-upsell-feat-heading {
	color: #2e4a62;
	font-size: 1.25rem;
	margin-bottom: 8px;
}

.nv-upsell-feat-description {
	font-size: 16px;
	color: #455a69;
	margin-top: 2px;
	margin-bottom: 16px;
}

.nv-upsell-feat-list {
	list-style: none;
	margin: 0;
	padding: 10px;
	background-color: white;
	border-radius: 10px;
	margin-bottom: 16px;
}

.nv-upsell-feat-item {
	display: flex;
	font-size: 16px;
	align-items: flex-end;
	margin: 8px 0;
}

.nv-upsell-feat-lock-icon {
	margin-left: 8px;
	color: #2271b1;
}

#nv-starter-content-notice {
	padding: 16px;
	background: #f0f6fc;
	border-right: 4px solid #2271b1;
	margin: 12px;
}

#nv-starter-content-notice .nv-notice {
	max-width: 250px;
	margin: 0 auto;
	display: grid;
	gap: 8px;
}

#nv-starter-content-notice .nv-notice :is(p, h3) {
	margin: 0;
}

#nv-starter-content-notice .nv-subtitle {
	text-align: center;
	color: #707070;
}

#nv-starter-content-notice .nv-notice-error {
	text-align: center;
	color: red;
}

.neve-separator-section {
	margin: 20px auto;
	max-width: 90%;
}.nv-button-group {
    display: flex;
    flex-direction: row;
    justify-content: space-between;
}

.nv-button-group label.button {
    border-radius: 0;
    flex: 1 1 0;
    text-align: center;
    display: flex;
    align-items: center;
    justify-content: center;
    line-height: 1;
    height: 27px;
    opacity: .6;
}

.nv-button-group input {
    display: none;
}

.nv-button-group input:checked + label,
.nv-button-group input:checked + label:hover {
    background: #fff;
    color: #13aff0;
    opacity: 1;
}

.nv-button-group label:first-of-type {
    border-left: none;
    border-bottom-right-radius: 3px;
    border-top-right-radius: 3px;
}

.nv-button-group label:last-of-type {
    border-right: none;
    border-bottom-left-radius: 3px;
    border-top-left-radius: 3px;
}

.nv-button-group-header {
    display: flex;
    align-items: center;
    position: relative;
    flex-wrap: wrap;
}

.nv-button-group-header i {
    margin-bottom: 4px;
    margin-right: 4px;
    cursor: pointer;
}

.nv-button-group-header i:hover {
    opacity: .75;
}

.nv-button-group-header input {
    display: none;
}

.nv-radio-description-info input{
    display: none;
}

.nv-radio-hidden-info {
    width: 100%;
    padding: 0 10px;
    border-radius: 5px;
    margin-bottom: 7px;
    max-height: 0;
    border: none;
    overflow: hidden;
    background-color: #fff;
    transition: all .3s ease;
}

.nv-button-group-header input:checked + .nv-radio-hidden-info {
    padding: 7px 10px;
    max-height: 200px;
}
.customize-control-checkbox-toggle .checkbox-toggle-wrap {
	flex-direction: row;
	padding: 7px 0;
	border: 1px solid #ccc;
	border-radius: 5px;

	-webkit-align-items: center;
	align-items: center;
	-webkit-box-align: center;
	-webkit-box-direction: normal;
	-webkit-box-orient: horizontal;
	-webkit-box-pack: justify;
	-ms-flex-align: center;
	-webkit-flex-direction: row;
	-ms-flex-direction: row;
	-ms-flex-pack: justify;
	-webkit-justify-content: space-between;
	justify-content: space-between;
}

.customize-control-checkbox-toggle span {
	display: inline-block;
	width: 65%;
	margin-right: 20px;
	font-weight: 600;
}

.customize-control-checkbox-toggle input[type=checkbox] {
	display: none;
}

.customize-control-checkbox-toggle label {
	display: inline-block;
	position: relative;
	width: 50px;
	height: 25px;
	margin-left: 20px;
	border-radius: 100px;
	background: grey;
	cursor: pointer;
}

.customize-control-checkbox-toggle label:after {
	position: absolute;
	top: 5px;
	right: 5px;
	width: 15px;
	height: 15px;
	border-radius: 90px;
	background: #fff;
	content: "";
	-webkit-transition: 0.3s;
	transition: 0.3s;
}

.customize-control-checkbox-toggle input:checked + label {
	background: #13aff0;
}

.customize-control-checkbox-toggle input:checked + label:after {
	right: -webkit-calc(100% - 5px);
	right: calc(100% - 5px);
	-webkit-transform: translateX(100%);
	-ms-transform: translateX(100%);
	transform: translateX(100%);
}

.customize-control-checkbox-toggle label:active:after {
	width: 30px;
}

.customize-control-checkbox-toggle > * {
	display: -ms-flexbox;
	display: -webkit-box;
	display: -webkit-flex;
	display: flex;
	flex-direction: row;

	-webkit-box-direction: normal;
	-webkit-box-orient: horizontal;
	-webkit-flex-direction: row;
	-ms-flex-direction: row;
}
.customize-control-neve-dimensions > ul {
	width: 100%;
}

.customize-control-neve-dimensions .dimension-wrap {
	float: right;
	width: 17%;
	margin: 0;
}

.customize-control-neve-dimensions .dimension-wrap input,
.customize-control-neve-dimensions .dimension-wrap button {
	display: block;
	width: 100%;
	height: 28px;
	padding: 4px 0;
	border: 1px solid;
	border-color: #a4afb7;
	border-right-width: 0;
	border-radius: 0;
	font-size: 12px;
	text-align: center;
}

.customize-control-neve-dimensions .dimension-wrap:first-child input {
	border-right-width: 1px;
	border-radius: 0 3px 3px 0;
}

.customize-control-neve-dimensions .dimension-wrap .dimension-label {
	display: block;
	padding-top: 5px;
	color: #949698;
	font-size: 10px;
	font-style: normal;
	text-align: center;
	text-transform: uppercase;
}

.customize-control-neve-dimensions .dimension-wrap input:focus + .dimension-label {
	color: #42474a;
}

.customize-control-neve-dimensions .dimension-wrap .link-dimensions {
	padding: 0;
	border: 1px solid #a4afb7;
	border-right-width: 0;
	border-radius: 3px 0 0 3px;
	outline: none;
	background-color: #fff;
	cursor: pointer;
}

.customize-control-neve-dimensions .dimension-wrap .link-dimensions span {
	display: block;
	width: 100%;
	height: 26px;
	font-size: 16px;
	line-height: 26px;
}

.customize-control-neve-dimensions .dimension-wrap .link-dimensions .neve-linked {
	color: #fff;
	background-color: #a4afb7;
}

.customize-control-neve-dimensions .dimension-wrap .link-dimensions.unlinked .neve-unlinked {
	display: none;
}

.customize-control-neve-dimensions .dimension-wrap .link-dimensions.unlinked .neve-linked {
	display: block;
}

.customize-control-neve-dimensions .dimension-wrap .link-dimensions .neve-linked {
	display: none;
}

.customize-control span.reset-dimensions {
	display: inline-block;
	position: relative;
	margin-right: 10px;
	color: rgba(0,0,0,0.2);
	line-height: 1;
	text-align: center;
	cursor: pointer;
	-webkit-transition: all 0.3s ease;
	-moz-transition: all 0.3s ease;
	-ms-transition: all 0.3s ease;
	-o-transition: all 0.3s ease;
	transition: all 0.3s ease;
}

.customize-control span.reset-dimensions:hover {
	color: #fe5252;
}
#customize-theme-controls #sub-accordion-section-neve_typography.customize-pane-child.open {
	height: 100%;
}

.neve-ss-wrap {
	position: relative;
	box-sizing: border-box;
	border: 1px solid #ddd;
}

.neve-ss-wrap.active {
	border: 1px solid #5897fb;
	box-shadow: 0 0 2px rgba(30, 140, 190, 0.8);
}

.customize-control input.neve-fs-main-input {
	display: block;
	float: right;
	box-sizing: border-box;
	width: 90%;
	height: 35px;
	border-left: 0;
	background: #fff;
	box-shadow: none;
	cursor: pointer;
}

.customize-control input.neve-fs-main-input:focus {
	border-color: #ddd;
}

.neve-fs-input-addon {
	display: inline-block;
	box-sizing: border-box;
	width: 10%;
	height: 35px;
	padding: 7px 0;
	border: 1px solid #ddd;
	border-right: 0;
	background: #fff;
	line-height: 18px;
	text-align: center;
}

.neve-fs-options-wrapper {
	overflow-y: scroll;
	max-height: 300px;
}

.neve-fs-options-group {
	display: block;
}

.neve-fs-search {
	display: block;
	padding: 7px;
	border-bottom: 1px solid #ddd;
}

.neve-fs-option,
.neve-fs-options-heading {
	display: block;
	padding: 3px 5px;
	line-height: 18px;
}

.neve-fs-option {
	cursor: pointer;
}

.neve-fs-options-heading {
	color: #777;
	background: #eee;
	font-weight: 600;
}

.neve-fs-option:hover {
	color: #fff;
	background: #5897fb;
}

.neve-ss-wrap.active .neve-fs-dropdown {
	display: block;
	z-index: 1000;
	width: 100%;
}

.neve-fs-dropdown {
	display: none;
	position: absolute;
	border: 1px solid #ddd;
	border-top: 0;
	background: #fff;
}
.neve-customizer-heading {
	color: #555d66;
	background-color: #fff;
	border-bottom: 1px solid #ddd;
	border-top: 1px solid #ddd;
	border-right: 4px solid #fff;
	transition: .15s color ease-in-out, .15s background-color ease-in-out, .15s border-color ease-in-out;
	font-size: 14px;
	border-left: none;
	padding-right: 14px;
	height: 42px;
	position: relative;
	display: flex;
	align-items: center;
	margin: 0 -12px;
	font-weight: 600;
	letter-spacing: .5px;
}

.customize-control.accordion .neve-customizer-heading {
	cursor: pointer;
	text-transform: uppercase;
	font-size: 13px;
}
.customize-control.accordion .neve-customizer-heading:hover {
	color: #0073aa;
	background: #f3f3f5;
	border-right-color: #0073aa;
}

.accordion-expand-button {
	margin-right: auto;
	z-index: 10;
	top: 0;
	left: 0;
	width: 42px;
	display: flex;
	align-items: center;
	justify-content: center;
	height: 100%;
	font-family: "Dashicons";
	border-right: 1px solid #DDDDDD;
}

.accordion-expand-button:after {
	display: block;
	position: relative;
	top: 1px;
	right: 1px;
	content: "\f347";
	-webkit-transition: 0.1s ease-in-out;
	transition: 0.1s ease-in-out;
	font-size: 16px;
	speak: none;
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale;
	text-decoration: none;
	color: #A0A5AA;
}

.customize-control.expanded .accordion-expand-button:after {
	transform: rotate(-180deg);
}
.ti-order-sortable li {
	display: -ms-flexbox;
	display: -webkit-box;
	display: -webkit-flex;
	display: flex;
	position: relative;
	border: 1px dashed #ccc;
	opacity: 0.7;
	background: #fff;
	text-align: center;

	-webkit-align-items: center;
	align-items: center;
	-webkit-box-align: center;
	-webkit-box-pack: center;
	-ms-flex-align: center;
	-ms-flex-pack: center;
	-webkit-justify-content: center;
	justify-content: center;
	z-index: 1;
}

.ti-order-sortable li.enabled {
	border: 1px solid #666;
	opacity: 1;
}

.ti-order-sortable li p {
	width: 100%;
	margin: 0;
	padding: 7px 10px;
}

.ti-order-sortable li > * {
	display: inline;
}

.ti-order-sortable span {
	position: absolute;
	z-index: 100;
	right: 0;
	padding: 5px 10px;
	cursor: pointer;
	-webkit-transition: 0.3s ease-in-out;
	transition: 0.3s ease-in-out;
}

.ti-order-sortable > li {
	right: inherit !important;
	cursor: move;
}

.ti-order-sortable > li:hover {
	border-color: #0087bf;
	cursor: move;
}

.ti-order-sortable > li:hover > p {
	color: #0087bf;
}

.ti-order-sortable .ui-sortable-helper {
	box-shadow: 0 2px 5px rgba(0, 0, 0, 0.3);
}

.ti-order-sortable span.drag {
	left: 0;
	right: auto;
	cursor: move;
}

.ti-order-sortable li .toggle-display:before {
	position: relative;
	top: 2px;
	font-family: Dashicons;
	font-size: 20px;
	content: "\f530";
}

.ti-order-sortable li .toggle-display:hover {
	color: #fff;
	background: #3ec8ff;
}

.ti-order-sortable li.enabled .toggle-display:before {
	content: "\f177";
}
.customize-control-radio-image .ui-buttonset {
	text-align: center;
}

.customize-control-radio-image label {
	display: inline-block;
	float: right;
	box-sizing: border-box;
	max-width: 33.3%;
	height: auto;
	padding: 3px;
	border-width: 0;
	border-radius: 0;
	color: inherit;
	background: none;
	box-shadow: none;
	font-size: inherit;
	line-height: inherit;
	vertical-align: inherit;
	white-space: nowrap;
	cursor: pointer;
    min-width: 25%;
	-webkit-appearance: none;
}


.customize-control-radio-image label:nth-of-type(4n+1){
    clear: both;
}

.customize-control-radio-image label:first-of-type {
	float: right;
}

.customize-control-radio-image label:hover {
	border-color: inherit;
	color: inherit;
	background: none;
}

.customize-control-radio-image label:active {
	border-color: inherit;
	background: none;
	box-shadow: none;
	-webkit-transform: none;
	-ms-transform: none;
	transform: none;
}

.customize-control-radio-image img {
	border: 1px solid transparent;
}

.customize-control-radio-image .ui-state-active img {
	border-color: #00b6ff;
	box-shadow: 0 0 5px #3ec8fe;
}

#customize-control-header_video,
#customize-control-external_header_video {
	display: none;
}

/**
 * Tab styling
 */
.customizer-tab:not(.customizer-subtab) {
	display: table;
	width: -webkit-calc(100% + 28px);
	width: calc(100% + 28px);
	margin: -15px -12px 0 0;
}

.customizer-tab:not(.customizer-subtab) label {
	display: inherit;
	width: 50%;
	max-width: 100%;
	padding: 10px 0;
	border-left: 1px solid #ddd;
	color: #333;
	background: #fff;
	font-weight: 600;
	vertical-align: top;
	text-decoration: none;
	text-transform: capitalize;
	-webkit-transition: all 0.3s ease;
	transition: all 0.3s ease;
}

.customizer-tab:not(.customizer-subtab) label i {
	margin-left: 4px;
	color: #333;
}

.customizer-tab:not(.customizer-subtab) label.ui-state-active {
	color: #0085ba;
	background-color: #fff;
	box-shadow: inset 0 -3px 0 0 #0085ba;
}

.customizer-tab:not(.customizer-subtab) label:last-child {
	border: none;
}

.ui-buttonset .ui-helper-hidden-accessible{
	position:relative;
}

.customize-control-radio-image input[type=radio]{
	display: none;
}
.range-slider {
	display: -ms-flexbox;
	display: -webkit-box;
	display: -webkit-flex;
	display: flex;
	flex-direction: row;
	-webkit-box-sizing: border-box;
	-moz-box-sizing: border-box;
	width: 100%;

	-webkit-align-items: center;
	align-items: center;
	-webkit-box-align: center;
	-webkit-box-direction: normal;
	-webkit-box-orient: horizontal;
	-webkit-box-pack: start;
	-ms-flex-align: center;
	-webkit-flex-direction: row;
	-ms-flex-direction: row;
	-ms-flex-pack: start;
	-webkit-flex-wrap: wrap;
	-ms-flex-wrap: wrap;
	flex-wrap: wrap;
	-webkit-justify-content: flex-start;
	justify-content: flex-start;
}

.range-slider__range {
	width: 67%;
	height: 5px;
	padding: 0;
	border-radius: 5px;
	outline: none;
	background-color: rgba(0,0,0,0.1);
	cursor: pointer;
	-webkit-transition: background 0.5s;
	transition: background 0.5s;

	-webkit-appearance: none;
}

.range-slider__range::-webkit-slider-thumb {
	width: 17px;
	height: 17px;
	border: 2px solid #2e86b9;
	border-radius: 15px;
	background-color: #fff;

	-webkit-appearance: none;
}

.range-slider__range::-webkit-slider-thumb:hover {
	background: #fff;
}

.range-slider__range:active::-webkit-slider-thumb {
	background: #fff;
}

.range-slider__range::-moz-range-thumb {
	width: 20px;
	height: 20px;
	border: 2px solid #2e86b9;
	border-radius: 50%;
	background-color: #fff;
	cursor: pointer;
	-webkit-transition: background 0.15s ease-in-out;
	transition: background 0.15s ease-in-out;
}

.range-slider__range::-moz-range-thumb:hover {
	background: #fff;
}

.range-slider__range:active::-moz-range-thumb {
	background: #fff;
}

.customize-control input[type=number].range-slider-value,
.customize-control input[type=text].range-slider-value {
	width: 21%;
	height: 28px;
	margin-right: 2%;
	padding: 3px;
	border-radius: 4px;
	color: #555;
	font-size: 12px;
	font-weight: 600;
	text-align: center;
	cursor: default;

	-moz-appearance: textfield;
}

.customize-control input[type=number].range-slider-value::-webkit-outer-spin-button,
.customize-control input[type=number].range-slider-value::-webkit-inner-spin-button {
	margin: 0;

	-webkit-appearance: none;
}

.customize-control input[type=number].range-slider-value {
	-moz-appearance: textfield;
}

.range-reset-slider .dashicons {
	width: 16px;
	height: 16px;
	font-size: 16px;
	line-height: 1;
}

.customize-control span.range-reset-slider {
	display: inline-block;
	position: relative;
	width: 6%;
	color: rgba(0,0,0,0.2);
	line-height: 1;
	text-align: center;
	cursor: pointer;
	-webkit-transition: all 0.3s ease;
	-moz-transition: all 0.3s ease;
	-ms-transition: all 0.3s ease;
	-o-transition: all 0.3s ease;
	transition: all 0.3s ease;
}

.customize-control span.range-reset-slider:hover {
	color: #fe5252;
}

::-moz-range-track {
	border: 0;
	background: #d7dcdf;
}

input::-moz-focus-inner,
input::-moz-focus-outer {
	border: 0;
}

.customize-control-range-value .customize-control-title,
.customize-control-range-value .responsive-switchers {
	display: inline-block;
}

.responsive-switchers {
	display: inline-block;
	margin-bottom: 5px;
	vertical-align: middle;
}

.responsive-switchers .preview-tablet,
.responsive-switchers .preview-mobile {
	display: none;
}

.customize-control .responsive-switchers {
	width: auto;
	margin-right: 5px;
}

.customize-control .responsive-switchers-open li button {
	display: block;
}

.customize-control .responsive-switchers li {
	float: right;
	margin: 0;
}

.customize-control .responsive-switchers li button {
	position: relative;
	width: 20px;
	height: 20px;
	margin-right: 5px;
	padding: 0;
	border: 0;
	border-radius: 50%;
	outline: none;
	color: #fff;
	background-color: #a4afb7;
	font-size: 10px;
	text-align: center;
	cursor: pointer;
	cursor: pointer;
	-webkit-transition: background-color 0.5s;
	transition: background-color 0.5s;
}

.customize-control .responsive-switchers li button:hover {
	background-color: #c2cbd2;
}

.customize-control .responsive-switchers li button.active {
	background-color: #13aff0;
}

.customize-control .responsive-switchers li button i {
	width: auto;
	height: auto;
	font-size: inherit;
	line-height: 18px;
}
.responsive-number .controls--wrap {
	display: flex;

	align-items: center;
}

.customize-control .responsive-number.no-units input[type=number] {
	width: 95%;
}

.customize-control .responsive-number:not(.no-units) input[type=number] {
	width: 73%;
}

.customize-control .responsive-number input[type=number].no-units {
	width: 98%;
}

.responsive-number select {
	float: left;
	width: 23%;
	margin-right: 2%;
}

.responsive-number .control-wrap.active {
	display: flex;
	/*justify-content: space-between;*/
}

.reset-number-input {
	display: inline-block;
	position: relative;
	width: 6%;
	margin-right: auto;
	color: rgba(0, 0, 0, 0.2);
	line-height: 1;
	text-align: center;
	cursor: pointer;
	transition: all 0.3s ease;
}

.reset-number-input .dashicons {
	width: 16px;
	height: 16px;
	font-size: 16px;
}
.customize-control-interface-tabs {
	display: list-item !important;
}

.neve-tabs-control {
	display: table;
	width: -webkit-calc(100% + 28px);
	width: calc(100% + 28px);
	margin: -15px -12px 0 0;
	border-bottom: 1px solid #ddd;
	table-layout: fixed;
}

.neve-tabs-control .neve-customizer-tab {
	display: table-cell;
	width: 100%;
	border-left: 1px solid #ddd;
	text-align: center;
}

.neve-tabs-control .neve-customizer-tab:last-child {
	border-left: none;
}

.neve-tabs-control .neve-customizer-tab label {
	display: block;
	width: 100%;
	padding: 10px 0;
	color: #333;
	background: #fff;
	box-shadow: inset 0 0 0 0 #0085ba;
	font-weight: 600;
	text-decoration: none;
	text-transform: capitalize;
	-webkit-transition: all 0.3s ease;
	transition: all 0.3s ease;
}

.neve-tabs-control .neve-customizer-tab label i {
	margin-left: 4px;
	color: #333;
}

.neve-tabs-control .neve-customizer-tab label:hover {
	color: #0085ba;
	background: #f3f3f5;
}

.neve-tabs-control .neve-customizer-tab label:hover i {
	color: #333;
}

.neve-tabs-control .neve-customizer-tab.active label {
	color: #0085ba;
	background-color: #fff;
	box-shadow: inset 0 -3px 0 0 #0085ba;
}

.neve-tabs-control input[type="radio"] {
	display: none !important;
}

.tab-hidden {
	visibility: hidden !important;
	overflow: hidden !important;
	height: 0 !important;
	margin: 0 !important;
	padding: 0 !important;
}
.nv-upsell {
    background: #fff;
    padding: 21px;
    border-radius: 3px;
}

.nv-upsell .upsell-pro-label {
    font-weight: bold;
    background: #a7a7a7;
    color: #fff;
    text-transform: uppercase;
    padding: 2px 7px 2px 6px;
    letter-spacing: .1px;
    font-size: 12px;
    border-radius: 3px;
    margin-left: 10px;
}

.nv-upsell-features li {
    line-height: 24px;
    margin-bottom: 23px;
    font-size: 14px;
}
.nv-upsell-features li:last-child {
    margin-bottom: 20px;
}
.nv-upsell-features.no-explained li {
    margin-bottom: 0;
}
.nv-upsell-features.no-explained li:last-child {
    margin-bottom: 0;
}

.nv-upsell .button {
    margin-left: 21px;
    width: 100%;
    text-align: center;
    letter-spacing: .2px;
}

.nv-upsell hr {
    margin-top: 22px;
    margin-bottom: 16px;
}

.nv-upsell-feature-list li:before {
    line-height: 37px;
}

.nv-upsell-feature-list li {
    line-height: 22px;
    font-size: 14px;
    font-style: italic;
    margin-bottom: 6px;
}

.nv-upsell-feature-list li:last-child {
    margin-bottom: 0;
}

.nv-upsell-content{
    margin-bottom: 10px;
}

#customize-controls #accordion-section-neve_upsells_section.control-section .accordion-section-title:hover {
    background-color: #0073aa;
    color: #fff;
}

#customize-controls #accordion-section-neve_upsells_section.control-section .accordion-section-title:hover:after {
    color: #fff;
}

.customize-control-nv_simple_upsell {
	background: transparent !important;
}
.nv-simple-upsell {
	display: flex;
	border-top: 1px solid #ccc;
	padding-top: 10px;
	align-items: center;
}
.nv-simple-upsell.column-layout {
	flex-direction: column;
	align-items: start;
	gap: 16px;
	border-bottom: 1px solid #ccc;
	border-top: none;
	padding-bottom: 12px;
}

.nv-simple-upsell.column-layout p {
	font-size: 13px;
	font-weight: normal;
}

.nv-simple-upsell p {
	margin: 0 0 0 10px;
	font-weight: 600;
	font-size: 12px;
}

.nv-simple-upsell a.button {
	font-weight: 600;
	font-size: 12px;
	line-height: normal;
	min-height: unset;
	display: flex;
	align-items: center;
	justify-content: center;
	padding: 6px 12px 7px;
	flex-grow: 0;
}


.control-section-nv_simple_upsell_section {
	padding: 12px 15px;
}

li.customize-control-neve_radio_image_control .option.upsell {
    position: relative;
}

li.customize-control-neve_radio_image_control .option.upsell label {
    pointer-events: none;
}

li.customize-control-neve_radio_image_control .option.upsell button {
    filter: saturate(0);
}

li.customize-control-neve_radio_image_control .option.upsell:hover .upsell-btn {
    display:block;
}

li.customize-control-neve_radio_image_control .upsell-btn {
    pointer-events: all;
    position: absolute;
    top: 40%;
    right: 50%;
    transform: translate(50%, -50%);
    background: white;
    padding: 10px 10px;
    vertical-align:middle;
    font-size:10px;
    line-height: normal;
    font-weight: bold;
    box-shadow: rgba(91, 91, 92, 0.5) 0px 8px 30px 0px;
    white-space: nowrap;
    display:none;
    color: #0073AA;
}

.upsell-btn .dashicons {
    vertical-align: middle;
    text-decoration: none;
    font-size:18px;
    font-weight: normal;
    color: #0073AA;
    margin:0;
}

li.customize-control-neve_radio_image_control .option.upsell .dashicons-lock {
    font-size:14px;
    position: absolute;
    top: 0;
    left: 5px;
    color: #0073AA;
    z-index: 1;
    opacity: 0.45;
}
