.sincotechs-form {
    max-width: 500px;
    padding: 15px;
    border: 1px solid #ddd;
    background: #fafafa;
}

.sincotechs-form-group {
    margin-bottom: 12px;
}

.sincotechs-form-group label {
    display: block;
    font-weight: 600;
    margin-bottom: 4px;
}

.sincotechs-form-group input,
.sincotechs-form-group textarea,
.sincotechs-form-group select {
    width: 100%;
    padding: 6px;
    border: 1px solid #ccc;
    border-radius: 3px;
    box-sizing: border-box;
}

.sincotechs-required {
    color: red;
    margin-left: 4px;
}

.sincotechs-submit {
    padding: 8px 14px;
    border-radius: 3px;
    border: none;
    cursor: pointer;
}

.sincotechs-confirmation-message {
    padding: 10px;
    background: #e6ffed;
    border: 1px solid #b7f0c2;
    margin-bottom: 15px;
}
