<?php
/**
 * Spacing Control for Customizer class for Header Footer Grid.
 *
 * Name:    Header Footer Grid
 * Author:  Bogdan Preda <bogdan.preda@themeisle.com>
 *
 * @version 1.0.0
 * @package HFG
 */

namespace HFG\Core\Customizer;

use HFG\Core\Settings\Config;
use WP_Customize_Control;

/**
 * Class SpacingControl
 *
 * @package HFG\Core\Customizer
 */
