!function(){"use strict";wp.domReady(function(){var e=wp.i18n.__;wp.blocks.unregisterBlockStyle("core/button","fill"),wp.blocks.unregisterBlockStyle("core/button","outline"),wp.blocks.registerBlockStyle("core/button",{name:"default",label:e("Default"),isDefault:!0}),wp.blocks.registerBlockStyle("core/button",{name:"primary",label:e("Primary","neve")}),wp.blocks.registerBlockStyle("core/button",{name:"secondary",label:e("Secondary"),isDefault:!1})})}();
