.customize-control-neve-dimensions > ul {
	width: 100%;
}

.customize-control-neve-dimensions .dimension-wrap {
	float: left;
	width: 17%;
	margin: 0;
}

.customize-control-neve-dimensions .dimension-wrap input,
.customize-control-neve-dimensions .dimension-wrap button {
	display: block;
	width: 100%;
	height: 28px;
	padding: 4px 0;
	border: 1px solid;
	border-color: #a4afb7;
	border-left-width: 0;
	border-radius: 0;
	font-size: 12px;
	text-align: center;
}

.customize-control-neve-dimensions .dimension-wrap:first-child input {
	border-left-width: 1px;
	border-radius: 3px 0 0 3px;
}

.customize-control-neve-dimensions .dimension-wrap .dimension-label {
	display: block;
	padding-top: 5px;
	color: #949698;
	font-size: 10px;
	font-style: normal;
	text-align: center;
	text-transform: uppercase;
}

.customize-control-neve-dimensions .dimension-wrap input:focus + .dimension-label {
	color: #42474a;
}

.customize-control-neve-dimensions .dimension-wrap .link-dimensions {
	padding: 0;
	border: 1px solid #a4afb7;
	border-left-width: 0;
	border-radius: 0 3px 3px 0;
	outline: none;
	background-color: #fff;
	cursor: pointer;
}

.customize-control-neve-dimensions .dimension-wrap .link-dimensions span {
	display: block;
	width: 100%;
	height: 26px;
	font-size: 16px;
	line-height: 26px;
}

.customize-control-neve-dimensions .dimension-wrap .link-dimensions .neve-linked {
	color: #fff;
	background-color: #a4afb7;
}

.customize-control-neve-dimensions .dimension-wrap .link-dimensions.unlinked .neve-unlinked {
	display: none;
}

.customize-control-neve-dimensions .dimension-wrap .link-dimensions.unlinked .neve-linked {
	display: block;
}

.customize-control-neve-dimensions .dimension-wrap .link-dimensions .neve-linked {
	display: none;
}

.customize-control span.reset-dimensions {
	display: inline-block;
	position: relative;
	margin-left: 10px;
	color: rgba(0,0,0,0.2);
	line-height: 1;
	text-align: center;
	cursor: pointer;
	-webkit-transition: all 0.3s ease;
	-moz-transition: all 0.3s ease;
	-ms-transition: all 0.3s ease;
	-o-transition: all 0.3s ease;
	transition: all 0.3s ease;
}

.customize-control span.reset-dimensions:hover {
	color: #fe5252;
}
