<?php
/**
 * Contact us starter content.
 *
 * @package Neve\Compatibility\Starter_Content
 */

return [
	'post_type'    => 'page',
	'post_name'    => 'contact',
	'post_title'   => _x( 'Contact', 'Theme starter content', 'neve' ),
	'post_content' => '<!-- wp:cover {"overlayColor":"nv-site-bg","isUserOverlayColor":true,"minHeight":300,"align":"full","style":{"spacing":{"padding":{"right":"0","left":"0"}}}} -->
<div class="wp-block-cover alignfull" style="padding-right:0;padding-left:0;min-height:300px"><span aria-hidden="true" class="wp-block-cover__background has-nv-site-bg-background-color has-background-dim-100 has-background-dim"></span><div class="wp-block-cover__inner-container"><!-- wp:group {"style":{"spacing":{"padding":{"right":"var:preset|spacing|30","left":"var:preset|spacing|30"}}}} -->
<div class="wp-block-group" style="padding-right:var(--wp--preset--spacing--30);padding-left:var(--wp--preset--spacing--30)"><!-- wp:heading {"level":1,"textColor":"neve-text-color","className":"has-text-align-left"} -->
<h1 class="wp-block-heading has-text-align-left has-neve-text-color-color has-text-color">Contact us</h1>
<!-- /wp:heading --></div>
<!-- /wp:group --></div></div>
<!-- /wp:cover -->

<!-- wp:cover {"overlayColor":"nv-light-bg","isUserOverlayColor":true,"minHeight":420,"align":"full"} -->
<div class="wp-block-cover alignfull" style="min-height:420px"><span aria-hidden="true" class="wp-block-cover__background has-nv-light-bg-background-color has-background-dim-100 has-background-dim"></span><div class="wp-block-cover__inner-container"><!-- wp:spacer {"height":"80px"} -->
<div style="height:80px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:columns -->
<div class="wp-block-columns"><!-- wp:column {"style":{"spacing":{"padding":{"right":"var:preset|spacing|30","left":"var:preset|spacing|30"}}},"className":"ticss-4ce656f1"} -->
<div class="wp-block-column ticss-4ce656f1" style="padding-right:var(--wp--preset--spacing--30);padding-left:var(--wp--preset--spacing--30)"><!-- wp:group {"style":{"border":{"radius":"24px"}},"backgroundColor":"nv-site-bg"} -->
<div class="wp-block-group has-nv-site-bg-background-color has-background" style="border-radius:24px"><!-- wp:spacer {"height":"24px"} -->
<div style="height:24px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:image {"sizeSlug":"full","linkDestination":"none","align":"center","className":"icon-style is-style-default"} -->
<figure class="wp-block-image aligncenter size-full icon-style is-style-default"><img src="' . trailingslashit( get_template_directory_uri() ) . 'assets/img/starter-content/neve-marketing-icon-7.png" alt=""/></figure>
<!-- /wp:image -->

<!-- wp:spacer {"height":"24px"} -->
<div style="height:24px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:heading {"level":3,"textColor":"neve-text-color","className":"has-text-align-center"} -->
<h3 class="wp-block-heading has-text-align-center has-neve-text-color-color has-text-color">Call us</h3>
<!-- /wp:heading -->

<!-- wp:paragraph {"align":"center","style":{"typography":{"fontSize":15}},"textColor":"neve-text-color"} -->
<p class="has-text-align-center has-neve-text-color-color has-text-color" style="font-size:15px">509-728-8632 | Monday - Friday</p>
<!-- /wp:paragraph -->

<!-- wp:spacer {"height":"24px"} -->
<div style="height:24px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer --></div>
<!-- /wp:group --></div>
<!-- /wp:column -->

<!-- wp:column {"style":{"spacing":{"padding":{"right":"var:preset|spacing|30","left":"var:preset|spacing|30"}}},"className":"ticss-f6fc7494"} -->
<div class="wp-block-column ticss-f6fc7494" style="padding-right:var(--wp--preset--spacing--30);padding-left:var(--wp--preset--spacing--30)"><!-- wp:group {"style":{"border":{"radius":"24px"}},"backgroundColor":"nv-site-bg"} -->
<div class="wp-block-group has-nv-site-bg-background-color has-background" style="border-radius:24px"><!-- wp:spacer {"height":"24px"} -->
<div style="height:24px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:image {"sizeSlug":"full","linkDestination":"none","align":"center","className":"icon-style is-style-default"} -->
<figure class="wp-block-image aligncenter size-full icon-style is-style-default"><img src="' . trailingslashit( get_template_directory_uri() ) . 'assets/img/starter-content/neve-marketing-icon-5.png" alt=""/></figure>
<!-- /wp:image -->

<!-- wp:spacer {"height":"24px"} -->
<div style="height:24px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:heading {"level":3,"textColor":"neve-text-color","className":"has-text-align-center"} -->
<h3 class="wp-block-heading has-text-align-center has-neve-text-color-color has-text-color">Email</h3>
<!-- /wp:heading -->

<!-- wp:paragraph {"align":"center","style":{"typography":{"fontSize":15}},"textColor":"neve-text-color"} -->
<p class="has-text-align-center has-neve-text-color-color has-text-color" style="font-size:15px">info@marketing-agency.com</p>
<!-- /wp:paragraph -->

<!-- wp:spacer {"height":"24px"} -->
<div style="height:24px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer --></div>
<!-- /wp:group --></div>
<!-- /wp:column -->

<!-- wp:column {"style":{"spacing":{"padding":{"right":"var:preset|spacing|30","left":"var:preset|spacing|30"}}},"className":"ticss-a5b4df29"} -->
<div class="wp-block-column ticss-a5b4df29" style="padding-right:var(--wp--preset--spacing--30);padding-left:var(--wp--preset--spacing--30)"><!-- wp:group {"style":{"border":{"radius":"24px"}},"backgroundColor":"nv-site-bg"} -->
<div class="wp-block-group has-nv-site-bg-background-color has-background" style="border-radius:24px"><!-- wp:spacer {"height":"24px"} -->
<div style="height:24px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:image {"sizeSlug":"full","linkDestination":"none","align":"center","className":"icon-style is-style-default"} -->
<figure class="wp-block-image aligncenter size-full icon-style is-style-default"><img src="' . trailingslashit( get_template_directory_uri() ) . 'assets/img/starter-content/neve-marketing-icon-6.png" alt=""/></figure>
<!-- /wp:image -->

<!-- wp:spacer {"height":"24px"} -->
<div style="height:24px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:heading {"level":3,"textColor":"neve-text-color","className":"has-text-align-center"} -->
<h3 class="wp-block-heading has-text-align-center has-neve-text-color-color has-text-color">Offices</h3>
<!-- /wp:heading -->

<!-- wp:paragraph {"align":"center","style":{"typography":{"fontSize":15}},"textColor":"neve-text-color"} -->
<p class="has-text-align-center has-neve-text-color-color has-text-color" style="font-size:15px">2982 Sun Valley Road, Washington</p>
<!-- /wp:paragraph -->

<!-- wp:spacer {"height":"24px"} -->
<div style="height:24px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer --></div>
<!-- /wp:group --></div>
<!-- /wp:column --></div>
<!-- /wp:columns -->

<!-- wp:spacer {"height":"30px"} -->
<div style="height:30px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer --></div></div>
<!-- /wp:cover -->

<!-- wp:cover {"overlayColor":"nv-dark-bg","isUserOverlayColor":true,"minHeight":600,"align":"full"} -->
<div class="wp-block-cover alignfull" style="min-height:600px"><span aria-hidden="true" class="wp-block-cover__background has-nv-dark-bg-background-color has-background-dim-100 has-background-dim"></span><div class="wp-block-cover__inner-container"><!-- wp:group -->
<div class="wp-block-group"><!-- wp:spacer {"height":"80px"} -->
<div style="height:80px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:cover {"url":"' . trailingslashit( get_template_directory_uri() ) . 'assets/img/starter-content/neve-marketing-agency-25.png","dimRatio":50,"overlayColor":"neve-link-color","isUserOverlayColor":true,"style":{"border":{"radius":"24px"}},"layout":{"type":"constrained"}} -->
<div class="wp-block-cover" style="border-radius:24px"><span aria-hidden="true" class="wp-block-cover__background has-neve-link-color-background-color has-background-dim"></span><img class="wp-block-cover__image-background" alt="" src="' . trailingslashit( get_template_directory_uri() ) . 'assets/img/starter-content/neve-marketing-agency-25.png" data-object-fit="cover"/><div class="wp-block-cover__inner-container"><!-- wp:paragraph {"align":"center","placeholder":"Write title…","fontSize":"large"} -->
<p class="has-text-align-center has-large-font-size"></p>
<!-- /wp:paragraph --></div></div>
<!-- /wp:cover -->

<!-- wp:spacer {"height":"40px"} -->
<div style="height:40px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:columns -->
<div class="wp-block-columns"><!-- wp:column {"width":"50%","style":{"spacing":{"padding":{"right":"var:preset|spacing|30","left":"var:preset|spacing|30"}}}} -->
<div class="wp-block-column" style="padding-right:var(--wp--preset--spacing--30);padding-left:var(--wp--preset--spacing--30);flex-basis:50%"><!-- wp:heading {"textColor":"nv-text-dark-bg"} -->
<h2 class="wp-block-heading has-nv-text-dark-bg-color has-text-color">Send us a message or Come visit us</h2>
<!-- /wp:heading -->

<!-- wp:paragraph {"textColor":"white"} -->
<p class="has-white-color has-text-color">Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.</p>
<!-- /wp:paragraph -->

<!-- wp:social-links {"iconColor":"nv-text-dark-bg","iconColorValue":"var(\u002d\u002dnv-text-dark-bg)","size":"has-normal-icon-size","className":"is-style-pill-shape"} -->
<ul class="wp-block-social-links has-normal-icon-size has-icon-color is-style-pill-shape"><!-- wp:social-link {"url":"#","service":"facebook"} /-->

<!-- wp:social-link {"url":"#","service":"twitter"} /-->

<!-- wp:social-link {"url":"#","service":"google"} /--></ul>
<!-- /wp:social-links --></div>
<!-- /wp:column -->

<!-- wp:spacer {"height":"40px"} -->
<div style="height:40px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer --></div>
<!-- /wp:group --></div></div>
<!-- /wp:cover -->',
];
