.wpgc-wrap{display:grid;grid-template-columns:1fr;gap:16px;align-items:start}
.wpgc-card{background:#fff;border:1px solid #e5e7eb;border-radius:16px;padding:12px;box-shadow:0 1px 2px rgba(0,0,0,.04)}
.wpgc-users{list-style:none;margin:0;padding:0;max-height:240px;overflow:auto}
.wpgc-users li{padding:6px 8px;border-bottom:1px dashed #e5e7eb;cursor:pointer}
.wpgc-controls{display:flex;gap:8px;align-items:center;flex-wrap:wrap}
.wpgc-controls button{border:0;border-radius:9999px;padding:10px 14px;cursor:pointer;box-shadow:0 1px 2px rgba(0,0,0,.08)}
.wpgc-controls button.muted{opacity:.6}
.wpgc-controls button.off{opacity:.6}
video{width:100%;border-radius:12px;background:#111;max-height:40vh}
.wpgc-chat{display:flex;flex-direction:column;height:260px}
.wpgc-chat-log{flex:1;overflow:auto;border:1px solid #e5e7eb;border-radius:8px;padding:8px;background:#fafafa;max-height:260px}
.wpgc-chat-row{padding:6px 8px;border-bottom:1px dashed #eee}
.wpgc-chat-form{display:flex;gap:8px;margin-top:8px}
.wpgc-chat-form input{flex:1;padding:10px;border:1px solid #ddd;border-radius:8px}
.wpgc-chat-form button{padding:10px 16px;border:0;background:#111;color:#fff;border-radius:8px;cursor:pointer}
.wpgc-meta{display:flex;gap:12px;flex-wrap:wrap;font-size:14px}
.wpgc-rule-box{white-space:pre-wrap;font-size:14px;background:#f6f6f6;border:1px solid #eee;border-radius:8px;padding:8px}
.wpgc-remote-status{font-size:14px;opacity:.9}
.wpgc-remote-name{font-size:18px;font-weight:600}
.wpgc-diag{font-size:12px;opacity:.7;margin-top:6px}
.wpgc-credit{font-size:12px;opacity:.8;text-align:center;margin-top:12px}
