#customize-theme-controls #sub-accordion-section-neve_typography.customize-pane-child.open {
	height: 100%;
}

.neve-ss-wrap {
	position: relative;
	box-sizing: border-box;
	border: 1px solid #ddd;
}

.neve-ss-wrap.active {
	border: 1px solid #5897fb;
	box-shadow: 0 0 2px rgba(30, 140, 190, 0.8);
}

.customize-control input.neve-fs-main-input {
	display: block;
	float: left;
	box-sizing: border-box;
	width: 90%;
	height: 35px;
	border-right: 0;
	background: #fff;
	box-shadow: none;
	cursor: pointer;
}

.customize-control input.neve-fs-main-input:focus {
	border-color: #ddd;
}

.neve-fs-input-addon {
	display: inline-block;
	box-sizing: border-box;
	width: 10%;
	height: 35px;
	padding: 7px 0;
	border: 1px solid #ddd;
	border-left: 0;
	background: #fff;
	line-height: 18px;
	text-align: center;
}

.neve-fs-options-wrapper {
	overflow-y: scroll;
	max-height: 300px;
}

.neve-fs-options-group {
	display: block;
}

.neve-fs-search {
	display: block;
	padding: 7px;
	border-bottom: 1px solid #ddd;
}

.neve-fs-option,
.neve-fs-options-heading {
	display: block;
	padding: 3px 5px;
	line-height: 18px;
}

.neve-fs-option {
	cursor: pointer;
}

.neve-fs-options-heading {
	color: #777;
	background: #eee;
	font-weight: 600;
}

.neve-fs-option:hover {
	color: #fff;
	background: #5897fb;
}

.neve-ss-wrap.active .neve-fs-dropdown {
	display: block;
	z-index: 1000;
	width: 100%;
}

.neve-fs-dropdown {
	display: none;
	position: absolute;
	border: 1px solid #ddd;
	border-top: 0;
	background: #fff;
}
