<?php

// autoload_classmap.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    'Composer\\InstalledVersions' => $vendorDir . '/composer/InstalledVersions.php',
    'HFG\\Core\\Builder\\Abstract_Builder' => $baseDir . '/header-footer-grid/Core/Builder/Abstract_Builder.php',
    'HFG\\Core\\Builder\\Footer' => $baseDir . '/header-footer-grid/Core/Builder/Footer.php',
    'HFG\\Core\\Builder\\Header' => $baseDir . '/header-footer-grid/Core/Builder/Header.php',
    'HFG\\Core\\Components\\Abstract_Component' => $baseDir . '/header-footer-grid/Core/Components/Abstract_Component.php',
    'HFG\\Core\\Components\\Abstract_FooterWidget' => $baseDir . '/header-footer-grid/Core/Components/Abstract_FooterWidget.php',
    'HFG\\Core\\Components\\Abstract_SearchComponent' => $baseDir . '/header-footer-grid/Core/Components/Abstract_SearchComponent.php',
    'HFG\\Core\\Components\\Button' => $baseDir . '/header-footer-grid/Core/Components/Button.php',
    'HFG\\Core\\Components\\CartIcon' => $baseDir . '/header-footer-grid/Core/Components/CartIcon.php',
    'HFG\\Core\\Components\\CustomHtml' => $baseDir . '/header-footer-grid/Core/Components/CustomHtml.php',
    'HFG\\Core\\Components\\EddCartIcon' => $baseDir . '/header-footer-grid/Core/Components/EddCartIcon.php',
    'HFG\\Core\\Components\\FooterWidgetFour' => $baseDir . '/header-footer-grid/Core/Components/FooterWidgetFour.php',
    'HFG\\Core\\Components\\FooterWidgetOne' => $baseDir . '/header-footer-grid/Core/Components/FooterWidgetOne.php',
    'HFG\\Core\\Components\\FooterWidgetThree' => $baseDir . '/header-footer-grid/Core/Components/FooterWidgetThree.php',
    'HFG\\Core\\Components\\FooterWidgetTwo' => $baseDir . '/header-footer-grid/Core/Components/FooterWidgetTwo.php',
    'HFG\\Core\\Components\\Logo' => $baseDir . '/header-footer-grid/Core/Components/Logo.php',
    'HFG\\Core\\Components\\MenuIcon' => $baseDir . '/header-footer-grid/Core/Components/MenuIcon.php',
    'HFG\\Core\\Components\\Nav' => $baseDir . '/header-footer-grid/Core/Components/Nav.php',
    'HFG\\Core\\Components\\NavFooter' => $baseDir . '/header-footer-grid/Core/Components/NavFooter.php',
    'HFG\\Core\\Components\\PaletteSwitch' => $baseDir . '/header-footer-grid/Core/Components/PaletteSwitch.php',
    'HFG\\Core\\Components\\Search' => $baseDir . '/header-footer-grid/Core/Components/Search.php',
    'HFG\\Core\\Components\\SearchResponsive' => $baseDir . '/header-footer-grid/Core/Components/SearchResponsive.php',
    'HFG\\Core\\Components\\SecondNav' => $baseDir . '/header-footer-grid/Core/Components/SecondNav.php',
    'HFG\\Core\\Components\\Utility\\SearchIconButton' => $baseDir . '/header-footer-grid/Core/Components/Utility/SearchIconButton.php',
    'HFG\\Core\\Css_Generator' => $baseDir . '/header-footer-grid/Core/Css_Generator.php',
    'HFG\\Core\\Customizer' => $baseDir . '/header-footer-grid/Core/Customizer.php',
    'HFG\\Core\\Interfaces\\Builder' => $baseDir . '/header-footer-grid/Core/Interfaces/Builder.php',
    'HFG\\Core\\Interfaces\\Component' => $baseDir . '/header-footer-grid/Core/Interfaces/Component.php',
    'HFG\\Core\\Magic_Tags' => $baseDir . '/header-footer-grid/Core/Magic_Tags.php',
    'HFG\\Core\\Script_Register' => $baseDir . '/header-footer-grid/Core/Script_Register.php',
    'HFG\\Core\\Settings\\Config' => $baseDir . '/header-footer-grid/Core/Settings/Config.php',
    'HFG\\Core\\Settings\\Defaults' => $baseDir . '/header-footer-grid/Core/Settings/Defaults.php',
    'HFG\\Core\\Settings\\Manager' => $baseDir . '/header-footer-grid/Core/Settings/Manager.php',
    'HFG\\Main' => $baseDir . '/header-footer-grid/Main.php',
    'HFG\\Traits\\Core' => $baseDir . '/header-footer-grid/Traits/Core.php',
);
