<?php get_header(); ?>
HELLO WORLD!!
<?php
$flag = wp_mail( "jasjit207047stu@gmail.com", "SUBJECT", "This is Message!!"); 
var_dump( $flag );
?>
<?php the_post(); ?>

<?php the_content(); ?>

<?php get_footer(); ?>