<div class="scp-root">
<h2>Sincotechs Dashboard</h2>
<h3>Your Token Balance</h3>
<p><strong id="scp-balance">0</strong> tokens</p>
<button class="scp-btn" onclick="buyTokens(100)">Buy 100</button>
<button class="scp-btn" onclick="buyTokens(500)">Buy 500</button>
<button class="scp-btn" onclick="buyTokens(1000)">Buy 1000</button>
<h3>Your Earnings (models)</h3>
<p><?php $u=wp_get_current_user(); $earn=intval(get_user_meta($u->ID,'scp_earnings',true)); echo $earn.' tokens earned'; ?></p>
<h3>Your Role</h3>
<p><?php echo implode(',', wp_get_current_user()->roles); ?></p>
<p style="text-align:center;font-size:11px;color:#777;margin-top:10px;">© Sincotechs – All rights reserved.</p>
</div>