#sincotechs-form-builder {
    margin-top: 10px;
}

#sincotechs-fields-list {
    list-style: none;
    margin: 10px 0;
    padding: 0;
}

.sincotechs-field-item {
    background: #fff;
    border: 1px solid #ddd;
    padding: 8px;
    margin-bottom: 8px;
    display: flex;
    flex-wrap: wrap;
    gap: 6px;
    align-items: center;
}

.sincotechs-drag-handle {
    cursor: move;
    font-size: 18px;
    margin-right: 6px;
}

.sincotechs-field-label,
.sincotechs-field-name,
.sincotechs-field-options {
    flex: 1 1 150px;
}

.sincotechs-field-type {
    flex: 0 0 150px;
}

.sincotechs-inline {
    flex: 0 0 120px;
}

.sincotechs-conditional-wrapper {
    display: flex;
    flex-wrap: wrap;
    gap: 4px;
    align-items: center;
    font-size: 12px;
    margin-top: 4px;
    flex: 1 1 100%;
}

.sincotechs-conditional-wrapper input {
    max-width: 150px;
}

.sincotechs-remove-field {
    margin-left: auto;
}
