.llms-button-primary, .llms-button-action {
  cursor: pointer;
  box-sizing: border-box;
  background: var(--primarybtnbg);
  color: var(--primarybtncolor);
  border-style: solid;
  border-color: currentColor;
  fill: currentColor;
  border-width: var(--primarybtnborderwidth, 0);
  border-radius: var(--primarybtnborderradius, 3px);
  padding: var(--primarybtnpadding, 13px 15px);
  font-weight: var(--btnfontweight, 700);
  font-size: var(--btnfs, var(--bodyfontsize));
  line-height: var(--btnlineheight, 1.6);
  letter-spacing: var(--btnletterspacing, var(--bodyletterspacing));
  text-transform: var(--btntexttransform, none);
}

.llms-button-primary:hover, .llms-button-action:hover {
  background: var(--primarybtnhoverbg);
  color: var(--primarybtnhovercolor);
  border-color: var(--primarybtnhovercolor);
}

.llms-button-secondary {
  cursor: pointer;
  box-sizing: border-box;
  background-color: var(--secondarybtnbg);
  color: var(--secondarybtncolor);
  border-style: solid;
  border-color: currentColor;
  fill: currentColor;
  border-width: var(--secondarybtnborderwidth, 0);
  border-radius: var(--secondarybtnborderradius, 3px);
  padding: var(--secondarybtnpadding, 7px 12px);
  font-weight: var(--btnfontweight, 700);
  font-size: var(--btnfs, var(--bodyfontsize));
  line-height: var(--btnlineheight, 1.6);
  letter-spacing: var(--btnletterspacing);
  text-transform: var(--btntexttransform, none);
}

.llms-button-secondary:hover {
  background-color: var(--secondarybtnhoverbg);
  color: var(--secondarybtnhovercolor);
  border-color: var(--secondarybtnhovercolor);
}

.single-course .review_box input:read-write, .single-course .review_box textarea {
  border-style: solid;
  border-color: var(--formfieldbordercolor);
  border-width: var(--formfieldborderwidth);
  border-radius: var(--formfieldborderradius, 3px);
  background: var(--formfieldbgcolor);
  color: var(--formfieldcolor);
  padding: var(--formfieldpadding);
  text-transform: var(--formfieldtexttransform);
  font-weight: var(--formfieldfontweight);
  font-family: var(--bodyfontfamily);
  font-size: var(--formfieldfontsize);
  letter-spacing: var(--formfieldletterspacing);
  line-height: var(--formfieldlineheight);
}

.llms-loop-list {
  padding: 0 !important;
}

.llms-sd-section-footer {
  margin-bottom: 25px;
}

.llms-pagination {
  margin: 10px auto;
}
.llms-pagination ul {
  list-style-type: none;
  padding: 0;
}
.llms-pagination ul li .page-numbers {
  text-decoration: none;
  display: inline-block;
  padding: 12px 15px;
}

.llms-button-primary, .llms-button-action {
  display: inline-block;
}
.llms-button-secondary {
  display: inline-block;
}
.llms-loop-item-footer .avatar, .llms-loop-item-footer .llms-author-info {
  vertical-align: middle;
}

.llms-choice > label {
  width: 100%;
}

.single-course .review_box {
  background-color: var(--nv-light-bg);
  padding: 40px;
}
.single-course .review_box input:read-write, .single-course .review_box textarea {
  max-width: 100%;
  width: 100%;
  display: block;
}
.single-course .review_box textarea {
  height: 200px;
}
.single-course .llms-lesson-counter {
  display: inline-block;
  margin-bottom: 0;
}

.llms-course-nav .llms-lesson-preview {
  width: 100%;
}

.llms-loop-item-content {
  background: var(--nv-light-bg);
}
.llms-loop-item-content:hover {
  background: var(--nv-light-bg);
}
.llms-loop-item-content .llms-loop-link, .llms-loop-item-content .llms-meta, .llms-loop-item-content .llms-author {
  color: var(--nv-text-color) !important;
}

.llms-lesson-preview .llms-lesson-link {
  background: var(--nv-light-bg);
  color: var(--nv-text-color) !important;
}
.llms-lesson-preview .llms-lesson-link:hover {
  background: var(--nv-light-bg);
  color: var(--nv-text-color);
}

.llms-table tbody tr:nth-child(odd) td, .llms-table tbody tr:nth-child(odd) th {
  background: var(--nv-light-bg);
}
.llms-table tfoot tr {
  background: var(--nv-light-bg);
}

.orders-table tbody tr:nth-child(even) td,
.llms-student-dashboard .orders-table tbody tr:nth-child(even) th {
  background: var(--nv-light-bg) !important;
}

.llms-notification {
  background: var(--nv-light-bg) !important;
}
.llms-notification .llms-notification-body .llms-mini-cert {
  background: var(--nv-light-bg) !important;
}

.llms-form-field .select2-container .select2-selection--single {
  background: var(--formfieldbgcolor);
  border-style: solid;
  border-color: var(--formfieldbordercolor);
  border-width: var(--formfieldborderwidth);
}

.lifterlms .select2-container--default .select2-selection--single .select2-selection__rendered,
.llms-sd-notification-center .llms-notification .llms-notification-date {
  color: var(--nv-text-color);
}

.llms-checkout {
  background: none;
}

#llms-voucher-code {
  display: block;
}

.llms-instructor-info .llms-instructors .llms-author,
.llms-quiz-ui,
.llms-achievement, .llms-certificate,
.llms-access-plan .llms-access-plan-footer, .llms-access-plan .llms-access-plan-content,
.select2-search--dropdown, .select2-results,
.llms-sd-widgets .llms-sd-widget {
  background: var(--nv-light-bg);
}

td .llms-progress .llms-progress-bar {
  background-color: var(--nv-light-bg);
  border: 1px solid;
}

.llms-progress .progress-bar-complete {
  background-color: var(--llmsprimarycolor, var(--nv-primary-accent));
}

.llms-donut {
  color: var(--llmsprimarycolor, var(--nv-primary-accent));
}
.llms-donut svg path {
  stroke: var(--llmsprimarycolor, var(--nv-primary-accent));
}

.llms-certificate-container {
  color: #000;
}

/*# sourceMappingURL=lifter.css.map */