.wp-block-button.is-style-button-outline-hover > a {
  background: transparent !important;
}

/* ================= > Button Hover < ================= */

.wp-block-button.is-style-button-outline-hover > a:hover {
  background: #fff !important;
  color: #333 !important;
}

.wp-block-button.is-style-button-hover-opacity > a:hover {
  opacity: 0.8 !important;
}