.ti-order-sortable li {
	display: -ms-flexbox;
	display: -webkit-box;
	display: -webkit-flex;
	display: flex;
	position: relative;
	border: 1px dashed #ccc;
	opacity: 0.7;
	background: #fff;
	text-align: center;

	-webkit-align-items: center;
	align-items: center;
	-webkit-box-align: center;
	-webkit-box-pack: center;
	-ms-flex-align: center;
	-ms-flex-pack: center;
	-webkit-justify-content: center;
	justify-content: center;
	z-index: 1;
}

.ti-order-sortable li.enabled {
	border: 1px solid #666;
	opacity: 1;
}

.ti-order-sortable li p {
	width: 100%;
	margin: 0;
	padding: 7px 10px;
}

.ti-order-sortable li > * {
	display: inline;
}

.ti-order-sortable span {
	position: absolute;
	z-index: 100;
	left: 0;
	padding: 5px 10px;
	cursor: pointer;
	-webkit-transition: 0.3s ease-in-out;
	transition: 0.3s ease-in-out;
}

.ti-order-sortable > li {
	left: inherit !important;
	cursor: move;
}

.ti-order-sortable > li:hover {
	border-color: #0087bf;
	cursor: move;
}

.ti-order-sortable > li:hover > p {
	color: #0087bf;
}

.ti-order-sortable .ui-sortable-helper {
	box-shadow: 0 2px 5px rgba(0, 0, 0, 0.3);
}

.ti-order-sortable span.drag {
	right: 0;
	left: auto;
	cursor: move;
}

.ti-order-sortable li .toggle-display:before {
	position: relative;
	top: 2px;
	font-family: Dashicons;
	font-size: 20px;
	content: "\f530";
}

.ti-order-sortable li .toggle-display:hover {
	color: #fff;
	background: #3ec8ff;
}

.ti-order-sortable li.enabled .toggle-display:before {
	content: "\f177";
}
