"use strict";(self.webpackChunkneve=self.webpackChunkneve||[]).push([[403],{403:(e,t,n)=>{n.r(t),n.d(t,{default:()=>l});var c=n(307),o=n(609),s=n(736),a=n(697),i=n.n(a);const r=({onIconChoice:e,setVisible:t,icons:n})=>{const[a,i]=(0,c.useState)(""),r=(l=(()=>{const e={};for(const[t,c]of Object.entries(n))t.indexOf(a)>-1&&(e[t]=c);return e})(),Object.entries(l).map((([n,s])=>(0,c.createElement)(o.Tooltip,{className:"tooltip",text:n,key:n},(0,c.createElement)(o.Button,{className:"icon-button",onClick:()=>{e(n),t(!1),i("")}},s)))));var l;return(0,c.createElement)("div",{className:"icons-popover-content"},(0,c.createElement)(o.TextControl,{placeholder:(0,s.__)("Search","neve"),value:a,type:"search",onChange:i,className:"icons-popover-header"}),(0,c.createElement)("div",{className:"icons-container"},r))};r.propTypes={onIconChoice:i().func.isRequired,setVisible:i().func.isRequired,icons:i().object.isRequired};const l=r}}]);