.wc-block-components-product-button .wp-block-button__link.add_to_cart_button,
.wc-block-grid__product-add-to-cart.wp-block-button .wp-block-button__link {
  cursor: pointer;
  box-sizing: border-box;
  border-color: currentColor;
  text-align: center;
  font-family: var(--bodyfontfamily), var(--nv-fallback-ff);
}

.wc-block-components-product-button .wp-block-button__link.add_to_cart_button,
.wc-block-grid__product-add-to-cart.wp-block-button .wp-block-button__link, .woocommerce #respond input#submit.alt.disabled,
.woocommerce #respond input#submit.alt:disabled,
.woocommerce #respond input#submit.alt:disabled[disabled],
.woocommerce a.button.alt.disabled,
.woocommerce a.button.alt:disabled,
.woocommerce a.button.alt:disabled[disabled],
.woocommerce button.button.alt.disabled,
.woocommerce button.button.alt:disabled,
.woocommerce button.button.alt:disabled[disabled],
.woocommerce input.button.alt.disabled,
.woocommerce input.button.alt:disabled,
.woocommerce input.button.alt:disabled[disabled], #review_form #respond input#submit,
.woocommerce #respond input#submit.disabled,
.woocommerce #respond input#submit:disabled,
.woocommerce #respond input#submit:disabled[disabled],
.woocommerce a.button,
.woocommerce a.button.disabled,
.woocommerce a.button:disabled,
.woocommerce a.button:disabled[disabled],
.woocommerce button.button,
.woocommerce button.button.disabled,
.woocommerce button.button:disabled,
.woocommerce button.button:disabled[disabled],
.woocommerce input.button.disabled,
.woocommerce input.button:disabled,
.woocommerce input.button:disabled[disabled],
#add_payment_method .wc-proceed-to-checkout a.checkout-button,
.woocommerce-cart .wc-proceed-to-checkout a.checkout-button,
.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button,
.woocommerce #respond input#submit.alt,
.woocommerce a.button.alt,
.woocommerce button.button.alt,
.woocommerce input.button.alt {
  cursor: pointer;
  box-sizing: border-box;
  background: var(--primarybtnbg);
  color: var(--primarybtncolor);
  border-style: solid;
  border-color: currentColor;
  fill: currentColor;
  border-width: var(--primarybtnborderwidth, 0);
  border-radius: var(--primarybtnborderradius, 3px);
  padding: var(--primarybtnpadding, 13px 15px);
  font-weight: var(--btnfontweight, 700);
  font-size: var(--btnfs, var(--bodyfontsize));
  line-height: var(--btnlineheight, 1.6);
  letter-spacing: var(--btnletterspacing, var(--bodyletterspacing));
  text-transform: var(--btntexttransform, none);
}

.wc-block-components-product-button .wp-block-button__link.add_to_cart_button:hover,
.wc-block-grid__product-add-to-cart.wp-block-button .wp-block-button__link:hover, .woocommerce #respond input#submit.alt.disabled:hover,
.woocommerce #respond input#submit.alt:disabled:hover,
.woocommerce #respond input#submit.alt:disabled[disabled]:hover,
.woocommerce a.button.alt.disabled:hover,
.woocommerce a.button.alt:disabled:hover,
.woocommerce a.button.alt:disabled[disabled]:hover,
.woocommerce button.button.alt.disabled:hover,
.woocommerce button.button.alt:disabled:hover,
.woocommerce button.button.alt:disabled[disabled]:hover,
.woocommerce input.button.alt.disabled:hover,
.woocommerce input.button.alt:disabled:hover,
.woocommerce input.button.alt:disabled[disabled]:hover, #review_form #respond input#submit:hover,
.woocommerce #respond input#submit.disabled:hover,
.woocommerce #respond input#submit:disabled:hover,
.woocommerce #respond input#submit:disabled[disabled]:hover,
.woocommerce a.button:hover,
.woocommerce a.button.disabled:hover,
.woocommerce a.button:disabled:hover,
.woocommerce a.button:disabled[disabled]:hover,
.woocommerce button.button:hover,
.woocommerce button.button.disabled:hover,
.woocommerce button.button:disabled:hover,
.woocommerce button.button:disabled[disabled]:hover,
.woocommerce input.button.disabled:hover,
.woocommerce input.button:disabled:hover,
.woocommerce input.button:disabled[disabled]:hover,
#add_payment_method .wc-proceed-to-checkout a.checkout-button:hover,
.woocommerce-cart .wc-proceed-to-checkout a.checkout-button:hover,
.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button:hover,
.woocommerce #respond input#submit.alt:hover,
.woocommerce a.button.alt:hover,
.woocommerce button.button.alt:hover,
.woocommerce input.button.alt:hover {
  background: var(--primarybtnhoverbg);
  color: var(--primarybtnhovercolor);
  border-color: var(--primarybtnhovercolor);
}

.woocommerce-info > a,
.woocommerce-error > a,
.woocommerce-message > a {
  cursor: pointer;
  box-sizing: border-box;
  border-style: solid;
  border-color: currentColor;
  border-width: var(--primarybtnborderwidth, 0);
  border-radius: var(--primarybtnborderradius, 3px);
  padding: var(--primarybtnpadding, 13px 15px);
  font-weight: var(--btnfontweight, 700);
  font-size: var(--btnfs, var(--bodyfontsize));
  line-height: var(--btnlineheight, 1.6);
  letter-spacing: var(--btnletterspacing, var(--bodyletterspacing));
  text-transform: var(--btntexttransform, none);
}

.sidebar-header .nv-sidebar-toggle, .button.button-secondary.more-details,
.woocommerce .price_slider_amount button.button,
a.added_to_cart,
.checkout_coupon button.button,
.woocommerce table.cart td.actions .input-text#coupon_code + .button,
.woocommerce-mini-cart__buttons.buttons a.button.wc-forward:not(.checkout) {
  cursor: pointer;
  box-sizing: border-box;
  background-color: var(--secondarybtnbg);
  color: var(--secondarybtncolor);
  border-style: solid;
  border-color: currentColor;
  fill: currentColor;
  border-width: var(--secondarybtnborderwidth, 0);
  border-radius: var(--secondarybtnborderradius, 3px);
  padding: var(--secondarybtnpadding, 7px 12px);
  font-weight: var(--btnfontweight, 700);
  font-size: var(--btnfs, var(--bodyfontsize));
  line-height: var(--btnlineheight, 1.6);
  letter-spacing: var(--btnletterspacing);
  text-transform: var(--btntexttransform, none);
}

.button.button-secondary.more-details:hover,
.woocommerce .price_slider_amount button.button:hover,
a.added_to_cart:hover,
.checkout_coupon button.button:hover,
.woocommerce table.cart td.actions .input-text#coupon_code + .button:hover,
.woocommerce-mini-cart__buttons.buttons a.button.wc-forward:not(.checkout):hover {
  background-color: var(--secondarybtnhoverbg);
  color: var(--secondarybtnhovercolor);
  border-color: var(--secondarybtnhovercolor);
}

.woocommerce-cart table.cart td.actions .coupon .input-text,
.woocommerce-page .select2-container--default .select2-selection--single,
.woocommerce-page .woocommerce form .form-row input.input-text,
.woocommerce-page .woocommerce form .form-row textarea,
.wc-block-product-search form input.wc-block-product-search__field {
  border-style: solid;
  border-color: var(--formfieldbordercolor);
  border-width: var(--formfieldborderwidth);
  border-radius: var(--formfieldborderradius, 3px);
  background: var(--formfieldbgcolor);
  color: var(--formfieldcolor);
  padding: var(--formfieldpadding);
  text-transform: var(--formfieldtexttransform);
  font-weight: var(--formfieldfontweight);
  font-family: var(--bodyfontfamily);
  font-size: var(--formfieldfontsize);
  letter-spacing: var(--formfieldletterspacing);
  line-height: var(--formfieldlineheight);
}

.woocommerce-checkout label {
  font-weight: var(--formlabelfontweight, var(--bodyfontweight));
  text-transform: var(--formlabeltexttransform);
  letter-spacing: var(--formlabelletterspacing);
  line-height: var(--formlabellineheight);
  font-size: var(--formlabelfontsize, var(--bodyfontsize));
}

main .nv-shop {
  margin-top: 60px;
}

.woocommerce span.onsale {
  background-color: var(--nv-c-1);
  border-radius: 0;
  line-height: inherit;
  min-height: auto;
  right: 0;
  top: 0;
  font-weight: 500;
}
.woocommerce ul.products li.product .onsale {
  top: 0;
  right: 0;
  left: auto;
  margin: 0;
}

.woocommerce nav.woocommerce-pagination ul {
  display: flex;
  border: 0;
  margin: 0;
}
.woocommerce nav.woocommerce-pagination ul li {
  margin-left: 20px;
  border: 0;
}
.woocommerce nav.woocommerce-pagination ul li a,
.woocommerce nav.woocommerce-pagination ul li span {
  background: var(--nv-light-bg);
  border-radius: 3px;
  padding: 12px 15px;
  color: var(--nv-text-color);
}
.woocommerce nav.woocommerce-pagination ul li .dots {
  background: 100%;
}
.woocommerce nav.woocommerce-pagination ul li a:focus,
.woocommerce nav.woocommerce-pagination ul li a:hover {
  background: var(--nv-light-bg);
  color: var(--nv-text-color);
}
.woocommerce nav.woocommerce-pagination ul li span.current {
  background: var(--nv-primary-accent);
  color: var(--nv-text-dark-bg);
}

/* stylelint-disable */
.woocommerce .star-rating {
  color: #ffb100;
}

.nv-content-wrap ul.wc-block-grid__products {
  list-style-type: none;
  padding-right: 0;
}

.woocommerce .blockOverlay {
  background-color: var(--nv-site-bg) !important;
}

.woocommerce form .form-row textarea:focus {
  box-shadow: 0 0 3px 0 var(--nv-secondary-accent);
}

.woocommerce-cart .nv-single-page-wrap, .woocommerce-checkout .nv-single-page-wrap, .woocommerce-account .nv-single-page-wrap {
  margin-bottom: 60px;
}

.woocommerce form .form-row {
  margin-bottom: 20px;
}

.woocommerce-NoticeGroup > ul,
.woocommerce-notices-wrapper > ul {
  flex-direction: column;
  align-items: flex-start;
}

.woocommerce-info,
.woocommerce-error,
.woocommerce-message {
  display: flex;
  align-items: start;
  flex-direction: column;
  text-align: start;
  padding: 15px 45px 15px 15px;
  --btnfs: $text-sm;
  --primarybtnpadding: 10px 15px;
  --primarybtnborderwidth: 3px;
  --primarybtncolor: #fff;
  --primarybtnhovercolor: #fff;
  --primarybtnhoverbg: transparent;
  --primarybtnbg: transparent;
}
.woocommerce-info a,
.woocommerce-info .button,
.woocommerce-error a,
.woocommerce-error .button,
.woocommerce-message a,
.woocommerce-message .button {
  width: 100%;
  margin-top: 15px;
  white-space: normal;
  margin-right: auto;
  text-align: center;
}

.woocommerce .woocommerce-message,
.woocommerce-page .woocommerce-message {
  border-radius: 3px;
  background: var(--nv-c-1);
  border: 0;
  color: #fff;
}
.woocommerce .woocommerce-message a, .woocommerce .woocommerce-message::before,
.woocommerce-page .woocommerce-message a,
.woocommerce-page .woocommerce-message::before {
  color: inherit;
}

.woocommerce .woocommerce-error,
.woocommerce-page .woocommerce-error {
  border-radius: 3px;
  background: var(--nv-c-2);
  border: 0;
  color: #fff;
}
.woocommerce .woocommerce-error a, .woocommerce .woocommerce-error::before,
.woocommerce-page .woocommerce-error a,
.woocommerce-page .woocommerce-error::before {
  color: inherit;
}

.woocommerce .woocommerce-info,
.woocommerce-page .woocommerce-info {
  border-radius: 3px;
  background: var(--nv-primary-accent);
  border: 0;
  color: #fff;
}
.woocommerce .woocommerce-info a, .woocommerce .woocommerce-info::before,
.woocommerce-page .woocommerce-info a,
.woocommerce-page .woocommerce-info::before {
  color: inherit;
}

.neve-main .wc-block-components-notice-banner {
  --btnfs: $text-sm;
  --primarybtnpadding: 10px 15px;
  --primarybtnborderwidth: 3px;
  --primarybtncolor: #fff;
  --primarybtnhovercolor: #fff;
  --primarybtnhoverbg: transparent;
  --primarybtnbg: transparent;
}
.neve-main .wc-block-components-notice-banner .wc-block-components-notice-banner__content:has(.wc-forward, .showcoupon) {
  display: inline-flex;
  flex-basis: 100%;
  flex-wrap: nowrap;
  justify-content: space-between;
  align-items: center;
}
.neve-main .wc-block-components-notice-banner .wc-block-components-notice-banner__content:has(.wc-forward) {
  flex-direction: row-reverse;
}
.neve-main .wc-block-components-notice-banner .wc-block-components-notice-banner__content:has(.showcoupon) {
  flex-direction: row;
}

.neve-main .wc-block-components-notice-banner.is-success {
  border-radius: 3px;
  background-color: var(--nv-c-1);
  border: 0;
  color: #fff;
  font-size: inherit;
  line-height: inherit;
  align-items: center;
}
.neve-main .wc-block-components-notice-banner.is-success svg {
  background-color: #fff;
  fill: var(--nv-c-1);
}
.neve-main .wc-block-components-notice-banner.is-success a:is(.wc-forward, .showcoupon) {
  background: var(--primarybtnbg) !important;
  border: var(--primarybtnborderwidth, 0) solid currentColor !important;
  border-radius: var(--primarybtnborderradius, 3px);
  color: var(--primarybtncolor) !important;
  padding: var(--primarybtnpadding, 13px 15px) !important;
  text-decoration: none !important;
  opacity: 1;
  float: none;
}
.neve-main .wc-block-components-notice-banner.is-success a:is(.wc-forward, .showcoupon):hover {
  background: var(--primarybtnhoverbg) !important;
  color: var(--primarybtnhovercolor) !important;
  border-color: var(--primarybtnhovercolor) !important;
  opacity: 0.9;
}

.neve-main .wc-block-components-notice-banner.is-error {
  border-radius: 3px;
  background-color: var(--nv-c-2);
  border: 0;
  color: #fff;
  font-size: inherit;
  line-height: inherit;
  align-items: center;
}
.neve-main .wc-block-components-notice-banner.is-error svg {
  background-color: #fff;
  fill: var(--nv-c-2);
}
.neve-main .wc-block-components-notice-banner.is-error a:is(.wc-forward, .showcoupon) {
  background: var(--primarybtnbg) !important;
  border: var(--primarybtnborderwidth, 0) solid currentColor !important;
  border-radius: var(--primarybtnborderradius, 3px);
  color: var(--primarybtncolor) !important;
  padding: var(--primarybtnpadding, 13px 15px) !important;
  text-decoration: none !important;
  opacity: 1;
  float: none;
}
.neve-main .wc-block-components-notice-banner.is-error a:is(.wc-forward, .showcoupon):hover {
  background: var(--primarybtnhoverbg) !important;
  color: var(--primarybtnhovercolor) !important;
  border-color: var(--primarybtnhovercolor) !important;
  opacity: 0.9;
}

.neve-main .wc-block-components-notice-banner.is-info {
  border-radius: 3px;
  background-color: var(--nv-primary-accent);
  border: 0;
  color: #fff;
  font-size: inherit;
  line-height: inherit;
  align-items: center;
}
.neve-main .wc-block-components-notice-banner.is-info svg {
  background-color: #fff;
  fill: var(--nv-primary-accent);
}
.neve-main .wc-block-components-notice-banner.is-info a:is(.wc-forward, .showcoupon) {
  background: var(--primarybtnbg) !important;
  border: var(--primarybtnborderwidth, 0) solid currentColor !important;
  border-radius: var(--primarybtnborderradius, 3px);
  color: var(--primarybtncolor) !important;
  padding: var(--primarybtnpadding, 13px 15px) !important;
  text-decoration: none !important;
  opacity: 1;
  float: none;
}
.neve-main .wc-block-components-notice-banner.is-info a:is(.wc-forward, .showcoupon):hover {
  background: var(--primarybtnhoverbg) !important;
  color: var(--primarybtnhovercolor) !important;
  border-color: var(--primarybtnhovercolor) !important;
  opacity: 0.9;
}

.woocommerce .woocommerce-error li {
  width: 100%;
  margin: 0;
}

.nv-woo-filters {
  display: flex;
  align-items: center;
  margin-bottom: 40px;
}
.nv-woo-filters .woocommerce-ordering {
  margin: 0;
}
.nv-woo-filters .nv-sidebar-toggle + .woocommerce-ordering select {
  max-width: 155px;
  margin-bottom: 0;
}

.woocommerce ul.products li.product {
  margin-bottom: 40px;
}
.woocommerce ul.products li.product a.woocommerce-loop-product__link > h2,
.woocommerce ul.products li.product a.woocommerce-loop-product__link > h3 {
  padding-top: 0;
  color: var(--nv-text-color);
  font-size: 1.25em;
}

.img-wrap {
  position: relative;
}
.img-wrap .out-of-stock-badge {
  color: var(--nv-text-color);
  font-weight: var(--h4fontweight);
  text-transform: uppercase;
  position: absolute;
  top: 50%;
  transform: translateY(-50%);
  right: 0;
  left: 0;
  padding: 15px 0;
  background: var(--nv-light-bg);
  text-align: center;
  opacity: 0.9;
  z-index: 1;
}

.ajax_add_to_cart.added,
.single_add_to_cart_button.added {
  display: none !important;
}

.woocommerce a.added_to_cart {
  display: flex;
  align-items: center;
  justify-content: center;
  width: auto;
  padding: var(--secondarybtnpadding);
}
.woocommerce li a.added_to_cart {
  display: inline-block;
  margin-top: 1em;
}

.button.button-secondary.more-details,
.woocommerce .price_slider_amount button.button,
a.added_to_cart,
.checkout_coupon button.button,
.woocommerce table.cart td.actions .input-text#coupon_code + .button,
.woocommerce-mini-cart__buttons.buttons a.button.wc-forward:not(.checkout) {
  box-shadow: var(--secondarybtnshadow, none);
}
.button.button-secondary.more-details:hover,
.woocommerce .price_slider_amount button.button:hover,
a.added_to_cart:hover,
.checkout_coupon button.button:hover,
.woocommerce table.cart td.actions .input-text#coupon_code + .button:hover,
.woocommerce-mini-cart__buttons.buttons a.button.wc-forward:not(.checkout):hover {
  box-shadow: var(--secondarybtnhovershadow, none);
}

.woocommerce ul.products li.product .button {
  white-space: normal;
}

/* stylelint-disable */
.woocommerce .button.loading {
  justify-content: center;
  display: inline-flex !important;
  padding-left: 15px !important;
}
.woocommerce .button.loading::after {
  margin-right: 5px;
  position: unset !important;
}

#review_form #respond input#submit,
.woocommerce #respond input#submit.disabled,
.woocommerce #respond input#submit:disabled,
.woocommerce #respond input#submit:disabled[disabled],
.woocommerce a.button,
.woocommerce a.button.disabled,
.woocommerce a.button:disabled,
.woocommerce a.button:disabled[disabled],
.woocommerce button.button,
.woocommerce button.button.disabled,
.woocommerce button.button:disabled,
.woocommerce button.button:disabled[disabled],
.woocommerce input.button.disabled,
.woocommerce input.button:disabled,
.woocommerce input.button:disabled[disabled],
#add_payment_method .wc-proceed-to-checkout a.checkout-button,
.woocommerce-cart .wc-proceed-to-checkout a.checkout-button,
.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button,
.woocommerce #respond input#submit.alt,
.woocommerce a.button.alt,
.woocommerce button.button.alt,
.woocommerce input.button.alt {
  box-shadow: var(--primarybtnshadow, none);
}
#review_form #respond input#submit:hover,
.woocommerce #respond input#submit.disabled:hover,
.woocommerce #respond input#submit:disabled:hover,
.woocommerce #respond input#submit:disabled[disabled]:hover,
.woocommerce a.button:hover,
.woocommerce a.button.disabled:hover,
.woocommerce a.button:disabled:hover,
.woocommerce a.button:disabled[disabled]:hover,
.woocommerce button.button:hover,
.woocommerce button.button.disabled:hover,
.woocommerce button.button:disabled:hover,
.woocommerce button.button:disabled[disabled]:hover,
.woocommerce input.button.disabled:hover,
.woocommerce input.button:disabled:hover,
.woocommerce input.button:disabled[disabled]:hover,
#add_payment_method .wc-proceed-to-checkout a.checkout-button:hover,
.woocommerce-cart .wc-proceed-to-checkout a.checkout-button:hover,
.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button:hover,
.woocommerce #respond input#submit.alt:hover,
.woocommerce a.button.alt:hover,
.woocommerce button.button.alt:hover,
.woocommerce input.button.alt:hover {
  box-shadow: var(--primarybtnhovershadow, none);
}

.woocommerce #respond input#submit.alt.disabled,
.woocommerce #respond input#submit.alt:disabled,
.woocommerce #respond input#submit.alt:disabled[disabled],
.woocommerce a.button.alt.disabled,
.woocommerce a.button.alt:disabled,
.woocommerce a.button.alt:disabled[disabled],
.woocommerce button.button.alt.disabled,
.woocommerce button.button.alt:disabled,
.woocommerce button.button.alt:disabled[disabled],
.woocommerce input.button.alt.disabled,
.woocommerce input.button.alt:disabled,
.woocommerce input.button.alt:disabled[disabled] {
  box-shadow: var(--primarybtnshadow, none);
}
.woocommerce #respond input#submit.alt.disabled:hover,
.woocommerce #respond input#submit.alt:disabled:hover,
.woocommerce #respond input#submit.alt:disabled[disabled]:hover,
.woocommerce a.button.alt.disabled:hover,
.woocommerce a.button.alt:disabled:hover,
.woocommerce a.button.alt:disabled[disabled]:hover,
.woocommerce button.button.alt.disabled:hover,
.woocommerce button.button.alt:disabled:hover,
.woocommerce button.button.alt:disabled[disabled]:hover,
.woocommerce input.button.alt.disabled:hover,
.woocommerce input.button.alt:disabled:hover,
.woocommerce input.button.alt:disabled[disabled]:hover {
  box-shadow: var(--primarybtnhovershadow, none);
}

.woocommerce-review-link {
  color: var(--nv-text-color);
  font-size: 0.9em;
}

.woocommerce-Tabs-panel h2 {
  font-size: var(--h2fontsize);
}

.woocommerce #reviews {
  display: grid;
  grid-row-gap: 40px;
}
.woocommerce #reviews .comment-form-cookies-consent {
  margin-bottom: 20px !important;
}
.woocommerce #reviews .comment-form-cookies-consent input {
  display: inline;
}
.woocommerce #reviews .comment-form-cookies-consent label {
  display: inline;
  margin: 0;
}
.woocommerce #reviews input[type=text],
.woocommerce #reviews input[type=email] {
  width: 100%;
}
.woocommerce .stars {
  margin-right: 40px !important;
}
.woocommerce .stars a {
  color: #ffb100;
}
.woocommerce .comment-form-rating {
  display: flex;
  align-items: center;
}
.woocommerce #reply-title {
  font-size: var(--h4fontsize);
  font-weight: var(--h2fontweight);
  line-height: var(--h2lineheight);
  letter-spacing: var(--h2letterspacing);
  text-transform: var(--h2texttransform);
  color: var(--headingcolor, inherit);
  margin-bottom: 30px;
  display: block;
}

.woocommerce #reviews #comments ol.commentlist li {
  margin-bottom: 40px;
}
.woocommerce #reviews #comments ol.commentlist li:last-child {
  margin-bottom: 0;
}
.woocommerce #reviews #comments ol.commentlist li .comment-text {
  padding: 0;
  border: 0;
}
.woocommerce #reviews #comments ol.commentlist li img.avatar {
  padding: 0;
  border: 0;
}
.woocommerce #reviews #comments ol.commentlist li .meta {
  color: var(--nv-text-color);
  font-size: 0.9em !important;
}

section.exclusive .nv-card-content-wrapper {
  position: relative;
  width: 100%;
}
section.exclusive .dots-nav {
  display: flex;
  align-items: center;
  justify-content: center;
  width: 100%;
}
section.exclusive .dots-nav .dot {
  background: 100%;
  border: 1px solid #b7b7b7;
  margin: 5px;
  width: 8px;
  height: 8px;
  padding: 0;
  border-radius: 100%;
}
section.exclusive .dots-nav .dot.tns-nav-active {
  background: #404248;
  border-color: #404248;
}
section.exclusive .tns-outer {
  direction: ltr;
  overflow: hidden;
  position: relative;
}
section.exclusive .tns-ovh {
  padding-left: 4px;
  overflow: unset;
  margin-bottom: 15px;
}
section.exclusive .tns-visually-hidden {
  display: none;
}
section.exclusive ul.products.exclusive-products {
  --shopcoltemplate: 4;
  margin: 0;
}
section.exclusive ul.tns-slider li.product,
section.exclusive ul:not(.tns-slider) li:nth-child(4) {
  margin: 0;
  clear: none;
}
section.exclusive ul:not(.tns-slider) li:nth-child(n+5) {
  display: none;
}

.nv-single-product-top {
  display: flex;
  flex-direction: column;
  position: relative;
}

.woocommerce.single .nv-woo-filters {
  display: none;
}

.woocommerce .cart .added_to_cart,
.woocommerce .cart .button,
.woocommerce .cart button {
  flex-grow: 1;
  display: flex;
  justify-content: center;
  align-items: center;
}

.woocommerce.single .entry-summary ul,
.woocommerce.single #tab-description ul {
  list-style-type: circle;
}
.woocommerce.single .entry-summary ul,
.woocommerce.single .entry-summary ol,
.woocommerce.single #tab-description ul,
.woocommerce.single #tab-description ol {
  padding-right: 15px;
  margin-bottom: 15px;
}
.woocommerce.single .entry-summary ul li,
.woocommerce.single .entry-summary ol li,
.woocommerce.single #tab-description ul li,
.woocommerce.single #tab-description ol li {
  margin-bottom: 10px;
}
.woocommerce.single .woocommerce-variation-add-to-cart {
  display: flex;
  flex-wrap: wrap;
}
.woocommerce.single .quantity input {
  box-sizing: border-box;
  line-height: normal;
  height: 100%;
  padding-left: 0;
}
.woocommerce.single .entry-summary > form.cart {
  display: flex;
  flex-wrap: wrap;
  border-bottom: 2px solid var(--nv-text-color);
  margin-bottom: 30px;
  padding-bottom: 20px;
}
.woocommerce.single .entry-summary > form.cart .single_variation_wrap {
  width: 100%;
}
.woocommerce.single .entry-summary > form.cart .wc-forward {
  margin-right: 4px;
  flex-basis: 50%;
}
.woocommerce.single .entry-summary > form.cart.grouped_form {
  flex-wrap: wrap;
}
.woocommerce.single .entry-summary > form.cart .group_table td {
  vertical-align: middle;
}
.woocommerce.single .entry-summary > form.cart .group_table td label {
  margin: 0;
}
.woocommerce.single .group_table {
  margin-bottom: 20px;
}
.woocommerce.single .wc-pao-addons-container {
  width: 100%;
}

.woocommerce table.shop_attributes {
  border: 0;
}
.woocommerce table.shop_attributes th,
.woocommerce table.shop_attributes td {
  border-bottom: 2px solid var(--nv-text-color);
  font-style: normal;
  font-size: 0.9em;
  padding: 20px;
  background: 100% !important;
}

.product_meta {
  font-size: 0.9em;
}
.product_meta a {
  color: var(--nv-text-color);
}
.product_meta > span {
  font-size: 0.9em;
  margin-top: 20px;
  display: block;
}

.woocommerce ul.products li.product .price ins,
.woocommerce ul.products li.product .price,
.woocommerce div.product p.price bdi,
.woocommerce div.product span.price,
.woocommerce div.product p.price,
.woocommerce li.product ins {
  color: var(--nv-text-color);
}
.woocommerce ul.products li.product .price {
  font-size: var(--bodyfontsize);
}

.woocommerce-variation-price {
  margin-bottom: 20px;
}

/* stylelint-disable */
.woocommerce div.product form.cart .variations td, .woocommerce div.product form.cart .variations th {
  padding: 0;
}
.woocommerce div.product form.cart .variations tr {
  margin-bottom: 15px;
  display: grid;
}
.woocommerce .reset_variations {
  display: block;
}

.variations select {
  width: 100%;
  height: auto;
}

.woocommerce-tabs {
  width: 100%;
  margin: 40px 0 40px;
}

.woocommerce div.product .woocommerce-tabs ul.tabs li {
  background: transparent;
  border: 0;
  margin: 0 0 0 40px;
  padding: 0;
}
.woocommerce div.product .woocommerce-tabs ul.tabs li::before, .woocommerce div.product .woocommerce-tabs ul.tabs li::after {
  content: none;
}
.woocommerce div.product .woocommerce-tabs ul.tabs li.active {
  color: var(--nv-primary-accent);
  background: 100%;
  border-bottom: 3px solid;
}
.woocommerce div.product .woocommerce-tabs ul.tabs li a {
  color: var(--nv-text-color);
}

.woocommerce #content div.product .woocommerce-tabs ul.tabs {
  margin-bottom: 40px;
  padding: 0;
  border: 0;
}
.woocommerce #content div.product .woocommerce-tabs ul.tabs::before {
  content: none;
}

.woocommerce div.product div.images .flex-control-thumbs {
  margin: 5px -5px 0;
}
.woocommerce div.product div.images .flex-control-thumbs li {
  padding: 5px;
}

.woocommerce-product-gallery {
  float: none !important;
  display: inline-block;
}

.woocommerce a.remove {
  color: var(--nv-text-color) !important;
  margin: 0;
}

.woocommerce table.cart td.actions .input-text#coupon_code {
  width: 200px;
  float: none;
  flex-grow: 1;
  max-height: unset;
  margin-left: 10px;
}
.woocommerce table.cart td.actions .input-text#coupon_code + .button {
  float: none;
}
.woocommerce-cart table.cart td.actions .coupon {
  display: flex;
}

.product-thumbnail:not([class^=elementor]) img {
  min-width: 60px !important;
}

.woocommerce table.shop_table.cart {
  border: 0;
}
.woocommerce table.shop_table.cart a {
  color: var(--nv-text-color);
}
.woocommerce table.shop_table.cart tr {
  border-bottom: 2px solid var(--nv-text-color);
  padding: 20px 0;
}
.woocommerce table.shop_table.cart tr:last-child {
  border: 0;
}
.woocommerce table.shop_table.cart thead tr {
  border: 0;
}
.woocommerce table.shop_table.cart td {
  background: transparent !important;
  font-size: var(--bodyfontsize);
  padding: 10px 0;
  border: 0;
}
.woocommerce table.shop_table.cart td::before {
  vertical-align: middle;
}
.woocommerce table.shop_table.cart td.actions {
  padding: 40px 0;
}
.woocommerce table.shop_table.cart .product-remove {
  float: right;
}
.woocommerce table.shop_table.cart .product-thumbnail {
  display: block !important;
}
.woocommerce table.shop_table.cart .product-thumbnail::before {
  content: none;
}
.woocommerce table.shop_table.cart thead th {
  font-size: 1.25em;
  border: 0;
}

.product-name .variation {
  margin-top: 10px;
  font-size: 0.9em;
  opacity: 0.75;
}
.product-name .variation dt {
  font-weight: 300;
}

.woocommerce .quantity .qty {
  box-sizing: content-box;
}

.woocommerce .cart_totals {
  border: 0;
}
.woocommerce .cart_totals > h2 {
  font-size: var(--h4fontsize);
}
.woocommerce .cart_totals td,
.woocommerce .cart_totals th {
  background: 100% !important;
  padding: 20px 15px !important;
  border-bottom: 2px solid var(--nv-text-color);
}
.woocommerce .cart_totals td {
  text-align: left;
}
.woocommerce .cart_totals .shipping-calculator-form {
  text-align: right;
}
.woocommerce .cart_totals th {
  text-align: right;
  font-weight: 300 !important;
}
.woocommerce .cart_totals table.shop_table {
  border: 0;
}
.woocommerce .cart_totals table.shop_table th {
  font-size: 0.9em;
}
.woocommerce .cart_totals .order-total {
  font-size: var(--bodyfontsize);
}
.woocommerce .cart_totals .order-total th {
  font-weight: 700 !important;
}
.woocommerce .cart_totals #shipping_method {
  text-align: right;
  margin-bottom: 30px;
  display: block;
}
.woocommerce .cart_totals #shipping_method li {
  display: flex;
  flex-direction: row-reverse;
}
.woocommerce .cart_totals #shipping_method li input {
  margin-right: 10px;
}
.woocommerce .cart_totals .wc-proceed-to-checkout {
  display: flex;
  justify-content: flex-end;
  --primarybtnpadding: 15px 40px;
}

.cross-sells > h2 {
  font-size: var(--h4fontsize);
}

.woocommerce-checkout .addresses .woocommerce-column {
  margin-bottom: 40px;
}
.woocommerce-checkout .addresses h2 {
  font-size: var(--h4fontsize);
}
.woocommerce-checkout .col2-set .col-1,
.woocommerce-checkout .col2-set .col-2 {
  width: 100%;
  float: none;
}
.woocommerce-checkout form.checkout {
  display: grid;
  grid-template-columns: 1fr;
}
.woocommerce-checkout .woocommerce-NoticeGroup {
  grid-column: 1;
}
.woocommerce-checkout .checkout_coupon {
  display: flex;
  flex-wrap: wrap;
}
.woocommerce-checkout .checkout_coupon p:first-child {
  width: 100%;
  margin-bottom: 15px;
}
.woocommerce-checkout .checkout_coupon button {
  width: 100%;
  height: 100%;
}
.woocommerce-checkout .checkout_coupon .form-row {
  display: flex;
  flex-grow: 1;
}
.woocommerce-checkout table.shop_table {
  border: 0;
  border-collapse: collapse;
}
.woocommerce-checkout table.shop_table bdi {
  font-weight: 400;
}
.woocommerce-checkout table.shop_table th {
  font-size: var(--h5fontsize);
  font-weight: var(--h5fontweight);
  padding: 15px;
}
.woocommerce-checkout table.shop_table td {
  padding: 15px;
  border: 0;
}
.woocommerce-checkout table.shop_table tfoot th,
.woocommerce-checkout table.shop_table tfoot td {
  border: 0;
  font-weight: var(--bodyfontweight);
  font-size: 0.9em;
}
.woocommerce-checkout table.shop_table tbody,
.woocommerce-checkout table.shop_table thead,
.woocommerce-checkout table.shop_table tfoot {
  border-bottom: 2px solid var(--nv-text-color);
}
.woocommerce-checkout table.shop_table .order-total th,
.woocommerce-checkout table.shop_table .order-total bdi {
  font-size: var(--bodyfontsize);
  font-weight: 700;
}
.woocommerce-checkout table.shop_table .product-total,
.woocommerce-checkout table.shop_table tfoot td {
  text-align: left;
}
.woocommerce-checkout table.shop_table label {
  font-size: inherit;
}
.woocommerce-checkout #payment {
  background: 100%;
}
.woocommerce-checkout #payment div.payment_box {
  background: var(--nv-light-bg);
  color: var(--nv-text-color);
  margin-top: 0;
}
.woocommerce-checkout #payment div.payment_box::before {
  content: none;
}
.woocommerce-checkout #payment fieldset {
  border: 0;
  padding: 0;
  margin: 0;
}
.woocommerce-checkout #payment fieldset .form-row {
  padding: 1em;
}
.woocommerce-checkout .payment_methods {
  border: 0 !important;
}
.woocommerce-checkout main button:not(.wc-block-components-button) {
  width: 100%;
}

.woocommerce-page .select2-container.select2-container--open {
  outline: 0;
  box-shadow: 0 0 3px 0 var(--nv-secondary-accent);
  --formfieldbordercolor: var(--nv-secondary-accent);
}
.woocommerce-page .select2-container [data-selected=true] {
  background-color: var(--nv-light-bg);
  color: var(--nv-text-color);
}
.woocommerce-page .select2-container--default .select2-selection--single {
  height: auto;
}
.woocommerce-page .select2-container--default .select2-selection--single,
.woocommerce-page .select2-results__options,
.woocommerce-page .select2-search,
.woocommerce-page .select2-search__field {
  color: var(--formfieldcolor);
  background-color: var(--formfieldbgcolor);
}
.woocommerce-page .select2-selection__rendered {
  padding: 0 !important;
  color: var(--formfieldcolor) !important;
}
.woocommerce-page .select2-selection__arrow {
  height: 100% !important;
}

.nv-pay-kco form.checkout {
  display: block;
}

.shop-sidebar {
  position: fixed;
  top: 0;
  right: 0;
  bottom: 0;
  z-index: 100000;
  height: 100vh;
  overflow: auto;
  width: 100%;
  transition: all 0.3s ease-out;
  background-color: var(--nv-site-bg);
  transform: translateX(100%);
}
.shop-sidebar.sidebar-open {
  transform: translateX(0);
}

.sidebar-header {
  display: flex;
  justify-content: flex-end;
  margin-bottom: 20px;
}
.nv-woo-filters .nv-sidebar-toggle {
  margin-left: 20px;
}

.woocommerce .widget_price_filter .price_slider_wrapper .ui-widget-content {
  background-color: #ccc;
  height: 5px;
}
.woocommerce .widget_price_filter .ui-slider .ui-slider-handle {
  background: var(--nv-primary-accent);
  border: 1px solid #fff;
  top: -5px;
}
.woocommerce .widget_price_filter .ui-slider .ui-slider-handle:hover {
  transform: scale(1.25);
}
.woocommerce .widget_price_filter .ui-slider .ui-slider-range {
  background-color: var(--nv-primary-accent);
}
.woocommerce .widget_price_filter .price_slider_amount .button {
  font-size: inherit;
  line-height: 1;
}

.woocommerce-widget-layered-nav .select2-selection--single {
  padding-left: 30px !important;
}

body .select2-dropdown {
  z-index: 100001;
}

.cart-icon-wrapper {
  display: flex;
  align-items: center;
}
.cart-icon-wrapper:hover {
  color: var(--hovercolor, var(--color));
}
.cart-icon-wrapper .nv-cart {
  display: flex;
}
.cart-icon-wrapper .nv-cart svg {
  width: var(--iconsize);
  height: var(--iconsize);
}
.cart-icon-wrapper .cart-icon-label {
  margin-left: 8px;
  font-size: var(--labelsize);
}
.cart-icon-wrapper .cart-count {
  background: var(--nv-light-bg);
  color: var(--nv-text-color);
  position: absolute;
  font-size: 0.6em;
  padding: 3px;
  bottom: -7px;
  left: -13px;
  font-weight: 800;
  line-height: 1;
  border-radius: 3px;
}

.nv-nav-cart {
  display: none;
  opacity: 0;
  visibility: hidden;
  background: var(--nv-site-bg);
  color: var(--nv-text-color);
  transition: all 0.3s;
  box-shadow: rgba(149, 157, 165, 0.2) 0 8px 24px;
  position: absolute;
  z-index: 100;
  width: 360px;
  text-align: right;
  --primarybtnpadding: 13px 15px;
  --secondarybtnpadding: 13px 15px;
}
.nv-nav-cart .widget {
  overflow: hidden;
}
.nv-nav-cart .woocommerce-mini-cart {
  margin-left: -40px !important;
  overflow-y: auto;
  overflow-x: hidden;
  max-height: 300px;
}
.nv-nav-cart li {
  padding: 20px 15px 20px 55px !important;
  border-bottom: 2px solid var(--nv-text-color);
  font-size: 0.9em;
}
.nv-nav-cart li:last-child {
  border: 0;
}
.nv-nav-cart li img {
  position: absolute;
  right: 35px;
  width: 60px !important;
  top: 50%;
  transform: translateY(-50%);
  margin-right: 10px !important;
}
.nv-nav-cart li .remove {
  top: 50% !important;
  right: 15px !important;
  transform: translateY(-50%);
}
.nv-nav-cart li .quantity {
  opacity: 0.5;
}
.nv-nav-cart li > *:not(.remove) {
  margin-right: 100px !important;
  font-weight: inherit !important;
}
.nv-nav-cart li dl {
  padding: 0 !important;
  border: 0 !important;
}
.nv-nav-cart li dl > dd {
  margin: 0 !important;
}
.nv-nav-cart li > a {
  color: var(--nv-text-color);
}
.nv-nav-cart .widget_shopping_cart_content .total {
  border: 0;
  margin: 0;
  box-shadow: 0 -3px 9px -9px;
  padding: 15px 20px;
}
.nv-nav-cart .widget_shopping_cart_content strong {
  font-weight: inherit;
  margin-left: 10px;
}
.nv-nav-cart .widget_shopping_cart_content .buttons {
  padding: 0 20px;
  margin-bottom: 20px;
}
.nv-nav-cart .widget_shopping_cart_content .buttons::before {
  content: none !important;
}
.nv-nav-cart .widget_shopping_cart_content .buttons .button {
  --btnfs: var(--bodyfontsize);
  margin: 0;
  display: flex;
  align-items: center;
  justify-content: center;
}

.woocommerce-mini-cart__buttons {
  display: grid;
  grid-template-columns: 1fr 1fr;
  grid-column-gap: 20px;
}

.menu-item-nav-cart {
  position: relative;
}
.menu-item-nav-cart .nv-nav-cart {
  left: 0;
}

body.woocommerce-account .woocommerce-form-login {
  display: grid;
  gap: 10px;
}
body.woocommerce-account .woocommerce-form-login .form-row:nth-child(3) {
  display: flex;
  flex-direction: column;
}
body.woocommerce-account .woocommerce-form-login .form-row:nth-child(3) * {
  margin-left: 0;
}
body.woocommerce-account .woocommerce-form-login [class*=rememberme] {
  margin-bottom: 10px;
}
body.woocommerce-account .woocommerce-form-login p {
  margin: 0;
}
body.woocommerce-account .woocommerce nav ul {
  border: 2px solid var(--nv-light-bg);
  border-radius: 8px;
  overflow: hidden;
  display: grid;
  list-style: none;
  padding: 0;
  margin: 0 0 40px;
}
body.woocommerce-account .woocommerce nav li {
  margin: 0;
}
body.woocommerce-account .woocommerce nav a {
  display: block;
  margin-top: -1px;
  padding: 15px 20px;
  border-bottom: 2px solid var(--nv-light-bg);
  text-decoration: none;
}
body.woocommerce-account .woocommerce nav li:last-child a {
  border-bottom: 0;
}
body.woocommerce-account .woocommerce nav .is-active {
  border-right: 5px solid var(--nv-primary-accent);
}
body.woocommerce-account .woocommerce nav .is-active a {
  color: var(--nv-primary-accent);
}
body.woocommerce-account .lost_password {
  text-align: center;
  font-size: 0.9em;
}
body.woocommerce-account h2 {
  --h2fontsize: var(--h3fontsize);
}
body.woocommerce-account .my_account_orders {
  font-size: var(--bodyfontsize);
}
body.woocommerce-account table {
  border: 0 !important;
  --primarybtnfs: 0.9em;
  --primarybtnpadding: 5px 20px;
}
body.woocommerce-account table td {
  border: 0 !important;
}
body.woocommerce-account table th,
body.woocommerce-account table td {
  padding: 10px 10px !important;
}
body.woocommerce-account table th:last-child,
body.woocommerce-account table td:last-child {
  text-align: left;
}
body.woocommerce-account table thead th {
  border-bottom: 2px solid var(--nv-text-color);
  font-size: 1.25em;
}
body.woocommerce-account table.order_details tfoot th,
body.woocommerce-account table.order_details td {
  border: 0;
}

.woocommerce .woocommerce-breadcrumb {
  color: var(--nv-text-color);
  font-size: 14px;
  white-space: nowrap;
  scrollbar-width: none; /* Firefox */
  overflow-x: scroll;
}
.woocommerce .woocommerce-breadcrumb::-webkit-scrollbar {
  display: none; /* Chrome, Safari, Opera*/
}
.woocommerce .woocommerce-breadcrumb a {
  color: var(--nv-secondary-accent);
}
.woocommerce .woocommerce-breadcrumb .nv-breadcrumb-delimiter {
  padding: 0 8px;
}

.woocommerce .woocommerce-result-count {
  float: none;
  margin: 0;
}

.nv-bc-count-wrap {
  margin-bottom: 20px;
  display: flex;
  font-size: 14px;
  justify-content: space-between;
  flex-direction: column;
}

.wc-block-grid__product-add-to-cart {
  display: inline-flex;
}

@media (min-width: 576px) {
  .woocommerce-info,
  .woocommerce-error,
  .woocommerce-message {
    text-align: right;
    padding-right: 60px;
    align-items: center;
  }
  .woocommerce-info a,
  .woocommerce-info .button,
  .woocommerce-error a,
  .woocommerce-error .button,
  .woocommerce-message a,
  .woocommerce-message .button {
    order: -1;
    margin-right: auto !important;
    margin-top: 0;
    width: auto;
  }
  .woocommerce-info::before,
  .woocommerce-error::before,
  .woocommerce-message::before {
    display: flex;
    top: 0;
    height: 100%;
    color: #fff;
  }
  .woocommerce-info,
  .woocommerce-message {
    flex-direction: row-reverse;
    justify-content: flex-end;
  }
  .woocommerce-info::before,
  .woocommerce-message::before {
    align-items: center;
  }
  .woocommerce-error {
    flex-direction: column-reverse;
  }
  .woocommerce-error::before {
    align-items: start;
    padding-top: 15px;
  }
  .nv-woo-filters .nv-sidebar-toggle + .woocommerce-ordering select {
    max-width: unset;
  }
}
@media (min-width: 769px) {
  .product-thumbnail:not([class^=elementor]) img {
    min-width: 120px !important;
  }
  .woocommerce table.shop_table.cart {
    border-collapse: collapse;
    padding: 0;
  }
  .woocommerce table.shop_table.cart th,
  .woocommerce table.shop_table.cart td {
    padding: 15px;
  }
  .woocommerce table.shop_table.cart th:last-child,
  .woocommerce table.shop_table.cart td:last-child {
    text-align: left;
  }
  .woocommerce table.shop_table.cart .product-thumbnail {
    width: 150px;
    display: table-cell !important;
  }
  .woocommerce table.shop_table.cart .product-remove {
    float: none;
    padding-left: 0;
    width: auto;
  }
  .woocommerce table.shop_table.cart tr:last-child .button {
    --secondarybtnpadding: 15px 40px;
    --primarybtnpadding: 18px 40px;
    margin-right: auto;
  }
  .cart_totals {
    width: 40%;
  }
  .nv-single-product-top {
    gap: 4%;
    flex-direction: row;
  }
  body.single-product .neve-main > .container > .row {
    flex-wrap: wrap;
  }
  .woocommerce.single .entry-summary > form.cart .wc-forward {
    flex-basis: auto;
  }
  .nv-single-image-wrapper {
    width: 48%;
  }
  .nv-single-image-wrapper .images {
    width: 100% !important;
  }
  .nv-bc-count-wrap {
    flex-direction: row;
  }
}
@media (min-width: 960px) {
  .woocommerce #reviews {
    grid-template-columns: 1fr 1fr;
    grid-column-gap: 80px;
  }
  .nv-nav-cart {
    display: block;
  }
  .menu-item-nav-cart:hover .nv-nav-cart, .menu-item-nav-cart:focus-within .nv-nav-cart {
    opacity: 1;
    visibility: visible;
  }
  .nv-sidebar-toggle {
    display: none;
  }
  .shop-sidebar {
    height: auto;
    background: transparent;
    position: static;
    overflow: visible;
    max-width: 30%;
    transform: none;
    z-index: unset;
  }
  .shop-sidebar .sidebar-header {
    display: none;
  }
  .woocommerce table.shop_table.cart thead th {
    border: 0;
  }
  .woocommerce table.shop_table.cart tbody tr:first-child {
    border-top: none;
  }
  .woocommerce table.shop_table.cart .remove {
    margin: 0 auto;
    font-size: 30px;
  }
  .woocommerce-cart table.cart td.actions .coupon {
    margin-right: 60px;
    margin-bottom: 0;
  }
  .woocommerce-checkout .woocommerce-NoticeGroup {
    grid-column: 1/3;
  }
  .woocommerce-checkout .nv-page-title {
    margin-bottom: 80px;
  }
  .woocommerce-checkout form.checkout {
    grid-template-columns: 3fr 2fr;
    grid-column-gap: 60px;
  }
}