.nv-repeater-options{margin-top:10px;display:flex;justify-content:flex-end;column-gap:15px;height:40px}.neve-sortable-item .neve-background-type-control{margin-bottom:10px}.neve-sortable-item .neve-control-header{margin:0}.neve-sortable-item .icon-control{height:30px;margin-bottom:10px}.neve-sortable-item .icon-control .add-icon-button{height:30px;width:53px;justify-content:center;margin-left:auto;border:1px solid #ccc;color:#50575e;box-shadow:none !important}.neve-sortable-item .icon-control .icon-setter{height:30px;width:53px;display:flex;margin-left:auto}.neve-sortable-item .icon-control .icon-setter .repeater-icon-preview{height:inherit;width:70%;justify-content:center;color:#1e1e1e;box-shadow:none;padding:0;border:1px solid #ccc}.neve-sortable-item .icon-control .icon-setter .repeater-delete-icon{height:inherit;justify-content:center;background-color:#ccc;color:#fff;box-shadow:none;padding:0}.neve-sortable-item .icon-control .icon-setter .repeater-delete-icon>*{height:16px;width:16px;font-size:16px}.neve-sortable-item .icon-control .icons-popover-content{max-height:280px}.neve-sortable-item .icon-control .icons-popover-content .icons-popover-header{margin:5px 10px}.neve-sortable-item .icon-control .icons-popover-content .icons-container{margin:10px 10px 10px 10px;display:grid;grid-template-columns:repeat(5, 40px);grid-template-rows:repeat(auto-fill, 40px)}.neve-sortable-item .icon-control .icons-popover-content .icons-container .icon-button{width:40px;height:40px;justify-content:center;padding:0}
