.range-slider {
	display: -ms-flexbox;
	display: -webkit-box;
	display: -webkit-flex;
	display: flex;
	flex-direction: row;
	-webkit-box-sizing: border-box;
	-moz-box-sizing: border-box;
	width: 100%;

	-webkit-align-items: center;
	align-items: center;
	-webkit-box-align: center;
	-webkit-box-direction: normal;
	-webkit-box-orient: horizontal;
	-webkit-box-pack: start;
	-ms-flex-align: center;
	-webkit-flex-direction: row;
	-ms-flex-direction: row;
	-ms-flex-pack: start;
	-webkit-flex-wrap: wrap;
	-ms-flex-wrap: wrap;
	flex-wrap: wrap;
	-webkit-justify-content: flex-start;
	justify-content: flex-start;
}

.range-slider__range {
	width: 67%;
	height: 5px;
	padding: 0;
	border-radius: 5px;
	outline: none;
	background-color: rgba(0,0,0,0.1);
	cursor: pointer;
	-webkit-transition: background 0.5s;
	transition: background 0.5s;

	-webkit-appearance: none;
}

.range-slider__range::-webkit-slider-thumb {
	width: 17px;
	height: 17px;
	border: 2px solid #2e86b9;
	border-radius: 15px;
	background-color: #fff;

	-webkit-appearance: none;
}

.range-slider__range::-webkit-slider-thumb:hover {
	background: #fff;
}

.range-slider__range:active::-webkit-slider-thumb {
	background: #fff;
}

.range-slider__range::-moz-range-thumb {
	width: 20px;
	height: 20px;
	border: 2px solid #2e86b9;
	border-radius: 50%;
	background-color: #fff;
	cursor: pointer;
	-webkit-transition: background 0.15s ease-in-out;
	transition: background 0.15s ease-in-out;
}

.range-slider__range::-moz-range-thumb:hover {
	background: #fff;
}

.range-slider__range:active::-moz-range-thumb {
	background: #fff;
}

.customize-control input[type=number].range-slider-value,
.customize-control input[type=text].range-slider-value {
	width: 21%;
	height: 28px;
	margin-left: 2%;
	padding: 3px;
	border-radius: 4px;
	color: #555;
	font-size: 12px;
	font-weight: 600;
	text-align: center;
	cursor: default;

	-moz-appearance: textfield;
}

.customize-control input[type=number].range-slider-value::-webkit-outer-spin-button,
.customize-control input[type=number].range-slider-value::-webkit-inner-spin-button {
	margin: 0;

	-webkit-appearance: none;
}

.customize-control input[type=number].range-slider-value {
	-moz-appearance: textfield;
}

.range-reset-slider .dashicons {
	width: 16px;
	height: 16px;
	font-size: 16px;
	line-height: 1;
}

.customize-control span.range-reset-slider {
	display: inline-block;
	position: relative;
	width: 6%;
	color: rgba(0,0,0,0.2);
	line-height: 1;
	text-align: center;
	cursor: pointer;
	-webkit-transition: all 0.3s ease;
	-moz-transition: all 0.3s ease;
	-ms-transition: all 0.3s ease;
	-o-transition: all 0.3s ease;
	transition: all 0.3s ease;
}

.customize-control span.range-reset-slider:hover {
	color: #fe5252;
}

::-moz-range-track {
	border: 0;
	background: #d7dcdf;
}

input::-moz-focus-inner,
input::-moz-focus-outer {
	border: 0;
}

.customize-control-range-value .customize-control-title,
.customize-control-range-value .responsive-switchers {
	display: inline-block;
}

.responsive-switchers {
	display: inline-block;
	margin-bottom: 5px;
	vertical-align: middle;
}

.responsive-switchers .preview-tablet,
.responsive-switchers .preview-mobile {
	display: none;
}

.customize-control .responsive-switchers {
	width: auto;
	margin-left: 5px;
}

.customize-control .responsive-switchers-open li button {
	display: block;
}

.customize-control .responsive-switchers li {
	float: left;
	margin: 0;
}

.customize-control .responsive-switchers li button {
	position: relative;
	width: 20px;
	height: 20px;
	margin-left: 5px;
	padding: 0;
	border: 0;
	border-radius: 50%;
	outline: none;
	color: #fff;
	background-color: #a4afb7;
	font-size: 10px;
	text-align: center;
	cursor: pointer;
	cursor: pointer;
	-webkit-transition: background-color 0.5s;
	transition: background-color 0.5s;
}

.customize-control .responsive-switchers li button:hover {
	background-color: #c2cbd2;
}

.customize-control .responsive-switchers li button.active {
	background-color: #13aff0;
}

.customize-control .responsive-switchers li button i {
	width: auto;
	height: auto;
	font-size: inherit;
	line-height: 18px;
}
