.customize-control-interface-tabs {
	display: list-item !important;
}

.neve-tabs-control {
	display: table;
	width: -webkit-calc(100% + 28px);
	width: calc(100% + 28px);
	margin: -15px 0 0 -12px;
	border-bottom: 1px solid #ddd;
	table-layout: fixed;
}

.neve-tabs-control .neve-customizer-tab {
	display: table-cell;
	width: 100%;
	border-right: 1px solid #ddd;
	text-align: center;
}

.neve-tabs-control .neve-customizer-tab:last-child {
	border-right: none;
}

.neve-tabs-control .neve-customizer-tab label {
	display: block;
	width: 100%;
	padding: 10px 0;
	color: #333;
	background: #fff;
	box-shadow: inset 0 0 0 0 #0085ba;
	font-weight: 600;
	text-decoration: none;
	text-transform: capitalize;
	-webkit-transition: all 0.3s ease;
	transition: all 0.3s ease;
}

.neve-tabs-control .neve-customizer-tab label i {
	margin-right: 4px;
	color: #333;
}

.neve-tabs-control .neve-customizer-tab label:hover {
	color: #0085ba;
	background: #f3f3f5;
}

.neve-tabs-control .neve-customizer-tab label:hover i {
	color: #333;
}

.neve-tabs-control .neve-customizer-tab.active label {
	color: #0085ba;
	background-color: #fff;
	box-shadow: inset 0 -3px 0 0 #0085ba;
}

.neve-tabs-control input[type="radio"] {
	display: none !important;
}

.tab-hidden {
	visibility: hidden !important;
	overflow: hidden !important;
	height: 0 !important;
	margin: 0 !important;
	padding: 0 !important;
}
