"use strict";(self.webpackChunkneve=self.webpackChunkneve||[]).push([[324],{324:(e,s,o)=>{o.r(s),o.d(s,{default:()=>i});var t=o(609);const a=(e,{source:s,valueKey:o,value:t})=>"hex"===s?{source:s,[s]:t}:{source:s,...{...e[s],[o]:t}};class i extends t.ColorPicker{handleInputChange(e){switch(e.state){case"reset":this.resetDraftValues();break;case"commit":const s=a(this.state,e);(e=>"hex"===e.source&&void 0===e.hex||"hsl"===e.source&&(void 0===e.h||void 0===e.s||void 0===e.l)||!("rgb"!==e.source||void 0!==e.r&&void 0!==e.g&&void 0!==e.b||void 0!==e.h&&void 0!==e.s&&void 0!==e.v&&void 0!==e.a||void 0!==e.h&&void 0!==e.s&&void 0!==e.l&&void 0!==e.a))(s)||this.commitValues(s);break;case"draft":this.setDraftValues(a(this.state,e))}}}}}]);