.in-sub-panel #customize-theme-controls .customize-pane-child.current-panel-parent,
#customize-theme-controls .customize-pane-child.current-section-parent {
  -webkit-transform: translateX(100%);
  -ms-transform: translateX(100%);
  transform: translateX(100%); }

@-webkit-keyframes spinnerRotate {
  from {
    -webkit-transform: rotate(0deg); }
  to {
    -webkit-transform: rotate(360deg); } }

@-moz-keyframes spinnerRotate {
  from {
    -moz-transform: rotate(0deg); }
  to {
    -moz-transform: rotate(360deg); } }

@-ms-keyframes spinnerRotate {
  from {
    -ms-transform: rotate(0deg); }
  to {
    -ms-transform: rotate(360deg); } }

.customize--reset-section {
  background: 100% 0;
  border: none;
  color: #555;
  cursor: pointer;
  margin: 0;
  padding: 20px;
  position: absolute;
  left: 0;
  top: 30px; }
  html[dir="rtl"] .customize--reset-section {
    left: auto;
    right: 0px; }
  .customize--reset-section:focus, .customize--reset-section:visited, .customize--reset-section:active {
    outline: none !important; }
  .customize--reset-section:before {
    -moz-osx-font-smoothing: grayscale;
    border: none;
    content: "\f531";
    display: block;
    font: 18px/1 dashicons;
    padding: 5px;
    text-align: center;
    text-decoration: none !important;
    text-indent: 0;
    right: 6px;
    position: absolute;
    top: 6px; }
  .customize--reset-section.loading {
    -webkit-animation-name: spinnerRotate;
    -webkit-animation-duration: 2s;
    -webkit-animation-iteration-count: infinite;
    -webkit-animation-timing-function: linear;
    -moz-animation-name: spinnerRotate;
    -moz-animation-duration: 2s;
    -moz-animation-iteration-count: infinite;
    -moz-animation-timing-function: linear;
    -ms-animation-name: spinnerRotate;
    -ms-animation-duration: 2s;
    -ms-animation-iteration-count: infinite;
    -ms-animation-timing-function: linear; }

.hfg--hide {
  display: none !important; }

.hfg--clear {
  clear: both; }

.hfg-control-field-header {
  cursor: pointer; }

.customize-control-hfg-modal .hfg-control-field-header,
.customize-control-hfg-typography .hfg-control-field-header,
.customize-control-hfg-styling .hfg-control-field-header {
  margin-left: 25px; }

.hfg-control--heading {
  padding: 5px 12px;
  background: #BBBBBB;
  margin: 10px -12px 2px; }
  .hfg-control--heading .customize-control-title {
    margin: 0px;
    text-transform: uppercase;
    letter-spacing: 2px;
    font-weight: 500;
    font-size: 12px;
    color: #FFFFFF; }

.hfg--field .hfg-field--heading {
  padding: 7px 12px;
  background: #fff;
  border-bottom: 1px solid #dddddd;
  border-top: 1px solid #dddddd;
  margin: 10px -15px;
  text-transform: uppercase;
  letter-spacing: 2px;
  font-weight: 400;
  font-size: 12px;
  color: #444444; }

#customize-controls .hfg--field .hfg-field--heading {
  font-size: 12px; }

#customize-controls .hfg-modal-settings h3.hfg-field--heading {
  font-size: 11px; }

#customize-controls .hfg-modal-settings .wp-picker-container {
  z-index: -1; }
  #customize-controls .hfg-modal-settings .wp-picker-container.wp-picker-active {
    z-index: 69; }

.customize-control .customize-control-description {
  margin-bottom: 15px;
  margin-top: -3px; }

.customize-control.control--bg.bottom-0 {
  margin-bottom: 0px; }

.customize-control.control--bg .hfg--settings-wrapper {
  background: #fff;
  margin-right: -12px;
  margin-left: -12px;
  min-height: 15px;
  padding: 10px 14px 8px 10px;
  border-bottom: 1px solid #ddd; }
  .customize-control.control--bg .hfg--settings-wrapper > .customize-control-description {
    display: none; }
  .customize-control.control--bg .hfg--settings-wrapper .hfg-actions {
    top: 13px;
    left: 10px;
    margin-top: 0px; }
    .customize-control.control--bg .hfg--settings-wrapper .hfg-actions .action--edit {
      padding: 0px;
      border: none; }
      .customize-control.control--bg .hfg--settings-wrapper .hfg-actions .action--edit:focus {
        box-shadow: none; }
      .customize-control.control--bg .hfg--settings-wrapper .hfg-actions .action--edit span {
        transition: all .2s linear;
        transform: rotate(90deg); }
        .customize-control.control--bg .hfg--settings-wrapper .hfg-actions .action--edit span:before {
          content: "\f347"; }

.customize-control.control--bg .hfg-modal-settings {
  margin-right: -12px;
  margin-left: -12px;
  margin-top: 0px;
  margin-bottom: 0px;
  box-shadow: none;
  background: transparent;
  border-bottom: 1px solid #ddd;
  z-index: 2; }
  .customize-control.control--bg .hfg-modal-settings:before {
    display: none !important; }
  .customize-control.control--bg .hfg-modal-settings .modal--tabs span.tab--active {
    background-color: #eee;
    border-bottom-color: #eee; }

.customize-control.control--bg.modal--opening .hfg--settings-wrapper .hfg-actions .action--edit span {
  transform: rotate(180deg); }
  .customize-control.control--bg.modal--opening .hfg--settings-wrapper .hfg-actions .action--edit span:before {
    content: "\f347"; }

.hfg-field-heading::after {
  display: block;
  content: "";
  clear: both; }

.hfg-field-heading label {
  display: inline-block; }

.hfg-field-heading .hfg-devices {
  display: inline-block;
  margin-right: 0px;
  float: left; }
  html[dir="rtl"] .hfg-field-heading .hfg-devices {
    float: right; }
  .hfg-field-heading .hfg-devices button {
    cursor: pointer;
    background: 100% 0;
    border: none;
    height: 23px;
    padding: 0 0px;
    margin: 0 1px 0 0;
    -webkit-box-shadow: none;
    box-shadow: none;
    outline: none !important;
    transition: .15s color ease-in-out,.15s background-color ease-in-out,.15s border-color ease-in-out;
    color: #bbbbbb; }
    .hfg-field-heading .hfg-devices button:before {
      display: inline-block;
      -webkit-font-smoothing: antialiased;
      font: 400 16px/4px dashicons;
      vertical-align: top;
      margin: 0;
      padding: 5px 0px 3px; }
    .hfg-field-heading .hfg-devices button.preview-desktop:before {
      content: "\f472"; }
    .hfg-field-heading .hfg-devices button.preview-tablet:before {
      content: "\f471"; }
    .hfg-field-heading .hfg-devices button.preview-mobile:before {
      content: "\f470"; }

/**
* Group Field
 */
.customize-control-hfg-group .hfg--settings-wrapper .hfg--settings-fields {
  border: 2px dashed #ccc;
  padding: 15px; }

.customize-control-hfg-group .hfg--settings-wrapper .hfg--group-field {
  margin-bottom: 15px; }
  .customize-control-hfg-group .hfg--settings-wrapper .hfg--group-field:last-child {
    margin-bottom: 0px; }

.hfg--multiple-devices .hfg-field-settings-inner {
  display: none; }
  .hfg--multiple-devices .hfg-field-settings-inner .hfg-field-settings-inner {
    display: block; }

.preview-desktop .hfg-devices .preview-desktop {
  border-color: #191e23;
  color: #191e23; }

.preview-desktop .hfg-field-settings-inner.hfg--for-desktop {
  display: block; }

.preview-tablet .hfg-devices .preview-tablet {
  border-color: #191e23;
  color: #191e23; }

.preview-tablet .hfg-field-settings-inner.hfg--for-tablet {
  display: block; }

.preview-mobile .hfg-devices .preview-mobile {
  border-color: #191e23;
  color: #191e23; }

.preview-mobile .hfg-field-settings-inner.hfg--for-mobile {
  display: block; }

.hfg--repeater-actions {
  text-align: left; }
  .hfg--repeater-actions .hfg--repeater-add-new {
    margin-right: 15px; }
    .hfg--repeater-actions .hfg--repeater-add-new:before {
      content: "\f132";
      display: inline-block;
      position: relative;
      right: -2px;
      top: -1px;
      font: 400 20px/1 dashicons;
      vertical-align: middle;
      transition: all .2s;
      -webkit-font-smoothing: antialiased;
      -moz-osx-font-smoothing: grayscale; }
  .hfg--repeater-actions .hfg--repeater-reorder {
    line-height: 27px; }

.hfg--repeater-items {
  margin-top: 15px;
  margin-bottom: 15px; }
  .hfg--repeater-items .hfg--repeater-field {
    margin-bottom: 15px; }
  .hfg--repeater-items .hfg--repeater-item-inner {
    padding: 10px; }
  .hfg--repeater-items .hfg--remove {
    padding: 0 10px 10px;
    display: inline-block; }
  .hfg--repeater-items .hfg--repeater-visible {
    display: inline-block;
    position: absolute;
    top: 0px;
    right: 0px;
    border-left: 1px solid #dddddd;
    width: 35px;
    text-align: center; }
    html[dir="rtl"] .hfg--repeater-items .hfg--repeater-visible {
      right: auto;
      left: 0px;
      border-left: 0px none;
      border-right: 1px solid #dddddd; }
    .hfg--repeater-items .hfg--repeater-visible .r-visible-icon:before {
      -moz-osx-font-smoothing: grayscale;
      border: none;
      content: "\f530";
      display: block;
      font: 14px/34px dashicons;
      padding: 5px;
      text-decoration: none !important;
      text-indent: 0; }
    .hfg--repeater-items .hfg--repeater-visible input:checked + span.r-visible-icon:before {
      content: "\f177"; }
    .hfg--repeater-items .hfg--repeater-visible input {
      display: none; }
  .hfg--repeater-items .hfg--repeater-item-heading {
    background: #FFF;
    padding: 15px;
    position: relative;
    display: block;
    line-height: 1;
    font-size: 1em;
    cursor: pointer; }
  .hfg--repeater-items .item---visible-hidden .hfg--repeater-item-heading {
    background: #f1f1f1; }
  .hfg--repeater-items .ui-sortable-helper .hfg--repeater-item-heading {
    cursor: grabbing;
    cursor: -webkit-grabbing;
    cursor: -moz-grabbing; }
  .hfg--repeater-items .hfg--repeater-live-title {
    white-space: nowrap;
    margin-left: 35px;
    margin-right: 30px;
    overflow: hidden;
    text-overflow: ellipsis;
    display: block;
    font-weight: 600;
    line-height: 1; }
    html[dir="rtl"] .hfg--repeater-items .hfg--repeater-live-title {
      margin-right: 35px;
      margin-left: 30px; }
  .hfg--repeater-items .hfg-nav-reorder {
    display: none;
    float: left;
    position: absolute;
    top: 0px;
    left: 0px;
    background-color: #fafafa; }
    .hfg--repeater-items .hfg-nav-reorder > span {
      position: relative;
      overflow: hidden;
      float: right;
      display: block;
      width: 33px;
      height: 43px;
      color: #82878c;
      text-indent: -9999px;
      cursor: pointer;
      outline: 0; }
      .hfg--repeater-items .hfg-nav-reorder > span:hover {
        color: #191e23;
        background: #eee; }
      .hfg--repeater-items .hfg-nav-reorder > span:before {
        display: inline-block;
        position: absolute;
        top: 0;
        left: 0;
        width: 100%;
        height: 100%;
        font: 400 20px/43px dashicons;
        text-align: center;
        text-indent: 0;
        -webkit-font-smoothing: antialiased;
        -moz-osx-font-smoothing: grayscale; }
    .hfg--repeater-items .hfg-nav-reorder .hfg--down:before {
      content: "\f347"; }
    .hfg--repeater-items .hfg-nav-reorder .hfg--up:before {
      content: "\f343"; }
  .hfg--repeater-items.reorder-active .hfg-nav-reorder {
    display: block; }
  .hfg--repeater-items.reorder-active .hfg--repeater-item-toggle {
    display: none !important; }
  .hfg--repeater-items .hfg--repeater-item {
    border: 1px solid #ddd;
    background: #ffffff;
    margin-bottom: 10px; }
    .hfg--repeater-items .hfg--repeater-item:last-child {
      margin-bottom: 0px; }
      .hfg--repeater-items .hfg--repeater-item:last-child .hfg-nav-reorder > span.hfg--down {
        background: #ffffff; }
    .hfg--repeater-items .hfg--repeater-item:first-child .hfg-nav-reorder > span.hfg--up {
      background: #ffffff; }
    .hfg--repeater-items .hfg--repeater-item .hfg--repeater-item-toggle {
      position: absolute;
      top: 0px;
      bottom: 0px;
      left: 0px;
      text-decoration: none;
      width: 32px;
      display: block;
      text-align: center;
      color: #555d66;
      box-shadow: none !important; }
      html[dir="rtl"] .hfg--repeater-items .hfg--repeater-item .hfg--repeater-item-toggle {
        left: auto;
        right: 0px; }
      .hfg--repeater-items .hfg--repeater-item .hfg--repeater-item-toggle:before {
        font: 400 20px/2 dashicons;
        content: "\f140"; }
    .hfg--repeater-items .hfg--repeater-item .hfg--repeater-item-settings {
      display: none; }
    .hfg--repeater-items .hfg--repeater-item.hfg--open .hfg--repeater-item-heading {
      border-bottom: 1px solid #ddd; }
    .hfg--repeater-items .hfg--repeater-item.hfg--open .hfg--repeater-item-settings {
      display: block; }
    .hfg--repeater-items .hfg--repeater-item.hfg--open .hfg--repeater-item-toggle:before {
      content: "\f142"; }

.hfg--group-field.ft--hr {
  clear: both; }

.hfg--group-field.field-half {
  width: 50%;
  float: right; }

.hfg--group-field.field-half-left {
  width: 50%;
  float: right; }
  .hfg--group-field.field-half-left .hfg--field {
    padding-left: 5px; }

.hfg--group-field.field-half-right {
  width: 50%;
  float: right; }
  .hfg--group-field.field-half-right .hfg--field {
    padding-right: 5px; }

.hfg--field {
  margin-bottom: 15px;
  width: 100%; }
  .hfg--field:last-child {
    margin-bottom: 0px; }
  .hfg--field * {
    box-sizing: border-box; }
  .hfg--field textarea {
    width: 100%; }
  .hfg--field .wp-picker-container input[type=text].wp-color-picker {
    width: 65px !important; }

.hfg-text-align input {
  display: none; }

.hfg-text-align input:checked + .button {
  background: #ccc; }

.hfg--css-unit {
  margin-bottom: 5px; }
  .hfg--css-unit label {
    display: none;
    margin-left: 5px;
    text-transform: uppercase;
    padding: 0px 5px;
    font-size: 11px; }
    .hfg--css-unit label:first-child {
      margin-right: -5px; }
      html[dir="rtl"] .hfg--css-unit label:first-child {
        margin-right: 0px; }
    .hfg--css-unit label.hfg--label-active {
      font-weight: bold; }
  .hfg--css-unit input {
    display: none; }

.hfg--gr-inputs {
  display: flex;
  margin-right: -2px;
  margin-left: -2px; }
  .hfg--gr-inputs > span {
    padding: 0px 2px; }
  .hfg--gr-inputs .hfg--small-label {
    font-size: 10px;
    display: block;
    text-transform: uppercase; }
  .hfg--gr-inputs span.input {
    height: 28px;
    display: block;
    vertical-align: middle;
    line-height: 28px;
    text-align: center; }
  .hfg--gr-inputs label {
    cursor: pointer;
    width: 25px;
    flex: none;
    position: relative; }
    .hfg--gr-inputs label input {
      display: none; }
    .hfg--gr-inputs label:before {
      font: 400 18px/37px dashicons;
      content: "\f225";
      position: absolute;
      top: -3px;
      right: 5px;
      display: block; }
    .hfg--gr-inputs label.hfg--label-active:before {
      content: "\f103"; }

.hfg-image-preview {
  margin: 0px 0 12px;
  display: block; }
  .hfg-image-preview:before {
    content: attr(data-no-file-text);
    display: block;
    border: 1px dashed #DDDDDD;
    padding: 9px 0px;
    text-align: center; }
  .hfg-image-preview.hfg--has-file:before {
    display: none; }

.hfg-input-slider-wrapper {
  position: relative;
  margin-top: 35px;
  display: block; }
  .hfg-input-slider-wrapper .hfg--css-unit {
    text-align: left;
    margin-top: -23px;
    margin-bottom: 0px; }
  .hfg-input-slider-wrapper .hfg--slider-input {
    width: 60px;
    max-width: 60px;
    position: absolute;
    top: -9px;
    left: 41px;
    height: 24px;
    line-height: 18px; }
    html[dir="rtl"] .hfg-input-slider-wrapper .hfg--slider-input {
      right: 41px;
      left: auto; }
    .hfg-input-slider-wrapper .hfg--slider-input.no-unit {
      left: 18px; }
  .hfg-input-slider-wrapper .hfg--label-active {
    display: block;
    top: -9px;
    left: 18px;
    line-height: 22px;
    position: absolute;
    margin-left: 0px;
    border: 1px solid #ddd;
    background: #fff;
    font-weight: normal;
    font-size: 10px;
    cursor: default;
    min-width: 24px;
    text-align: center; }
    html[dir="rtl"] .hfg-input-slider-wrapper .hfg--label-active {
      right: 17px;
      left: auto; }
  .hfg-input-slider-wrapper .reset {
    text-decoration: none;
    display: inline-block;
    color: #555d66;
    top: -9px;
    left: -5px;
    line-height: 22px;
    position: absolute;
    margin-left: 0px;
    border: 1px solid #ddd;
    background: #fff;
    font-weight: normal; }
    html[dir="rtl"] .hfg-input-slider-wrapper .reset {
      right: -5px;
      left: auto; }
    .hfg-input-slider-wrapper .reset:before {
      -moz-osx-font-smoothing: grayscale;
      border: none;
      content: "\f531";
      display: block;
      font: 12px/1 dashicons;
      padding: 5px;
      text-decoration: none !important;
      text-indent: 0; }

.hfg-input-slider {
  position: relative;
  margin: 11px 4px 20px 118px;
  height: 5px;
  display: block;
  background: #CCCCCC; }
  html[dir="rtl"] .hfg-input-slider {
    margin: 11px 118px 20px 4px; }
  .hfg-input-slider .ui-slider-range {
    width: 100%;
    display: block;
    height: 5px;
    background: #3068af; }
    html[dir="rtl"] .hfg-input-slider .ui-slider-range {
      position: absolute;
      right: 0px; }
  .hfg-input-slider .ui-slider-handle {
    width: 18px;
    height: 18px;
    display: block;
    position: absolute;
    top: -7px;
    background: #ffffff;
    border: 1px solid #CCCCCC;
    border-radius: 50%;
    cursor: pointer;
    transform: translateX(5px); }

.hfg--field-shadow .hfg--gr-inputs {
  margin-top: 10px; }

.hfg--icon-picker {
  display: flex; }
  .hfg--icon-picker .hfg--icon-preview {
    flex: 1;
    border: 1px solid #ddd;
    border-left: 0px;
    cursor: pointer;
    position: relative; }
    html[dir="rtl"] .hfg--icon-picker .hfg--icon-preview {
      border-left: 1px solid #ddd;
      border-right: 0px; }
  .hfg--icon-picker .hfg--icon-preview-icon {
    width: 35px;
    display: block;
    border-left: 0px;
    text-align: center;
    height: 100%;
    position: relative;
    background: #FFFFFF; }
    .hfg--icon-picker .hfg--icon-preview-icon i {
      position: absolute;
      top: 50%;
      right: 13px;
      transform: translateY(-50%); }
  .hfg--icon-picker input {
    box-shadow: none !important;
    outline: none !important;
    background: #ffffff; }
  .hfg--icon-picker .hfg--icon-remove {
    cursor: pointer;
    flex: 1;
    border: 1px solid #ddd;
    border-right: 0px;
    font-size: 18px; }
    html[dir="rtl"] .hfg--icon-picker .hfg--icon-remove {
      border-right: 1px solid #ddd;
      border-left: 0px; }
    .hfg--icon-picker .hfg--icon-remove .dashicons {
      width: 30px;
      display: block;
      transform: translateY(2px); }

#hfg--sidebar-icons {
  position: fixed;
  right: -300px;
  border-left: 1px solid #ddd;
  transition: all .5s ease;
  width: 300px;
  bottom: 0px;
  top: 0px;
  display: block;
  z-index: 8;
  background: #EBEBEB; }
  html[dir="rtl"] #hfg--sidebar-icons {
    right: auto;
    left: -300px;
    border-left: 0px none;
    border-right: 1px solid #ddd; }
  #hfg--sidebar-icons.hfg--active {
    right: 300px; }
    html[dir="rtl"] #hfg--sidebar-icons.hfg--active {
      right: auto;
      left: 300px; }
  #hfg--sidebar-icons * {
    box-sizing: border-box; }
  #hfg--sidebar-icons .hfg--sidebar-header {
    height: 46px;
    display: block;
    border-bottom: 1px solid #ddd; }
  #hfg--sidebar-icons .hfg--icon-type-inner {
    padding: 10px 50px 10px 10px;
    display: block; }
  #hfg--sidebar-icons .customize-controls-icon-close {
    display: block;
    position: absolute;
    top: 0;
    right: 0;
    width: 45px;
    height: 41px;
    padding: 0 0 0 2px;
    background: #eee;
    border: none;
    border-top: 4px solid #eee;
    border-left: 1px solid #ddd;
    color: #444;
    text-align: right;
    cursor: pointer;
    transition: color .15s ease-in-out,border-color .15s ease-in-out,background .15s ease-in-out;
    box-sizing: content-box;
    text-decoration: none; }
    #hfg--sidebar-icons .customize-controls-icon-close:before {
      font: 400 22px/45px dashicons;
      content: "\f335";
      position: relative;
      top: -3px;
      right: 13px; }
  #hfg--sidebar-icons #hfg--sidebar-icon-type {
    display: block;
    width: 100%;
    height: 26px; }
  #hfg--sidebar-icons .hfg--sidebar-search {
    background: #ffffff;
    padding: 10px; }
    #hfg--sidebar-icons .hfg--sidebar-search input {
      display: block;
      width: 100%; }
  #hfg--sidebar-icons #hfg--icon-browser {
    position: absolute;
    top: 100px;
    right: 0px;
    left: 0px;
    bottom: 0px;
    overflow: auto; }
  #hfg--sidebar-icons .hfg--list-icons li {
    width: 20%;
    float: right;
    font-size: 24px;
    text-align: center;
    padding: 10px 10px;
    overflow: hidden;
    cursor: pointer;
    transition: all 0.3s ease; }
    #hfg--sidebar-icons .hfg--list-icons li:hover {
      transform: scale(1.5); }
  #hfg--sidebar-icons .hfg--list-icons:after {
    clear: both;
    content: "";
    display: block; }

/* Typography */
.hfg--font-style .button input {
  display: none; }

.hfg--font-style .button span {
  line-height: inherit; }
  .hfg--font-style .button span:before {
    line-height: inherit; }

.hfg--font-style .button.hfg--checked {
  background: #ccc; }

/* Text Align */
.hfg-text-align .button {
  padding-top: 3px; }

.custom-control-image_select .hfg-radio-list input, .custom-control-radio_group .hfg-radio-list input {
  display: none; }

.custom-control-image_select .hfg-radio-list p, .custom-control-radio_group .hfg-radio-list p {
  margin: 0px 0 10px; }

.custom-control-image_select .hfg-radio-list p, .custom-control-image_select .hfg-radio-list label, .custom-control-radio_group .hfg-radio-list p, .custom-control-radio_group .hfg-radio-list label {
  display: inline-block; }

.custom-control-image_select .hfg-radio-list {
  display: flex;
  flex-wrap: wrap; }
  .custom-control-image_select .hfg-radio-list > p {
    flex-basis: 33.333%; }
    .custom-control-image_select .hfg-radio-list > p label {
      position: relative; }
    .custom-control-image_select .hfg-radio-list > p .label {
      display: inline-block;
      margin-top: 3px;
      position: relative; }
    .custom-control-image_select .hfg-radio-list > p .bubble {
      position: absolute;
      top: 0px;
      left: 0px;
      padding: 6px 3px;
      border: 1px solid #ca4a1f;
      background: #fff;
      font-size: 9px;
      line-height: 12px;
      text-transform: uppercase;
      border-radius: 20px;
      transform: translate(-9px, -6px); }
    .custom-control-image_select .hfg-radio-list > p.input-disabled img {
      opacity: 0.5; }

/**
 Radio Group
 */
.custom-control-radio_group .hfg-radio-list {
  display: flex; }
  .custom-control-radio_group .hfg-radio-list p {
    flex: 1; }
    .custom-control-radio_group .hfg-radio-list p:last-child span.label {
      border-left: 1px solid #ccc;
      border-top-left-radius: 3px;
      border-bottom-left-radius: 3px; }
      html[dir="rtl"] .custom-control-radio_group .hfg-radio-list p:last-child span.label {
        border-left: 0px none;
        border-right: 1px solid #ccc;
        border-top-left-radius: 0px;
        border-bottom-left-radius: 0px;
        border-top-right-radius: 3px;
        border-bottom-right-radius: 3px; }
    .custom-control-radio_group .hfg-radio-list p:first-child span.label {
      border-top-right-radius: 3px;
      border-bottom-right-radius: 3px; }
      html[dir="rtl"] .custom-control-radio_group .hfg-radio-list p:first-child span.label {
        border-left: 1px solid #ccc;
        border-top-right-radius: 0px;
        border-bottom-right-radius: 0px;
        border-top-left-radius: 3px;
        border-bottom-left-radius: 3px; }
  .custom-control-radio_group .hfg-radio-list label {
    width: 100%;
    display: block;
    text-align: center; }
  .custom-control-radio_group .hfg-radio-list span.label {
    border: 1px solid #ccc;
    display: inline-block;
    padding: 6px 5px;
    width: 100%;
    border-left: none; }
  .custom-control-radio_group .hfg-radio-list input:checked + span.label {
    border-color: #0085ba;
    background: #0085ba;
    color: #fff; }

/**
 Image Select
 */
.custom-control-image_select .hfg-radio-list img {
  line-height: 0px;
  display: block; }

.custom-control-image_select .hfg-radio-list span.label {
  display: inline-block;
  padding: 4px;
  max-width: 80px;
  border-radius: 5px; }
  .custom-control-image_select .hfg-radio-list span.label span {
    display: inline-block;
    margin-top: 3px; }

.custom-control-image_select .hfg-radio-list input:checked + span.label {
  border-color: #3068af;
  box-shadow: 0 0 5px 2px rgba(0, 0, 0, 0.2);
  background: #FFF; }

/*Background field*/
.customize-control.hfg-background-control--- .hfg-group-device-fields {
  position: relative; }
  .customize-control.hfg-background-control--- .hfg-group-device-fields::after {
    clear: both;
    content: "";
    display: block; }

.customize-control.hfg-background-control--- .hfg--settings-fields {
  position: relative;
  min-height: 160px;
  display: block;
  margin-top: 7px; }
  .customize-control.hfg-background-control--- .hfg--settings-fields::after {
    clear: both;
    content: "";
    display: block; }
  .customize-control.hfg-background-control--- .hfg--settings-fields .hfg--field select {
    width: 135px; }
  .customize-control.hfg-background-control--- .hfg--settings-fields .hfg--field.hfg--field-name-color .wp-picker-container {
    position: relative;
    z-index: 35; }
  .customize-control.hfg-background-control--- .hfg--settings-fields .hfg--field.hfg--field-name-color .wp-picker-holder {
    position: absolute;
    left: 0px;
    z-index: 10; }
  .customize-control.hfg-background-control--- .hfg--settings-fields .hfg--field.hfg--field-name-image {
    width: 115px;
    display: block;
    position: absolute;
    top: 35px;
    right: 0px; }
    .customize-control.hfg-background-control--- .hfg--settings-fields .hfg--field.hfg--field-name-image .hfg-field-header {
      display: none; }
    .customize-control.hfg-background-control--- .hfg--settings-fields .hfg--field.hfg--field-name-image .button {
      overflow: hidden;
      width: 35px;
      vertical-align: middle; }
      .customize-control.hfg-background-control--- .hfg--settings-fields .hfg--field.hfg--field-name-image .button:before {
        font-family: dashicons;
        margin-left: 35px;
        display: inline-block; }
      .customize-control.hfg-background-control--- .hfg--settings-fields .hfg--field.hfg--field-name-image .button.hfg--change:before, .customize-control.hfg-background-control--- .hfg--settings-fields .hfg--field.hfg--field-name-image .button.hfg--add:before {
        content: "\f317"; }
      .customize-control.hfg-background-control--- .hfg--settings-fields .hfg--field.hfg--field-name-image .button.hfg--remove:before {
        content: "\f335"; }
    .customize-control.hfg-background-control--- .hfg--settings-fields .hfg--field.hfg--field-name-image .hfg-image-preview {
      margin: 0px 0px 10px; }
      .customize-control.hfg-background-control--- .hfg--settings-fields .hfg--field.hfg--field-name-image .hfg-image-preview:before {
        padding: 35px 20px; }
    .customize-control.hfg-background-control--- .hfg--settings-fields .hfg--field.hfg--field-name-image .hfg-field-header {
      display: none; }
    .customize-control.hfg-background-control--- .hfg--settings-fields .hfg--field.hfg--field-name-image img {
      width: 115px;
      height: 115px;
      display: block;
      object-fit: cover; }
  .customize-control.hfg-background-control--- .hfg--settings-fields .hfg--field.hfg--field-name-position {
    position: absolute;
    top: 60px;
    left: 0px; }
    .customize-control.hfg-background-control--- .hfg--settings-fields .hfg--field.hfg--field-name-position .hfg-field-header {
      display: none; }
  .customize-control.hfg-background-control--- .hfg--settings-fields .hfg--field.hfg--field-name-repeat {
    position: absolute;
    top: 100px;
    left: 0px; }
    .customize-control.hfg-background-control--- .hfg--settings-fields .hfg--field.hfg--field-name-repeat .hfg-field-header {
      display: none; }
  .customize-control.hfg-background-control--- .hfg--settings-fields .hfg--field.hfg--field-name-cover {
    clear: both;
    position: absolute;
    top: 140px;
    left: 0px; }
  .customize-control.hfg-background-control--- .hfg--settings-fields .hfg--field.hfg--field-name-attachment {
    clear: both;
    position: absolute;
    top: 170px;
    left: 0px; }
    .customize-control.hfg-background-control--- .hfg--settings-fields .hfg--field.hfg--field-name-attachment .hfg-field-header {
      display: none; }

.hfg--settings-wrapper {
  position: relative;
  display: block; }
  .hfg--settings-wrapper .hfg-actions {
    position: absolute;
    top: 0px;
    left: 0px;
    vertical-align: middle;
    margin-top: 5px; }
    html[dir="rtl"] .hfg--settings-wrapper .hfg-actions {
      left: auto;
      right: 0px; }
    .hfg--settings-wrapper .hfg-actions a {
      text-decoration: none;
      display: inline-block; }
    .hfg--settings-wrapper .hfg-actions .action--reset {
      font-size: 12px;
      margin-left: 10px;
      display: none; }
      .hfg--settings-wrapper .hfg-actions .action--reset span {
        font-size: inherit;
        width: auto;
        height: auto;
        vertical-align: middle;
        margin-top: 0px; }
        .hfg--settings-wrapper .hfg-actions .action--reset span:before {
          font-size: 12px;
          width: auto;
          height: auto; }
    .hfg--settings-wrapper .hfg-actions .action--edit {
      background: #FFFFFF;
      border: 1px solid #ddd;
      border-radius: 3px;
      padding: 5px; }
      .modal--opening .hfg--settings-wrapper .hfg-actions .action--edit span:before {
        content: "\f335"; }

.modal--tabs {
  display: flex;
  margin-right: -12px;
  margin-left: -12px;
  border-bottom: 1px solid #ddd;
  margin-bottom: 15px; }
  .modal--tabs div {
    flex-basis: 100%;
    max-width: 100%;
    text-align: center;
    padding: 5px 5px 0px; }
    .modal--tabs div:first-child {
      padding-right: 10px; }
    .modal--tabs div:last-child {
      padding-left: 10px; }
  .modal--tabs span {
    display: block;
    border: 1px solid #dddddd;
    padding: 5px;
    cursor: pointer;
    margin-bottom: -1px;
    font-weight: 600; }
    .modal--tabs span.tab--active {
      background: #ffffff;
      border-bottom-color: #fff; }

.modal-tab-content {
  display: none; }
  .modal-tab-content.tab--active {
    display: block; }

#customize-theme-controls .customize-pane-child.accordion-section-content {
  min-height: 100%;
  display: block; }

.customize-control-hfg-typography .customize-control-description {
  margin-bottom: 0px; }

.customize-control-hfg-typography .ft--checkboxes[data-field-name="languages"] {
  margin-bottom: 0px; }

.customize-control-hfg-typography .list-subsets p {
  margin-top: 0px;
  width: 50%;
  float: right; }

.customize-control-hfg-typography .list-subsets:before, .customize-control-hfg-typography .list-subsets:after {
  content: "";
  display: block;
  clear: both; }

.customize-control-hfg-typography .list-subsets:after {
  clear: both; }

.customize-control-hfg-typography .hfg--group-field:before, .customize-control-hfg-typography .hfg--group-field:after {
  content: "";
  display: block;
  clear: both; }

.customize-control-hfg-typography .hfg--group-field:after {
  clear: both; }

.customize-control-hfg-typography .hfg--group-field .hfg-field-header {
  width: 50%;
  float: right; }

.customize-control-hfg-typography .hfg--group-field .hfg-field-settings-inner {
  width: 50%;
  float: left; }

.customize-control-hfg-typography .hfg--group-field.hfg--multiple-devices .hfg-field-header, .customize-control-hfg-typography .hfg--group-field.hfg--multiple-devices .hfg-field-settings-inner {
  width: auto;
  float: none; }

.customize-control-hfg-typography .hfg--group-field .hfg--field-slider .hfg-field-header, .customize-control-hfg-typography .hfg--group-field .hfg--field-slider .hfg-field-settings-inner, .customize-control-hfg-typography .hfg--group-field .hfg--field-name-languages .hfg-field-header, .customize-control-hfg-typography .hfg--group-field .hfg--field-name-languages .hfg-field-settings-inner {
  width: auto;
  float: none; }

.hfg-field-settings-inner {
  position: relative; }

.hfg-modal--inside {
  position: relative; }
  .hfg-modal--inside .description {
    margin-bottom: 0px; }

.customize-control-hfg-styling .hfg--settings-wrapper > .customize-control-description, .customize-control-hfg-typography .hfg--settings-wrapper > .customize-control-description, .customize-control-hfg-modal .hfg--settings-wrapper > .customize-control-description {
  margin-bottom: 0px; }

.customize-control-hfg-styling .hfg--settings-wrapper, .customize-control-hfg-typography .hfg--settings-wrapper, .customize-control-hfg-modal .hfg--settings-wrapper {
  min-height: 40px;
  display: block; }

.ft--heading {
  clear: both; }

.control--bg .hfg-modal-settings .hfg--field-heading h3.hfg-field--heading {
  background: #fff; }

.hfg-modal-settings {
  box-shadow: 0 2px 15px rgba(0, 0, 0, 0.3);
  background: #fff;
  padding: 12px;
  margin-bottom: 15px;
  margin-top: 10px;
  right: 0px;
  left: 0px;
  z-index: 9;
  position: relative; }
  .hfg-modal-settings:before {
    content: '';
    position: absolute;
    top: -6px;
    left: 5px;
    width: 15px;
    height: 15px;
    background: #fff;
    transform: rotate(-45deg);
    border-radius: 3px; }
    html[dir="rtl"] .hfg-modal-settings:before {
      left: auto;
      right: 5px; }
  .hfg-modal-settings::after {
    content: '';
    display: table;
    clear: both; }
  .hfg-modal-settings .wp-color-result-text {
    line-height: 23px; }
  .hfg-modal-settings .hfg--field-heading h3.hfg-field--heading {
    font-size: 11px;
    margin: 10px -12px;
    padding: 5px 12px 4px;
    background: #eeeeee; }
  .hfg-modal-settings .customize-control-title {
    font-weight: 600;
    font-size: 13px; }
  .hfg-modal-settings .hfg--group-field {
    margin-bottom: 5px; }
    .hfg-modal-settings .hfg--group-field:last-child {
      margin-bottom: 0px; }
  .hfg-modal-settings .lb-left:before, .hfg-modal-settings .lb-left:after {
    content: "";
    display: block;
    clear: both; }
  .hfg-modal-settings .lb-left:after {
    clear: both; }
  .hfg-modal-settings .lb-left .hfg-typography--field-header {
    width: 50%;
    float: right; }
  .hfg-modal-settings .lb-left .hfg-typography--field-settings {
    float: left;
    width: 50%; }

/* Checkbox */
.hfg--field-checkbox .hfg-field-settings-inner {
  padding-left: 30px;
  position: relative;
  font-size: 14px;
  line-height: 24px;
  font-weight: 600;
  margin-bottom: 4px; }
  .hfg--field-checkbox .hfg-field-settings-inner .onoffswitch {
    float: left;
    position: absolute;
    top: 3px;
    left: 0px; }

.customize-control-hfg-checkbox .has-title-desc .hfg--settings-fields {
  position: absolute;
  top: -6px;
  left: 0px; }

.customize-control-hfg-checkbox .has-title-desc .hfg-control-field-header {
  cursor: pointer;
  margin-left: 30px; }

.customize-control-hfg-checkbox .has-title-desc .checkbox-field-text {
  display: none !important; }

.preview-desktop .hfg--field-checkbox .hfg--for-tablet,
.preview-desktop .hfg--field-checkbox .hfg--for-mobile {
  display: none; }

.preview-tablet .hfg--field-checkbox .hfg--for-desktop,
.preview-tablet .hfg--field-checkbox .hfg--for-mobile {
  display: none; }

.preview-mobile .hfg--field-checkbox .hfg--for-desktop,
.preview-mobile .hfg--field-checkbox .hfg--for-tablet {
  display: none; }

/* OnOff Button */
.onoffswitch {
  position: relative;
  width: 25px;
  display: inline-block;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none; }

.onoffswitch-checkbox {
  display: none !important; }

.onoffswitch-label {
  display: block;
  overflow: hidden;
  cursor: pointer;
  border: 0px none;
  border-radius: 10px;
  position: relative;
  top: 3px;
  transition: all 0.3s ease-in 0s;
  opacity: 1; }

.onoffswitch-inner {
  display: block;
  width: 200%;
  margin-right: -100%;
  transition: margin 0.3s ease-in 0s; }

.onoffswitch-inner:before, .onoffswitch-inner:after {
  display: block;
  float: right;
  width: 50%;
  height: 15px;
  padding: 0;
  box-sizing: border-box; }

.onoffswitch-inner:before {
  content: "";
  padding-right: 10px;
  background-color: #00aadc;
  color: #FFFFFF; }

.onoffswitch-inner:after {
  content: "";
  padding-left: 10px;
  background-color: #CCCCCC;
  text-align: left; }

.onoffswitch-switch {
  display: block;
  width: 11px;
  margin: 0px 1px 0px 3px;
  background: #FFFFFF;
  position: absolute;
  top: 2px;
  bottom: 2px;
  left: 8px;
  border-radius: 10px;
  transition: all 0.3s ease-in 0s; }

.onoffswitch-checkbox:checked + .onoffswitch-label .onoffswitch-inner {
  margin-right: 0; }

.onoffswitch-checkbox:checked + .onoffswitch-label .onoffswitch-switch {
  left: 0px; }

.onoffswitch-checkbox:disabled + .onoffswitch-label {
  opacity: 0.4;
  cursor: default; }

/* Customify Pro section */
#customize-controls #accordion-section-hfg-pro {
  border-top: 1px solid #ca4a1f;
  border-bottom: 1px solid #ca4a1f; }

#customize-controls #accordion-section-hfg-pro h3 {
  margin: 0;
  position: relative; }

#customize-controls #accordion-section-hfg-pro h3 a {
  padding: 10px 14px 11px 10px;
  line-height: 20px;
  display: block;
  background: #ffffff;
  color: #ca4a1f;
  text-decoration: none;
  position: relative; }

#customize-controls #accordion-section-hfg-pro h3 a:hover {
  background: #f5f5f5; }

#customize-controls #accordion-section-hfg-pro h3 a:after {
  content: "\f345";
  position: absolute;
  color: #ca4a1f;
  top: 11px;
  left: 10px;
  z-index: 1;
  float: left;
  border: none;
  background: none;
  font: normal 20px/1 dashicons;
  speak: none;
  display: block;
  padding: 0;
  text-indent: 0;
  text-align: center; }

.hfg-pro-teaser {
  color: #856404;
  background-color: #fff3cd;
  margin: 1em 0px;
  position: relative;
  padding: .75rem 1.25rem;
  margin-bottom: 1rem;
  border-top: 1px solid #ddd;
  border-bottom: 1px solid #ddd;
  border-radius: .25rem; }
  .hfg-pro-teaser ul {
    margin-bottom: 1em; }
  .hfg-pro-teaser .button {
    display: block;
    text-align: center; }

.customize-control.customize-control-pro {
  float: none;
  padding-top: 1em; }

.customize-control .hfg-pro-teaser {
  margin-right: -12px;
  margin-left: -12px; }

.customize-control-interface-tabs {
  display: list-item !important; }

.hfg-tabs-control {
  border-bottom: 1px solid #ddd;
  width: calc(100% + 28px);
  margin: -15px -12px 0 0;
  table-layout: fixed;
  display: table; }
  .hfg-tabs-control .hfg-customizer-tab {
    border-left: 1px solid #ddd;
    display: table-cell;
    text-align: center;
    width: 100%; }
    .hfg-tabs-control .hfg-customizer-tab:last-child {
      border-left: none; }
    .hfg-tabs-control .hfg-customizer-tab label {
      text-transform: capitalize;
      background: #fff;
      box-shadow: inset 0 0 0 0 #0085ba;
      transition: all .3s ease;
      display: block;
      width: 100%;
      padding: 10px 0;
      text-decoration: none;
      font-weight: 600;
      color: #333; }
      .hfg-tabs-control .hfg-customizer-tab label:hover {
        color: #0085ba;
        background: #f3f3f5; }
        .hfg-tabs-control .hfg-customizer-tab label:hover i {
          color: #333; }
      .hfg-tabs-control .hfg-customizer-tab label i {
        color: #333;
        margin-left: 4px; }
  .hfg-tabs-control.active label {
    box-shadow: inset 0 -3px 0 0 #0085ba;
    color: #0085ba;
    background-color: #fff; }
  .hfg-tabs-control input[type="radio"] {
    display: none !important; }

.hfg--hide {
  display: none !important; }

#customize-preview {
  transition: all 500ms; }
  #customize-preview.cb--preview-panel-show {
    bottom: 330px; }

.preview-desktop #customize-preview.cb--preview-panel-show {
  height: auto; }

.preview-tablet #customize-preview.cb--preview-panel-show {
  height: auto; }

.preview-mobile #customize-preview.cb--preview-panel-show {
  height: 480px; }

.hfg--customize-builder {
  position: fixed;
  bottom: 0px;
  width: 100%;
  max-width: 100%;
  right: 0px;
  display: block;
  background: #f1f1f1;
  border-top: 1px solid #ddd;
  transition: all 500ms;
  transform: translateY(100%); }
  .hfg--customize-builder .panel-name-text {
    display: none; }
  .hfg--customize-builder.hfg--builder-show {
    transform: translateY(0); }
    .hfg--customize-builder.hfg--builder-show.hfg--builder--hide {
      transform: translateY(100%); }
      .hfg--customize-builder.hfg--builder-show.hfg--builder--hide .close-text {
        display: none; }
      .hfg--customize-builder.hfg--builder-show.hfg--builder--hide .panel-name-text {
        display: inline-block;
        font-weight: 500; }
      .hfg--customize-builder.hfg--builder-show.hfg--builder--hide .hfg--panel-close {
        position: absolute;
        top: -45px;
        left: 30px;
        text-transform: uppercase; }
        html[dir="rtl"] .hfg--customize-builder.hfg--builder-show.hfg--builder--hide .hfg--panel-close {
          left: auto;
          right: 30px; }
  .hfg--customize-builder * {
    box-sizing: border-box; }
  .hfg--customize-builder .hfg--cb-inner {
    transition: all 500ms;
    margin-right: 300px;
    margin-left: 0px;
    height: 100%;
    display: block;
    overflow: auto; }
    html[dir="rtl"] .hfg--customize-builder .hfg--cb-inner {
      margin-right: 0px;
      margin-left: 300px; }
  .hfg--customize-builder .hfg--cb-body {
    height: 295px;
    overflow: auto;
    display: block; }

.hfg--cb-body {
  position: relative;
  overflow: hidden; }

.hfg--device-panel {
  display: flex;
  flex-wrap: wrap;
  flex-direction: row-reverse;
  z-index: 4;
  position: relative;
  padding: 30px 20px 20px;
  overflow: hidden; }
  .hfg--device-panel:before, .hfg--device-panel:after {
    content: "";
    display: block;
    clear: both; }
  .hfg--device-panel:after {
    clear: both; }
  .hfg--device-panel.hfg--panel-hide {
    opacity: 0;
    height: 0;
    overflow: hidden;
    display: block;
    z-index: 1;
    position: absolute;
    top: -99999px;
    right: -99999px;
    width: 0px; }
  .hfg--device-panel.hfg--panel-desktop .hfg--cp-sidebar {
    display: none; }
  .hfg--device-panel.hfg--panel-desktop .hfg--cp-rows {
    width: 100%; }
  .hfg--device-panel.hfg--panel-mobile .hfg--cp-rows {
    width: 80%;
    flex-grow: 1; }
  .hfg--device-panel.hfg--panel-mobile .hfg--cp-sidebar {
    display: none;
    width: 20%;
    min-height: 160px;
    height: 100%; }
    .hfg--device-panel.hfg--panel-mobile .hfg--cp-sidebar h4 {
      margin-top: -20px;
      margin-bottom: 4px;
      margin-right: 25px; }
    .hfg--device-panel.hfg--panel-mobile .hfg--cp-sidebar .hfg--cb-row {
      height: 100%;
      min-height: 160px; }
      .hfg--device-panel.hfg--panel-mobile .hfg--cp-sidebar .hfg--cb-row .hfg--row-inner .hfg--cb-items {
        height: 100%; }

.hfg--cb-header {
  padding: 10px 20px 0;
  background-color: #fff;
  border-bottom: 1px solid #ccc; }
  .hfg--cb-header:before, .hfg--cb-header:after {
    content: "";
    display: block;
    clear: both; }
  .hfg--cb-header:after {
    clear: both; }
  .hfg--cb-header .hfg--cb-devices-switcher {
    float: right; }
    html[dir="rtl"] .hfg--cb-header .hfg--cb-devices-switcher {
      float: left; }
    .hfg--cb-header .hfg--cb-devices-switcher a {
      border: 1px solid #ccc;
      border-top-left-radius: 3px;
      border-top-right-radius: 3px;
      display: inline-block;
      margin-left: 10px;
      padding: 8px 15px 9px;
      margin-bottom: -1px;
      font-weight: 600;
      background-color: #f1f1f1;
      text-decoration: none;
      color: #555; }
      .hfg--cb-header .hfg--cb-devices-switcher a:focus {
        box-shadow: none; }
      .hfg--cb-header .hfg--cb-devices-switcher a span:not(.icon) {
        display: none; }
      .hfg--cb-header .hfg--cb-devices-switcher a.hfg--tab-active {
        color: #0073aa;
        border-bottom-color: transparent; }
        .hfg--cb-header .hfg--cb-devices-switcher a.hfg--tab-active span:not(.icon) {
          display: unset; }
        .hfg--cb-header .hfg--cb-devices-switcher a.hfg--tab-active .icon {
          margin-left: 3px; }
    .hfg--cb-header .hfg--cb-devices-switcher .icon {
      font: 400 14px/14px dashicons;
      position: relative;
      top: 2px; }
    .hfg--cb-header .hfg--cb-devices-switcher .mobile-icon:after {
      content: "\f470"; }
    .hfg--cb-header .hfg--cb-devices-switcher .desktop-icon:after {
      content: "\f472"; }
  .hfg--cb-header .hfg--cb-actions {
    float: left;
    margin-top: -1px; }
    html[dir="rtl"] .hfg--cb-header .hfg--cb-actions {
      float: right; }
    .hfg--cb-header .hfg--cb-actions a {
      display: inline-block;
      margin-right: 10px; }
    .hfg--cb-header .hfg--cb-actions .builder-version-change {
      text-transform: uppercase; }

.hfg--cb-body {
  position: relative;
  z-index: 4; }

.hfg--cb-footer {
  position: relative;
  z-index: 5; }

.hfg--cb-row {
  padding: 0;
  position: relative;
  border: 1px solid #ddd;
  display: flex;
  margin-bottom: 10px;
  margin-right: 20px; }
  html[dir="rtl"] .hfg--cb-row {
    margin-left: 20px;
    margin-right: 0; }
  .hfg--cb-row:last-child {
    margin-bottom: 0px; }
  .hfg--cb-row.row-active {
    border-color: #0073aa; }
    .hfg--cb-row.row-active .hfg--cb-row-settings {
      background: #0073aa;
      border-color: #0073aa; }
    .hfg--cb-row.row-active .hfg--cb-row-settings:before {
      color: #fff; }
  .hfg--cb-row:before, .hfg--cb-row:after {
    content: "";
    display: block;
    clear: both; }
  .hfg--cb-row:after {
    clear: both; }
  .hfg--cb-row:hover .hfg--cb-row-settings, .hfg--cb-row:hover .hfg--row-inner .row--title {
    opacity: 1; }
  .hfg--cb-row .hfg--cb-row-settings {
    background: #fff;
    position: absolute;
    right: -20px;
    opacity: 0;
    top: -1px;
    bottom: -1px;
    border: 1px solid #ddd;
    transition: opacity .2s ease-out;
    z-index: 10000;
    box-sizing: border-box;
    display: flex;
    align-items: center;
    justify-content: center;
    text-decoration: none;
    width: 20px;
    text-align: center;
    color: #444444; }
    html[dir="rtl"] .hfg--cb-row .hfg--cb-row-settings {
      border-left: 0 none;
      border-right: 1px solid #ddd; }
    .hfg--cb-row .hfg--cb-row-settings:focus {
      box-shadow: none; }
    .hfg--cb-row .hfg--cb-row-settings:before {
      -webkit-font-smoothing: antialiased;
      font: 400 14px/20px dashicons;
      content: "\f111";
      position: relative; }
    .hfg--cb-row .hfg--cb-row-settings:hover {
      color: #0073aa; }
  .hfg--cb-row .hfg--cb-items {
    display: block;
    min-height: 35px; }
    .hfg--cb-row .hfg--cb-items.hfg--sidebar-items {
      padding: 0 5px; }
      .hfg--cb-row .hfg--cb-items.hfg--sidebar-items .grid-stack-item {
        display: block;
        margin-bottom: 5px; }
        .hfg--cb-row .hfg--cb-items.hfg--sidebar-items .grid-stack-item .hfg--cb-item-remove {
          left: 3px; }
        .hfg--cb-row .hfg--cb-items.hfg--sidebar-items .grid-stack-item .hfg--cb-item-setting {
          left: 26px; }
        .hfg--cb-row .hfg--cb-items.hfg--sidebar-items .grid-stack-item.ui-draggable-handle {
          width: 100% !important;
          min-width: 100%; }
        .hfg--cb-row .hfg--cb-items.hfg--sidebar-items .grid-stack-item:last-child {
          margin-bottom: 0px; }
  .hfg--cb-row .hfg--row-inner {
    width: 100%;
    padding: 5px 0;
    background: #ffffff;
    position: relative; }
    .hfg--cb-row .hfg--row-inner .row--title {
      position: absolute;
      top: 50%;
      transform: translateY(-50%);
      text-align: center;
      width: 100%;
      z-index: 2;
      font-size: 16px;
      font-weight: 600;
      color: #ccc;
      user-select: none;
      opacity: 0;
      transition: opacity .2s ease-out; }
    .hfg--cb-row .hfg--row-inner .row--grid {
      position: absolute;
      top: 0;
      right: 0;
      width: 100%;
      z-index: 1;
      display: flex;
      bottom: 0; }
      .hfg--cb-row .hfg--row-inner .row--grid div {
        border-left: 1px solid #fafafa;
        width: 8.3333333333%;
        flex-basis: 8.3333333333%;
        max-width: 8.3333333333%;
        display: block; }
        .hfg--cb-row .hfg--row-inner .row--grid div:last-child {
          border-left: 0 none; }
        html[dir="rtl"] .hfg--cb-row .hfg--row-inner .row--grid div {
          border-left: none 0px;
          border-right: 1px dashed #dddddd; }
          html[dir="rtl"] .hfg--cb-row .hfg--row-inner .row--grid div:last-child {
            border-left: 0 none;
            border-right: 0px none; }
    .hfg--cb-row .hfg--row-inner .hfg--cb-items {
      z-index: 36;
      background: transparent; }
  .hfg--cb-row .grid-stack-item-content {
    background: #fafafa;
    border: 1px solid #dddddd;
    line-height: 1; }
  .hfg--cb-row .grid-stack-item.item-active .grid-stack-item-content {
    background-color: #0073aa;
    border-color: #0073aa;
    color: #fff; }
  .hfg--cb-row .grid-stack-item.item-active .hfg-cb-icon:hover {
    color: #fff;
    opacity: .75; }
  .hfg--cb-row .hfg--cb-item-name {
    overflow: hidden;
    text-overflow: ellipsis;
    margin: 0 10px;
    padding-left: 60px;
    display: inline-block;
    width: 100%;
    max-width: 100%;
    line-height: 35px; }
    html[dir="rtl"] .hfg--cb-row .hfg--cb-item-name {
      padding-left: 0;
      padding-right: 60px; }
  .hfg--cb-row .hfg--cb-item-add {
    display: none; }

.builder-item-moving .ui-resizable-handle {
  display: none !important; }

.hfg-available-items {
  clear: both;
  margin-top: 10px;
  width: 100%;
  display: inline-block; }
  .hfg-available-items:before, .hfg-available-items:after {
    content: "";
    display: block;
    clear: both; }
  .hfg-available-items:after {
    clear: both; }
  .hfg-available-items:empty {
    border: 1px dashed #ccc;
    height: 35px;
    background-color: #eee; }
  .hfg-available-items.hfg--panel-hide {
    height: 0px;
    overflow: hidden;
    display: block;
    visibility: hidden; }
  .hfg-available-items:before, .hfg-available-items:after {
    content: "";
    display: block;
    clear: both; }
  .hfg-available-items:after {
    clear: both; }
  .hfg-available-items .grid-stack-item-content {
    padding: 6px 15px;
    border: 1px solid #ddd;
    margin-left: 10px;
    cursor: -webkit-grab;
    cursor: -moz-grab;
    box-shadow: 0 1px 0 #ccc;
    background: #f7f7f7;
    color: #555555;
    border-radius: 2px; }
    .hfg-available-items .grid-stack-item-content:hover {
      color: #23282d;
      background: #fafafa;
      border-color: #999; }
    .hfg-available-items .grid-stack-item-content:active {
      cursor: -webkit-grabbing;
      cursor: -moz-grabbing; }
  .hfg-available-items * {
    box-sizing: content-box; }
  .hfg-available-items .grid-stack-item {
    float: right;
    width: auto !important; }
    .hfg-available-items .grid-stack-item .item-tooltip {
      display: none; }
  .hfg-available-items .hfg--cb-item-setting,
  .hfg-available-items .hfg--cb-item-remove {
    display: none; }

.grid-stack > .grid-stack-item > .grid-stack-item-content {
  overflow: hidden !important; }

.grid-stack-item {
  position: relative;
  height: 35px;
  display: inline-block;
  z-index: 50;
  cursor: pointer; }
  .grid-stack-item.ui-draggable-dragging {
    z-index: 9999999;
    cursor: grabbing;
    cursor: -webkit-grabbing;
    cursor: -moz-grabbing; }
  .grid-stack-item .item-tooltip {
    position: absolute;
    background: #333333;
    color: #ffffff;
    font-size: 11px;
    line-height: 15px;
    padding: 3px 10px 4px;
    border-radius: 2px;
    top: 0px;
    right: 11px;
    z-index: 0;
    opacity: 0;
    height: 0px;
    overflow: hidden; }
    .grid-stack-item .item-tooltip:before {
      bottom: -7px;
      content: "";
      position: absolute;
      width: 0;
      height: 0;
      border-style: solid;
      border-width: 8px 8px 0 8px;
      border-color: #333333 transparent transparent transparent; }
  .grid-stack-item.show-tooltip .item-tooltip {
    top: -29px;
    right: 11px;
    z-index: 68;
    opacity: 1;
    height: auto;
    overflow: initial; }
  .grid-stack-item .grid-stack-item-content {
    background: #fafafa;
    border-radius: 2px; }
  .grid-stack-item .hfg-cb-icon {
    position: absolute;
    opacity: 0;
    transition: opacity .2s ease-out; }
    .grid-stack-item .hfg-cb-icon:before {
      -webkit-font-smoothing: antialiased;
      font: 400 20px/26px dashicons; }
  .grid-stack-item:hover .hfg-cb-icon {
    opacity: 1; }
  .grid-stack-item .hfg--cb-item-add {
    top: 50%;
    left: 10px;
    transform: translateY(-50%); }
    .grid-stack-item .hfg--cb-item-add:before {
      content: "\f132"; }
  .grid-stack-item .hfg--cb-item-remove {
    top: 50%;
    background: inherit;
    padding: 5px 3px;
    left: 0px;
    transform: translateY(-50%);
    cursor: pointer; }
    html[dir="rtl"] .grid-stack-item .hfg--cb-item-remove {
      left: auto;
      right: 0px; }
    .grid-stack-item .hfg--cb-item-remove:before {
      content: "\f335"; }
    .grid-stack-item .hfg--cb-item-remove:hover {
      color: #0073aa; }
  .grid-stack-item .hfg--cb-item-setting {
    background: inherit;
    top: 50%;
    left: 22px;
    padding: 5px 3px;
    transform: translateY(-50%);
    cursor: pointer; }
    html[dir="rtl"] .grid-stack-item .hfg--cb-item-setting {
      left: auto;
      right: 22px; }
    .grid-stack-item .hfg--cb-item-setting:before {
      content: "\f111";
      font-size: 15px; }
    .grid-stack-item .hfg--cb-item-setting:hover {
      color: #0073aa; }

.grid-stack.grid-stack-1 > .grid-stack-item {
  min-width: 100%; }
  .grid-stack.grid-stack-1 > .grid-stack-item[data-gs-width="1"] {
    width: 100%; }
  .grid-stack.grid-stack-1 > .grid-stack-item[data-gs-x="1"] {
    right: 100%; }
  .grid-stack.grid-stack-1 > .grid-stack-item[data-gs-min-width="1"] {
    min-width: 100%; }
  .grid-stack.grid-stack-1 > .grid-stack-item[data-gs-max-width="1"] {
    max-width: 100%; }

.grid-stack.grid-stack-2 > .grid-stack-item {
  min-width: 50%; }
  .grid-stack.grid-stack-2 > .grid-stack-item[data-gs-width="1"] {
    width: 50%; }
  .grid-stack.grid-stack-2 > .grid-stack-item[data-gs-x="1"] {
    right: 50%; }
  .grid-stack.grid-stack-2 > .grid-stack-item[data-gs-min-width="1"] {
    min-width: 50%; }
  .grid-stack.grid-stack-2 > .grid-stack-item[data-gs-max-width="1"] {
    max-width: 50%; }
  .grid-stack.grid-stack-2 > .grid-stack-item[data-gs-width="2"] {
    width: 100%; }
  .grid-stack.grid-stack-2 > .grid-stack-item[data-gs-x="2"] {
    right: 100%; }
  .grid-stack.grid-stack-2 > .grid-stack-item[data-gs-min-width="2"] {
    min-width: 100%; }
  .grid-stack.grid-stack-2 > .grid-stack-item[data-gs-max-width="2"] {
    max-width: 100%; }

.grid-stack.grid-stack-3 > .grid-stack-item {
  min-width: 33.33333%; }
  .grid-stack.grid-stack-3 > .grid-stack-item[data-gs-width="1"] {
    width: 33.33333%; }
  .grid-stack.grid-stack-3 > .grid-stack-item[data-gs-x="1"] {
    right: 33.33333%; }
  .grid-stack.grid-stack-3 > .grid-stack-item[data-gs-min-width="1"] {
    min-width: 33.33333%; }
  .grid-stack.grid-stack-3 > .grid-stack-item[data-gs-max-width="1"] {
    max-width: 33.33333%; }
  .grid-stack.grid-stack-3 > .grid-stack-item[data-gs-width="2"] {
    width: 66.66667%; }
  .grid-stack.grid-stack-3 > .grid-stack-item[data-gs-x="2"] {
    right: 66.66667%; }
  .grid-stack.grid-stack-3 > .grid-stack-item[data-gs-min-width="2"] {
    min-width: 66.66667%; }
  .grid-stack.grid-stack-3 > .grid-stack-item[data-gs-max-width="2"] {
    max-width: 66.66667%; }
  .grid-stack.grid-stack-3 > .grid-stack-item[data-gs-width="3"] {
    width: 100%; }
  .grid-stack.grid-stack-3 > .grid-stack-item[data-gs-x="3"] {
    right: 100%; }
  .grid-stack.grid-stack-3 > .grid-stack-item[data-gs-min-width="3"] {
    min-width: 100%; }
  .grid-stack.grid-stack-3 > .grid-stack-item[data-gs-max-width="3"] {
    max-width: 100%; }

.grid-stack.grid-stack-4 > .grid-stack-item {
  min-width: 25%; }
  .grid-stack.grid-stack-4 > .grid-stack-item[data-gs-width="1"] {
    width: 25%; }
  .grid-stack.grid-stack-4 > .grid-stack-item[data-gs-x="1"] {
    right: 25%; }
  .grid-stack.grid-stack-4 > .grid-stack-item[data-gs-min-width="1"] {
    min-width: 25%; }
  .grid-stack.grid-stack-4 > .grid-stack-item[data-gs-max-width="1"] {
    max-width: 25%; }
  .grid-stack.grid-stack-4 > .grid-stack-item[data-gs-width="2"] {
    width: 50%; }
  .grid-stack.grid-stack-4 > .grid-stack-item[data-gs-x="2"] {
    right: 50%; }
  .grid-stack.grid-stack-4 > .grid-stack-item[data-gs-min-width="2"] {
    min-width: 50%; }
  .grid-stack.grid-stack-4 > .grid-stack-item[data-gs-max-width="2"] {
    max-width: 50%; }
  .grid-stack.grid-stack-4 > .grid-stack-item[data-gs-width="3"] {
    width: 75%; }
  .grid-stack.grid-stack-4 > .grid-stack-item[data-gs-x="3"] {
    right: 75%; }
  .grid-stack.grid-stack-4 > .grid-stack-item[data-gs-min-width="3"] {
    min-width: 75%; }
  .grid-stack.grid-stack-4 > .grid-stack-item[data-gs-max-width="3"] {
    max-width: 75%; }
  .grid-stack.grid-stack-4 > .grid-stack-item[data-gs-width="4"] {
    width: 100%; }
  .grid-stack.grid-stack-4 > .grid-stack-item[data-gs-x="4"] {
    right: 100%; }
  .grid-stack.grid-stack-4 > .grid-stack-item[data-gs-min-width="4"] {
    min-width: 100%; }
  .grid-stack.grid-stack-4 > .grid-stack-item[data-gs-max-width="4"] {
    max-width: 100%; }

.grid-stack.grid-stack-5 > .grid-stack-item {
  min-width: 20%; }
  .grid-stack.grid-stack-5 > .grid-stack-item[data-gs-width="1"] {
    width: 20%; }
  .grid-stack.grid-stack-5 > .grid-stack-item[data-gs-x="1"] {
    right: 20%; }
  .grid-stack.grid-stack-5 > .grid-stack-item[data-gs-min-width="1"] {
    min-width: 20%; }
  .grid-stack.grid-stack-5 > .grid-stack-item[data-gs-max-width="1"] {
    max-width: 20%; }
  .grid-stack.grid-stack-5 > .grid-stack-item[data-gs-width="2"] {
    width: 40%; }
  .grid-stack.grid-stack-5 > .grid-stack-item[data-gs-x="2"] {
    right: 40%; }
  .grid-stack.grid-stack-5 > .grid-stack-item[data-gs-min-width="2"] {
    min-width: 40%; }
  .grid-stack.grid-stack-5 > .grid-stack-item[data-gs-max-width="2"] {
    max-width: 40%; }
  .grid-stack.grid-stack-5 > .grid-stack-item[data-gs-width="3"] {
    width: 60%; }
  .grid-stack.grid-stack-5 > .grid-stack-item[data-gs-x="3"] {
    right: 60%; }
  .grid-stack.grid-stack-5 > .grid-stack-item[data-gs-min-width="3"] {
    min-width: 60%; }
  .grid-stack.grid-stack-5 > .grid-stack-item[data-gs-max-width="3"] {
    max-width: 60%; }
  .grid-stack.grid-stack-5 > .grid-stack-item[data-gs-width="4"] {
    width: 80%; }
  .grid-stack.grid-stack-5 > .grid-stack-item[data-gs-x="4"] {
    right: 80%; }
  .grid-stack.grid-stack-5 > .grid-stack-item[data-gs-min-width="4"] {
    min-width: 80%; }
  .grid-stack.grid-stack-5 > .grid-stack-item[data-gs-max-width="4"] {
    max-width: 80%; }
  .grid-stack.grid-stack-5 > .grid-stack-item[data-gs-width="5"] {
    width: 100%; }
  .grid-stack.grid-stack-5 > .grid-stack-item[data-gs-x="5"] {
    right: 100%; }
  .grid-stack.grid-stack-5 > .grid-stack-item[data-gs-min-width="5"] {
    min-width: 100%; }
  .grid-stack.grid-stack-5 > .grid-stack-item[data-gs-max-width="5"] {
    max-width: 100%; }

.grid-stack.grid-stack-6 > .grid-stack-item {
  min-width: 16.66667%; }
  .grid-stack.grid-stack-6 > .grid-stack-item[data-gs-width="1"] {
    width: 16.66667%; }
  .grid-stack.grid-stack-6 > .grid-stack-item[data-gs-x="1"] {
    right: 16.66667%; }
  .grid-stack.grid-stack-6 > .grid-stack-item[data-gs-min-width="1"] {
    min-width: 16.66667%; }
  .grid-stack.grid-stack-6 > .grid-stack-item[data-gs-max-width="1"] {
    max-width: 16.66667%; }
  .grid-stack.grid-stack-6 > .grid-stack-item[data-gs-width="2"] {
    width: 33.33333%; }
  .grid-stack.grid-stack-6 > .grid-stack-item[data-gs-x="2"] {
    right: 33.33333%; }
  .grid-stack.grid-stack-6 > .grid-stack-item[data-gs-min-width="2"] {
    min-width: 33.33333%; }
  .grid-stack.grid-stack-6 > .grid-stack-item[data-gs-max-width="2"] {
    max-width: 33.33333%; }
  .grid-stack.grid-stack-6 > .grid-stack-item[data-gs-width="3"] {
    width: 50%; }
  .grid-stack.grid-stack-6 > .grid-stack-item[data-gs-x="3"] {
    right: 50%; }
  .grid-stack.grid-stack-6 > .grid-stack-item[data-gs-min-width="3"] {
    min-width: 50%; }
  .grid-stack.grid-stack-6 > .grid-stack-item[data-gs-max-width="3"] {
    max-width: 50%; }
  .grid-stack.grid-stack-6 > .grid-stack-item[data-gs-width="4"] {
    width: 66.66667%; }
  .grid-stack.grid-stack-6 > .grid-stack-item[data-gs-x="4"] {
    right: 66.66667%; }
  .grid-stack.grid-stack-6 > .grid-stack-item[data-gs-min-width="4"] {
    min-width: 66.66667%; }
  .grid-stack.grid-stack-6 > .grid-stack-item[data-gs-max-width="4"] {
    max-width: 66.66667%; }
  .grid-stack.grid-stack-6 > .grid-stack-item[data-gs-width="5"] {
    width: 83.33333%; }
  .grid-stack.grid-stack-6 > .grid-stack-item[data-gs-x="5"] {
    right: 83.33333%; }
  .grid-stack.grid-stack-6 > .grid-stack-item[data-gs-min-width="5"] {
    min-width: 83.33333%; }
  .grid-stack.grid-stack-6 > .grid-stack-item[data-gs-max-width="5"] {
    max-width: 83.33333%; }
  .grid-stack.grid-stack-6 > .grid-stack-item[data-gs-width="6"] {
    width: 100%; }
  .grid-stack.grid-stack-6 > .grid-stack-item[data-gs-x="6"] {
    right: 100%; }
  .grid-stack.grid-stack-6 > .grid-stack-item[data-gs-min-width="6"] {
    min-width: 100%; }
  .grid-stack.grid-stack-6 > .grid-stack-item[data-gs-max-width="6"] {
    max-width: 100%; }

.grid-stack.grid-stack-7 > .grid-stack-item {
  min-width: 14.28571%; }
  .grid-stack.grid-stack-7 > .grid-stack-item[data-gs-width="1"] {
    width: 14.28571%; }
  .grid-stack.grid-stack-7 > .grid-stack-item[data-gs-x="1"] {
    right: 14.28571%; }
  .grid-stack.grid-stack-7 > .grid-stack-item[data-gs-min-width="1"] {
    min-width: 14.28571%; }
  .grid-stack.grid-stack-7 > .grid-stack-item[data-gs-max-width="1"] {
    max-width: 14.28571%; }
  .grid-stack.grid-stack-7 > .grid-stack-item[data-gs-width="2"] {
    width: 28.57143%; }
  .grid-stack.grid-stack-7 > .grid-stack-item[data-gs-x="2"] {
    right: 28.57143%; }
  .grid-stack.grid-stack-7 > .grid-stack-item[data-gs-min-width="2"] {
    min-width: 28.57143%; }
  .grid-stack.grid-stack-7 > .grid-stack-item[data-gs-max-width="2"] {
    max-width: 28.57143%; }
  .grid-stack.grid-stack-7 > .grid-stack-item[data-gs-width="3"] {
    width: 42.85714%; }
  .grid-stack.grid-stack-7 > .grid-stack-item[data-gs-x="3"] {
    right: 42.85714%; }
  .grid-stack.grid-stack-7 > .grid-stack-item[data-gs-min-width="3"] {
    min-width: 42.85714%; }
  .grid-stack.grid-stack-7 > .grid-stack-item[data-gs-max-width="3"] {
    max-width: 42.85714%; }
  .grid-stack.grid-stack-7 > .grid-stack-item[data-gs-width="4"] {
    width: 57.14286%; }
  .grid-stack.grid-stack-7 > .grid-stack-item[data-gs-x="4"] {
    right: 57.14286%; }
  .grid-stack.grid-stack-7 > .grid-stack-item[data-gs-min-width="4"] {
    min-width: 57.14286%; }
  .grid-stack.grid-stack-7 > .grid-stack-item[data-gs-max-width="4"] {
    max-width: 57.14286%; }
  .grid-stack.grid-stack-7 > .grid-stack-item[data-gs-width="5"] {
    width: 71.42857%; }
  .grid-stack.grid-stack-7 > .grid-stack-item[data-gs-x="5"] {
    right: 71.42857%; }
  .grid-stack.grid-stack-7 > .grid-stack-item[data-gs-min-width="5"] {
    min-width: 71.42857%; }
  .grid-stack.grid-stack-7 > .grid-stack-item[data-gs-max-width="5"] {
    max-width: 71.42857%; }
  .grid-stack.grid-stack-7 > .grid-stack-item[data-gs-width="6"] {
    width: 85.71429%; }
  .grid-stack.grid-stack-7 > .grid-stack-item[data-gs-x="6"] {
    right: 85.71429%; }
  .grid-stack.grid-stack-7 > .grid-stack-item[data-gs-min-width="6"] {
    min-width: 85.71429%; }
  .grid-stack.grid-stack-7 > .grid-stack-item[data-gs-max-width="6"] {
    max-width: 85.71429%; }
  .grid-stack.grid-stack-7 > .grid-stack-item[data-gs-width="7"] {
    width: 100%; }
  .grid-stack.grid-stack-7 > .grid-stack-item[data-gs-x="7"] {
    right: 100%; }
  .grid-stack.grid-stack-7 > .grid-stack-item[data-gs-min-width="7"] {
    min-width: 100%; }
  .grid-stack.grid-stack-7 > .grid-stack-item[data-gs-max-width="7"] {
    max-width: 100%; }

.grid-stack.grid-stack-8 > .grid-stack-item {
  min-width: 12.5%; }
  .grid-stack.grid-stack-8 > .grid-stack-item[data-gs-width="1"] {
    width: 12.5%; }
  .grid-stack.grid-stack-8 > .grid-stack-item[data-gs-x="1"] {
    right: 12.5%; }
  .grid-stack.grid-stack-8 > .grid-stack-item[data-gs-min-width="1"] {
    min-width: 12.5%; }
  .grid-stack.grid-stack-8 > .grid-stack-item[data-gs-max-width="1"] {
    max-width: 12.5%; }
  .grid-stack.grid-stack-8 > .grid-stack-item[data-gs-width="2"] {
    width: 25%; }
  .grid-stack.grid-stack-8 > .grid-stack-item[data-gs-x="2"] {
    right: 25%; }
  .grid-stack.grid-stack-8 > .grid-stack-item[data-gs-min-width="2"] {
    min-width: 25%; }
  .grid-stack.grid-stack-8 > .grid-stack-item[data-gs-max-width="2"] {
    max-width: 25%; }
  .grid-stack.grid-stack-8 > .grid-stack-item[data-gs-width="3"] {
    width: 37.5%; }
  .grid-stack.grid-stack-8 > .grid-stack-item[data-gs-x="3"] {
    right: 37.5%; }
  .grid-stack.grid-stack-8 > .grid-stack-item[data-gs-min-width="3"] {
    min-width: 37.5%; }
  .grid-stack.grid-stack-8 > .grid-stack-item[data-gs-max-width="3"] {
    max-width: 37.5%; }
  .grid-stack.grid-stack-8 > .grid-stack-item[data-gs-width="4"] {
    width: 50%; }
  .grid-stack.grid-stack-8 > .grid-stack-item[data-gs-x="4"] {
    right: 50%; }
  .grid-stack.grid-stack-8 > .grid-stack-item[data-gs-min-width="4"] {
    min-width: 50%; }
  .grid-stack.grid-stack-8 > .grid-stack-item[data-gs-max-width="4"] {
    max-width: 50%; }
  .grid-stack.grid-stack-8 > .grid-stack-item[data-gs-width="5"] {
    width: 62.5%; }
  .grid-stack.grid-stack-8 > .grid-stack-item[data-gs-x="5"] {
    right: 62.5%; }
  .grid-stack.grid-stack-8 > .grid-stack-item[data-gs-min-width="5"] {
    min-width: 62.5%; }
  .grid-stack.grid-stack-8 > .grid-stack-item[data-gs-max-width="5"] {
    max-width: 62.5%; }
  .grid-stack.grid-stack-8 > .grid-stack-item[data-gs-width="6"] {
    width: 75%; }
  .grid-stack.grid-stack-8 > .grid-stack-item[data-gs-x="6"] {
    right: 75%; }
  .grid-stack.grid-stack-8 > .grid-stack-item[data-gs-min-width="6"] {
    min-width: 75%; }
  .grid-stack.grid-stack-8 > .grid-stack-item[data-gs-max-width="6"] {
    max-width: 75%; }
  .grid-stack.grid-stack-8 > .grid-stack-item[data-gs-width="7"] {
    width: 87.5%; }
  .grid-stack.grid-stack-8 > .grid-stack-item[data-gs-x="7"] {
    right: 87.5%; }
  .grid-stack.grid-stack-8 > .grid-stack-item[data-gs-min-width="7"] {
    min-width: 87.5%; }
  .grid-stack.grid-stack-8 > .grid-stack-item[data-gs-max-width="7"] {
    max-width: 87.5%; }
  .grid-stack.grid-stack-8 > .grid-stack-item[data-gs-width="8"] {
    width: 100%; }
  .grid-stack.grid-stack-8 > .grid-stack-item[data-gs-x="8"] {
    right: 100%; }
  .grid-stack.grid-stack-8 > .grid-stack-item[data-gs-min-width="8"] {
    min-width: 100%; }
  .grid-stack.grid-stack-8 > .grid-stack-item[data-gs-max-width="8"] {
    max-width: 100%; }

.grid-stack.grid-stack-9 > .grid-stack-item {
  min-width: 11.11111%; }
  .grid-stack.grid-stack-9 > .grid-stack-item[data-gs-width="1"] {
    width: 11.11111%; }
  .grid-stack.grid-stack-9 > .grid-stack-item[data-gs-x="1"] {
    right: 11.11111%; }
  .grid-stack.grid-stack-9 > .grid-stack-item[data-gs-min-width="1"] {
    min-width: 11.11111%; }
  .grid-stack.grid-stack-9 > .grid-stack-item[data-gs-max-width="1"] {
    max-width: 11.11111%; }
  .grid-stack.grid-stack-9 > .grid-stack-item[data-gs-width="2"] {
    width: 22.22222%; }
  .grid-stack.grid-stack-9 > .grid-stack-item[data-gs-x="2"] {
    right: 22.22222%; }
  .grid-stack.grid-stack-9 > .grid-stack-item[data-gs-min-width="2"] {
    min-width: 22.22222%; }
  .grid-stack.grid-stack-9 > .grid-stack-item[data-gs-max-width="2"] {
    max-width: 22.22222%; }
  .grid-stack.grid-stack-9 > .grid-stack-item[data-gs-width="3"] {
    width: 33.33333%; }
  .grid-stack.grid-stack-9 > .grid-stack-item[data-gs-x="3"] {
    right: 33.33333%; }
  .grid-stack.grid-stack-9 > .grid-stack-item[data-gs-min-width="3"] {
    min-width: 33.33333%; }
  .grid-stack.grid-stack-9 > .grid-stack-item[data-gs-max-width="3"] {
    max-width: 33.33333%; }
  .grid-stack.grid-stack-9 > .grid-stack-item[data-gs-width="4"] {
    width: 44.44444%; }
  .grid-stack.grid-stack-9 > .grid-stack-item[data-gs-x="4"] {
    right: 44.44444%; }
  .grid-stack.grid-stack-9 > .grid-stack-item[data-gs-min-width="4"] {
    min-width: 44.44444%; }
  .grid-stack.grid-stack-9 > .grid-stack-item[data-gs-max-width="4"] {
    max-width: 44.44444%; }
  .grid-stack.grid-stack-9 > .grid-stack-item[data-gs-width="5"] {
    width: 55.55556%; }
  .grid-stack.grid-stack-9 > .grid-stack-item[data-gs-x="5"] {
    right: 55.55556%; }
  .grid-stack.grid-stack-9 > .grid-stack-item[data-gs-min-width="5"] {
    min-width: 55.55556%; }
  .grid-stack.grid-stack-9 > .grid-stack-item[data-gs-max-width="5"] {
    max-width: 55.55556%; }
  .grid-stack.grid-stack-9 > .grid-stack-item[data-gs-width="6"] {
    width: 66.66667%; }
  .grid-stack.grid-stack-9 > .grid-stack-item[data-gs-x="6"] {
    right: 66.66667%; }
  .grid-stack.grid-stack-9 > .grid-stack-item[data-gs-min-width="6"] {
    min-width: 66.66667%; }
  .grid-stack.grid-stack-9 > .grid-stack-item[data-gs-max-width="6"] {
    max-width: 66.66667%; }
  .grid-stack.grid-stack-9 > .grid-stack-item[data-gs-width="7"] {
    width: 77.77778%; }
  .grid-stack.grid-stack-9 > .grid-stack-item[data-gs-x="7"] {
    right: 77.77778%; }
  .grid-stack.grid-stack-9 > .grid-stack-item[data-gs-min-width="7"] {
    min-width: 77.77778%; }
  .grid-stack.grid-stack-9 > .grid-stack-item[data-gs-max-width="7"] {
    max-width: 77.77778%; }
  .grid-stack.grid-stack-9 > .grid-stack-item[data-gs-width="8"] {
    width: 88.88889%; }
  .grid-stack.grid-stack-9 > .grid-stack-item[data-gs-x="8"] {
    right: 88.88889%; }
  .grid-stack.grid-stack-9 > .grid-stack-item[data-gs-min-width="8"] {
    min-width: 88.88889%; }
  .grid-stack.grid-stack-9 > .grid-stack-item[data-gs-max-width="8"] {
    max-width: 88.88889%; }
  .grid-stack.grid-stack-9 > .grid-stack-item[data-gs-width="9"] {
    width: 100%; }
  .grid-stack.grid-stack-9 > .grid-stack-item[data-gs-x="9"] {
    right: 100%; }
  .grid-stack.grid-stack-9 > .grid-stack-item[data-gs-min-width="9"] {
    min-width: 100%; }
  .grid-stack.grid-stack-9 > .grid-stack-item[data-gs-max-width="9"] {
    max-width: 100%; }

.grid-stack.grid-stack-10 > .grid-stack-item {
  min-width: 10%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-width="1"] {
    width: 10%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-x="1"] {
    right: 10%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-min-width="1"] {
    min-width: 10%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-max-width="1"] {
    max-width: 10%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-width="2"] {
    width: 20%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-x="2"] {
    right: 20%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-min-width="2"] {
    min-width: 20%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-max-width="2"] {
    max-width: 20%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-width="3"] {
    width: 30%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-x="3"] {
    right: 30%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-min-width="3"] {
    min-width: 30%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-max-width="3"] {
    max-width: 30%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-width="4"] {
    width: 40%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-x="4"] {
    right: 40%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-min-width="4"] {
    min-width: 40%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-max-width="4"] {
    max-width: 40%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-width="5"] {
    width: 50%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-x="5"] {
    right: 50%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-min-width="5"] {
    min-width: 50%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-max-width="5"] {
    max-width: 50%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-width="6"] {
    width: 60%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-x="6"] {
    right: 60%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-min-width="6"] {
    min-width: 60%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-max-width="6"] {
    max-width: 60%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-width="7"] {
    width: 70%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-x="7"] {
    right: 70%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-min-width="7"] {
    min-width: 70%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-max-width="7"] {
    max-width: 70%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-width="8"] {
    width: 80%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-x="8"] {
    right: 80%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-min-width="8"] {
    min-width: 80%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-max-width="8"] {
    max-width: 80%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-width="9"] {
    width: 90%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-x="9"] {
    right: 90%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-min-width="9"] {
    min-width: 90%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-max-width="9"] {
    max-width: 90%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-width="10"] {
    width: 100%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-x="10"] {
    right: 100%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-min-width="10"] {
    min-width: 100%; }
  .grid-stack.grid-stack-10 > .grid-stack-item[data-gs-max-width="10"] {
    max-width: 100%; }

.grid-stack.grid-stack-11 > .grid-stack-item {
  min-width: 9.09091%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-width="1"] {
    width: 9.09091%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-x="1"] {
    right: 9.09091%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-min-width="1"] {
    min-width: 9.09091%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-max-width="1"] {
    max-width: 9.09091%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-width="2"] {
    width: 18.18182%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-x="2"] {
    right: 18.18182%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-min-width="2"] {
    min-width: 18.18182%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-max-width="2"] {
    max-width: 18.18182%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-width="3"] {
    width: 27.27273%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-x="3"] {
    right: 27.27273%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-min-width="3"] {
    min-width: 27.27273%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-max-width="3"] {
    max-width: 27.27273%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-width="4"] {
    width: 36.36364%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-x="4"] {
    right: 36.36364%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-min-width="4"] {
    min-width: 36.36364%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-max-width="4"] {
    max-width: 36.36364%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-width="5"] {
    width: 45.45455%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-x="5"] {
    right: 45.45455%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-min-width="5"] {
    min-width: 45.45455%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-max-width="5"] {
    max-width: 45.45455%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-width="6"] {
    width: 54.54545%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-x="6"] {
    right: 54.54545%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-min-width="6"] {
    min-width: 54.54545%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-max-width="6"] {
    max-width: 54.54545%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-width="7"] {
    width: 63.63636%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-x="7"] {
    right: 63.63636%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-min-width="7"] {
    min-width: 63.63636%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-max-width="7"] {
    max-width: 63.63636%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-width="8"] {
    width: 72.72727%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-x="8"] {
    right: 72.72727%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-min-width="8"] {
    min-width: 72.72727%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-max-width="8"] {
    max-width: 72.72727%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-width="9"] {
    width: 81.81818%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-x="9"] {
    right: 81.81818%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-min-width="9"] {
    min-width: 81.81818%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-max-width="9"] {
    max-width: 81.81818%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-width="10"] {
    width: 90.90909%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-x="10"] {
    right: 90.90909%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-min-width="10"] {
    min-width: 90.90909%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-max-width="10"] {
    max-width: 90.90909%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-width="11"] {
    width: 100%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-x="11"] {
    right: 100%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-min-width="11"] {
    min-width: 100%; }
  .grid-stack.grid-stack-11 > .grid-stack-item[data-gs-max-width="11"] {
    max-width: 100%; }

.grid-stack.grid-stack-12 > .grid-stack-item {
  min-width: 8.33333%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-width="1"] {
    width: 8.33333%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-x="1"] {
    right: 8.33333%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-min-width="1"] {
    min-width: 8.33333%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-max-width="1"] {
    max-width: 8.33333%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-width="2"] {
    width: 16.66667%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-x="2"] {
    right: 16.66667%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-min-width="2"] {
    min-width: 16.66667%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-max-width="2"] {
    max-width: 16.66667%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-width="3"] {
    width: 25%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-x="3"] {
    right: 25%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-min-width="3"] {
    min-width: 25%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-max-width="3"] {
    max-width: 25%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-width="4"] {
    width: 33.33333%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-x="4"] {
    right: 33.33333%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-min-width="4"] {
    min-width: 33.33333%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-max-width="4"] {
    max-width: 33.33333%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-width="5"] {
    width: 41.66667%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-x="5"] {
    right: 41.66667%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-min-width="5"] {
    min-width: 41.66667%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-max-width="5"] {
    max-width: 41.66667%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-width="6"] {
    width: 50%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-x="6"] {
    right: 50%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-min-width="6"] {
    min-width: 50%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-max-width="6"] {
    max-width: 50%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-width="7"] {
    width: 58.33333%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-x="7"] {
    right: 58.33333%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-min-width="7"] {
    min-width: 58.33333%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-max-width="7"] {
    max-width: 58.33333%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-width="8"] {
    width: 66.66667%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-x="8"] {
    right: 66.66667%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-min-width="8"] {
    min-width: 66.66667%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-max-width="8"] {
    max-width: 66.66667%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-width="9"] {
    width: 75%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-x="9"] {
    right: 75%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-min-width="9"] {
    min-width: 75%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-max-width="9"] {
    max-width: 75%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-width="10"] {
    width: 83.33333%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-x="10"] {
    right: 83.33333%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-min-width="10"] {
    min-width: 83.33333%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-max-width="10"] {
    max-width: 83.33333%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-width="11"] {
    width: 91.66667%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-x="11"] {
    right: 91.66667%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-min-width="11"] {
    min-width: 91.66667%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-max-width="11"] {
    max-width: 91.66667%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-width="12"] {
    width: 100%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-x="12"] {
    right: 100%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-min-width="12"] {
    min-width: 100%; }
  .grid-stack.grid-stack-12 > .grid-stack-item[data-gs-max-width="12"] {
    max-width: 100%; }

:root .grid-stack-item > .ui-resizable-handle {
  filter: none; }

.grid-stack {
  position: relative; }
  .grid-stack.grid-stack-rtl {
    direction: rtl; }
    .grid-stack.grid-stack-rtl > .grid-stack-item {
      direction: ltr; }
  .grid-stack .grid-stack-placeholder > .placeholder-content {
    border: 1px dashed lightgray;
    margin: 0;
    position: absolute;
    top: 0;
    right: 10px;
    left: 10px;
    bottom: 0;
    width: auto;
    z-index: 0 !important;
    text-align: center; }
  .grid-stack > .grid-stack-item {
    min-width: 8.33333%;
    position: absolute;
    padding: 0; }
    .grid-stack > .grid-stack-item > .grid-stack-item-content {
      margin: 0;
      position: absolute;
      top: 0;
      right: 10px;
      left: 10px;
      bottom: 0;
      width: auto;
      overflow-x: hidden;
      overflow-y: auto; }
    .grid-stack > .grid-stack-item > .ui-resizable-handle {
      position: absolute;
      font-size: 0.1px;
      display: block;
      -ms-touch-action: none;
      touch-action: none; }
    .grid-stack > .grid-stack-item.ui-resizable-disabled > .ui-resizable-handle,
    .grid-stack > .grid-stack-item.ui-resizable-autohide > .ui-resizable-handle {
      display: none; }
    .grid-stack > .grid-stack-item.ui-draggable-dragging, .grid-stack > .grid-stack-item.ui-resizable-resizing {
      z-index: 100; }
      .grid-stack > .grid-stack-item.ui-draggable-dragging > .grid-stack-item-content,
      .grid-stack > .grid-stack-item.ui-draggable-dragging > .grid-stack-item-content, .grid-stack > .grid-stack-item.ui-resizable-resizing > .grid-stack-item-content,
      .grid-stack > .grid-stack-item.ui-resizable-resizing > .grid-stack-item-content {
        box-shadow: -1px 4px 6px rgba(0, 0, 0, 0.2);
        opacity: 0.8; }
    .grid-stack > .grid-stack-item > .ui-resizable-se,
    .grid-stack > .grid-stack-item > .ui-resizable-sw {
      background-image: url(data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iaXNvLTg4NTktMSI/Pgo8IS0tIEdlbmVyYXRvcjogQWRvYmUgSWxsdXN0cmF0b3IgMTYuMC4wLCBTVkcgRXhwb3J0IFBsdWctSW4gLiBTVkcgVmVyc2lvbjogNi4wMCBCdWlsZCAwKSAgLS0+CjwhRE9DVFlQRSBzdmcgUFVCTElDICItLy9XM0MvL0RURCBTVkcgMS4xLy9FTiIgImh0dHA6Ly93d3cudzMub3JnL0dyYXBoaWNzL1NWRy8xLjEvRFREL3N2ZzExLmR0ZCI+CjxzdmcgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIiB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcvMTk5OS94bGluayIgdmVyc2lvbj0iMS4xIiBpZD0iQ2FwYV8xIiB4PSIwcHgiIHk9IjBweCIgd2lkdGg9IjE2cHgiIGhlaWdodD0iMTZweCIgdmlld0JveD0iMCAwIDUxMS42MjYgNTExLjYyNyIgc3R5bGU9ImVuYWJsZS1iYWNrZ3JvdW5kOm5ldyAwIDAgNTExLjYyNiA1MTEuNjI3OyIgeG1sOnNwYWNlPSJwcmVzZXJ2ZSI+CjxnPgoJPHBhdGggZD0iTTMyOC45MDYsNDAxLjk5NGgtMzYuNTUzVjEwOS42MzZoMzYuNTUzYzQuOTQ4LDAsOS4yMzYtMS44MDksMTIuODQ3LTUuNDI2YzMuNjEzLTMuNjE1LDUuNDIxLTcuODk4LDUuNDIxLTEyLjg0NSAgIGMwLTQuOTQ5LTEuODAxLTkuMjMxLTUuNDI4LTEyLjg1MWwtNzMuMDg3LTczLjA5QzI2NS4wNDQsMS44MDksMjYwLjc2LDAsMjU1LjgxMywwYy00Ljk0OCwwLTkuMjI5LDEuODA5LTEyLjg0Nyw1LjQyNCAgIGwtNzMuMDg4LDczLjA5Yy0zLjYxOCwzLjYxOS01LjQyNCw3LjkwMi01LjQyNCwxMi44NTFjMCw0Ljk0NiwxLjgwNyw5LjIyOSw1LjQyNCwxMi44NDVjMy42MTksMy42MTcsNy45MDEsNS40MjYsMTIuODUsNS40MjYgICBoMzYuNTQ1djI5Mi4zNThoLTM2LjU0MmMtNC45NTIsMC05LjIzNSwxLjgwOC0xMi44NSw1LjQyMWMtMy42MTcsMy42MjEtNS40MjQsNy45MDUtNS40MjQsMTIuODU0ICAgYzAsNC45NDUsMS44MDcsOS4yMjcsNS40MjQsMTIuODQ3bDczLjA4OSw3My4wODhjMy42MTcsMy42MTcsNy44OTgsNS40MjQsMTIuODQ3LDUuNDI0YzQuOTUsMCw5LjIzNC0xLjgwNywxMi44NDktNS40MjQgICBsNzMuMDg3LTczLjA4OGMzLjYxMy0zLjYyLDUuNDIxLTcuOTAxLDUuNDIxLTEyLjg0N2MwLTQuOTQ4LTEuODA4LTkuMjMyLTUuNDIxLTEyLjg1NCAgIEMzMzguMTQyLDQwMy44MDIsMzMzLjg1Nyw0MDEuOTk0LDMyOC45MDYsNDAxLjk5NHoiIGZpbGw9IiM2NjY2NjYiLz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8L3N2Zz4K);
      background-repeat: no-repeat;
      background-position: center;
      -webkit-transform: rotate(-45deg);
      -moz-transform: rotate(-45deg);
      -ms-transform: rotate(-45deg);
      -o-transform: rotate(-45deg);
      transform: rotate(-45deg); }
    .grid-stack > .grid-stack-item > .ui-resizable-se {
      -webkit-transform: rotate(45deg);
      -moz-transform: rotate(45deg);
      -ms-transform: rotate(45deg);
      -o-transform: rotate(45deg);
      transform: rotate(45deg); }
    .grid-stack > .grid-stack-item > .ui-resizable-nw {
      cursor: ne-resize;
      width: 20px;
      height: 20px;
      right: 10px;
      top: 0; }
    .grid-stack > .grid-stack-item > .ui-resizable-n {
      cursor: n-resize;
      height: 10px;
      top: 0;
      right: 25px;
      left: 25px; }
    .grid-stack > .grid-stack-item > .ui-resizable-ne {
      cursor: nw-resize;
      width: 20px;
      height: 20px;
      left: 10px;
      top: 0; }
    .grid-stack > .grid-stack-item > .ui-resizable-e {
      cursor: col-resize;
      width: 10px;
      left: 10px;
      top: 0px;
      bottom: 0px; }
    .grid-stack > .grid-stack-item > .ui-resizable-se {
      cursor: sw-resize;
      width: 20px;
      height: 20px;
      left: 10px;
      bottom: 0; }
    .grid-stack > .grid-stack-item > .ui-resizable-s {
      cursor: s-resize;
      height: 10px;
      right: 25px;
      bottom: 0;
      left: 25px; }
    .grid-stack > .grid-stack-item > .ui-resizable-sw {
      cursor: se-resize;
      width: 20px;
      height: 20px;
      right: 10px;
      bottom: 0; }
    .grid-stack > .grid-stack-item > .ui-resizable-w {
      cursor: col-resize;
      width: 10px;
      right: 10px;
      top: 0px;
      bottom: 0px; }
    .grid-stack > .grid-stack-item.ui-draggable-dragging > .ui-resizable-handle {
      display: none !important; }
    .grid-stack > .grid-stack-item[data-gs-width="1"] {
      width: 8.33333%; }
    .grid-stack > .grid-stack-item[data-gs-x="1"] {
      right: 8.33333%; }
    .grid-stack > .grid-stack-item[data-gs-min-width="1"] {
      min-width: 8.33333%; }
    .grid-stack > .grid-stack-item[data-gs-max-width="1"] {
      max-width: 8.33333%; }
    .grid-stack > .grid-stack-item[data-gs-width="2"] {
      width: 16.66667%; }
    .grid-stack > .grid-stack-item[data-gs-x="2"] {
      right: 16.66667%; }
    .grid-stack > .grid-stack-item[data-gs-min-width="2"] {
      min-width: 16.66667%; }
    .grid-stack > .grid-stack-item[data-gs-max-width="2"] {
      max-width: 16.66667%; }
    .grid-stack > .grid-stack-item[data-gs-width="3"] {
      width: 25%; }
    .grid-stack > .grid-stack-item[data-gs-x="3"] {
      right: 25%; }
    .grid-stack > .grid-stack-item[data-gs-min-width="3"] {
      min-width: 25%; }
    .grid-stack > .grid-stack-item[data-gs-max-width="3"] {
      max-width: 25%; }
    .grid-stack > .grid-stack-item[data-gs-width="4"] {
      width: 33.33333%; }
    .grid-stack > .grid-stack-item[data-gs-x="4"] {
      right: 33.33333%; }
    .grid-stack > .grid-stack-item[data-gs-min-width="4"] {
      min-width: 33.33333%; }
    .grid-stack > .grid-stack-item[data-gs-max-width="4"] {
      max-width: 33.33333%; }
    .grid-stack > .grid-stack-item[data-gs-width="5"] {
      width: 41.66667%; }
    .grid-stack > .grid-stack-item[data-gs-x="5"] {
      right: 41.66667%; }
    .grid-stack > .grid-stack-item[data-gs-min-width="5"] {
      min-width: 41.66667%; }
    .grid-stack > .grid-stack-item[data-gs-max-width="5"] {
      max-width: 41.66667%; }
    .grid-stack > .grid-stack-item[data-gs-width="6"] {
      width: 50%; }
    .grid-stack > .grid-stack-item[data-gs-x="6"] {
      right: 50%; }
    .grid-stack > .grid-stack-item[data-gs-min-width="6"] {
      min-width: 50%; }
    .grid-stack > .grid-stack-item[data-gs-max-width="6"] {
      max-width: 50%; }
    .grid-stack > .grid-stack-item[data-gs-width="7"] {
      width: 58.33333%; }
    .grid-stack > .grid-stack-item[data-gs-x="7"] {
      right: 58.33333%; }
    .grid-stack > .grid-stack-item[data-gs-min-width="7"] {
      min-width: 58.33333%; }
    .grid-stack > .grid-stack-item[data-gs-max-width="7"] {
      max-width: 58.33333%; }
    .grid-stack > .grid-stack-item[data-gs-width="8"] {
      width: 66.66667%; }
    .grid-stack > .grid-stack-item[data-gs-x="8"] {
      right: 66.66667%; }
    .grid-stack > .grid-stack-item[data-gs-min-width="8"] {
      min-width: 66.66667%; }
    .grid-stack > .grid-stack-item[data-gs-max-width="8"] {
      max-width: 66.66667%; }
    .grid-stack > .grid-stack-item[data-gs-width="9"] {
      width: 75%; }
    .grid-stack > .grid-stack-item[data-gs-x="9"] {
      right: 75%; }
    .grid-stack > .grid-stack-item[data-gs-min-width="9"] {
      min-width: 75%; }
    .grid-stack > .grid-stack-item[data-gs-max-width="9"] {
      max-width: 75%; }
    .grid-stack > .grid-stack-item[data-gs-width="10"] {
      width: 83.33333%; }
    .grid-stack > .grid-stack-item[data-gs-x="10"] {
      right: 83.33333%; }
    .grid-stack > .grid-stack-item[data-gs-min-width="10"] {
      min-width: 83.33333%; }
    .grid-stack > .grid-stack-item[data-gs-max-width="10"] {
      max-width: 83.33333%; }
    .grid-stack > .grid-stack-item[data-gs-width="11"] {
      width: 91.66667%; }
    .grid-stack > .grid-stack-item[data-gs-x="11"] {
      right: 91.66667%; }
    .grid-stack > .grid-stack-item[data-gs-min-width="11"] {
      min-width: 91.66667%; }
    .grid-stack > .grid-stack-item[data-gs-max-width="11"] {
      max-width: 91.66667%; }
    .grid-stack > .grid-stack-item[data-gs-width="12"] {
      width: 100%; }
    .grid-stack > .grid-stack-item[data-gs-x="12"] {
      right: 100%; }
    .grid-stack > .grid-stack-item[data-gs-min-width="12"] {
      min-width: 100%; }
    .grid-stack > .grid-stack-item[data-gs-max-width="12"] {
      max-width: 100%; }
  .grid-stack.grid-stack-animate,
  .grid-stack.grid-stack-animate .grid-stack-item {
    -webkit-transition: right 0.3s, top 0.3s, height 0.3s, width 0.3s;
    -moz-transition: right 0.3s, top 0.3s, height 0.3s, width 0.3s;
    -ms-transition: right 0.3s, top 0.3s, height 0.3s, width 0.3s;
    -o-transition: right 0.3s, top 0.3s, height 0.3s, width 0.3s;
    transition: right 0.3s, top 0.3s, height 0.3s, width 0.3s; }
  .grid-stack.grid-stack-animate .grid-stack-item.ui-draggable-dragging,
  .grid-stack.grid-stack-animate .grid-stack-item.ui-resizable-resizing,
  .grid-stack.grid-stack-animate .grid-stack-item.grid-stack-placeholder {
    -webkit-transition: right 0s, top 0s, height 0s, width 0s;
    -moz-transition: right 0s, top 0s, height 0s, width 0s;
    -ms-transition: right 0s, top 0s, height 0s, width 0s;
    -o-transition: right 0s, top 0s, height 0s, width 0s;
    transition: right 0s, top 0s, height 0s, width 0s; }
  .grid-stack.grid-stack-one-column-mode {
    height: auto !important; }
    .grid-stack.grid-stack-one-column-mode > .grid-stack-item {
      position: relative !important;
      width: auto !important;
      right: 0 !important;
      top: auto !important;
      margin-bottom: 20px;
      max-width: none !important; }
      .grid-stack.grid-stack-one-column-mode > .grid-stack-item > .ui-resizable-handle {
        display: none; }

/* Saved templates */
.save-template-form,
.flex-form {
  display: flex;
  margin-bottom: 15px; }
  .save-template-form .button,
  .flex-form .button {
    margin-right: 10px; }

.list-boxed.has-templates .no_template {
  display: none; }

.list-boxed li:before, .list-boxed li:after {
  content: "";
  display: block;
  clear: both; }

.list-boxed li:after {
  clear: both; }

.list-boxed li.li-boxed {
  background: #fff;
  padding: 12px 10px;
  position: relative;
  border: 1px solid #e5e5e5;
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.04); }

.list-boxed li a {
  cursor: pointer;
  float: left; }
  .list-boxed li a.load-tpl {
    margin-right: 10px; }

.list-boxed li.no_template {
  padding: 15px 0;
  font-style: italic; }

/**
 * Upsell panel
  */
.hfg-upsell-panel {
  margin-bottom: 0px;
  margin-top: 0px;
  float: right;
  display: block;
  padding-top: 8px;
  color: #888888; }

.hfg--widgets-info {
  width: 100%;
  margin-bottom: 0;
  color: #555555;
  display: flex;
  align-items: center;
  position: relative; }
  .hfg--widgets-info i {
    line-height: 20px;
    margin-right: 5px;
    font-size: 18px;
    cursor: pointer; }
    .hfg--widgets-info i:hover {
      opacity: .75; }
      .hfg--widgets-info i:hover + .tooltip {
        display: block; }
  .hfg--widgets-info .tooltip {
    background: rgba(0, 0, 0, 0.6);
    color: #fff;
    border-radius: 3px;
    font-weight: 300;
    font-size: 12px;
    padding: 5px;
    position: absolute;
    top: -30px;
    right: 20px;
    z-index: 200;
    display: none; }

:root .grid-stack-item > .ui-resizable-handle {
  filter: none; }

.grid-stack {
  position: relative; }
  .grid-stack.grid-stack-rtl {
    direction: rtl; }
    .grid-stack.grid-stack-rtl > .grid-stack-item {
      direction: ltr; }
  .grid-stack .grid-stack-placeholder > .placeholder-content {
    border: 1px dashed lightgray;
    margin: 0;
    position: absolute;
    top: 0;
    right: 10px;
    left: 10px;
    bottom: 0;
    width: auto;
    z-index: 0 !important;
    text-align: center; }
  .grid-stack > .grid-stack-item {
    min-width: 8.33333%;
    position: absolute;
    padding: 0; }
    .grid-stack > .grid-stack-item > .grid-stack-item-content {
      margin: 0;
      position: absolute;
      top: 0;
      right: 4px;
      left: 4px;
      bottom: 0;
      width: auto;
      z-index: 0 !important;
      overflow-x: hidden;
      overflow-y: auto; }
    .grid-stack > .grid-stack-item > .ui-resizable-handle {
      position: absolute;
      font-size: 0.1px;
      display: block;
      -ms-touch-action: none;
      touch-action: none; }
    .grid-stack > .grid-stack-item.ui-resizable-disabled > .ui-resizable-handle,
    .grid-stack > .grid-stack-item.ui-resizable-autohide > .ui-resizable-handle {
      display: none; }
    .grid-stack > .grid-stack-item.ui-draggable-dragging, .grid-stack > .grid-stack-item.ui-resizable-resizing {
      z-index: 100; }
      .grid-stack > .grid-stack-item.ui-draggable-dragging > .grid-stack-item-content,
      .grid-stack > .grid-stack-item.ui-draggable-dragging > .grid-stack-item-content, .grid-stack > .grid-stack-item.ui-resizable-resizing > .grid-stack-item-content,
      .grid-stack > .grid-stack-item.ui-resizable-resizing > .grid-stack-item-content {
        box-shadow: -1px 4px 6px rgba(0, 0, 0, 0.2);
        opacity: 0.8; }
    .grid-stack > .grid-stack-item > .ui-resizable-se,
    .grid-stack > .grid-stack-item > .ui-resizable-sw {
      background-image: url(data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iaXNvLTg4NTktMSI/Pgo8IS0tIEdlbmVyYXRvcjogQWRvYmUgSWxsdXN0cmF0b3IgMTYuMC4wLCBTVkcgRXhwb3J0IFBsdWctSW4gLiBTVkcgVmVyc2lvbjogNi4wMCBCdWlsZCAwKSAgLS0+CjwhRE9DVFlQRSBzdmcgUFVCTElDICItLy9XM0MvL0RURCBTVkcgMS4xLy9FTiIgImh0dHA6Ly93d3cudzMub3JnL0dyYXBoaWNzL1NWRy8xLjEvRFREL3N2ZzExLmR0ZCI+CjxzdmcgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIiB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcvMTk5OS94bGluayIgdmVyc2lvbj0iMS4xIiBpZD0iQ2FwYV8xIiB4PSIwcHgiIHk9IjBweCIgd2lkdGg9IjE2cHgiIGhlaWdodD0iMTZweCIgdmlld0JveD0iMCAwIDUxMS42MjYgNTExLjYyNyIgc3R5bGU9ImVuYWJsZS1iYWNrZ3JvdW5kOm5ldyAwIDAgNTExLjYyNiA1MTEuNjI3OyIgeG1sOnNwYWNlPSJwcmVzZXJ2ZSI+CjxnPgoJPHBhdGggZD0iTTMyOC45MDYsNDAxLjk5NGgtMzYuNTUzVjEwOS42MzZoMzYuNTUzYzQuOTQ4LDAsOS4yMzYtMS44MDksMTIuODQ3LTUuNDI2YzMuNjEzLTMuNjE1LDUuNDIxLTcuODk4LDUuNDIxLTEyLjg0NSAgIGMwLTQuOTQ5LTEuODAxLTkuMjMxLTUuNDI4LTEyLjg1MWwtNzMuMDg3LTczLjA5QzI2NS4wNDQsMS44MDksMjYwLjc2LDAsMjU1LjgxMywwYy00Ljk0OCwwLTkuMjI5LDEuODA5LTEyLjg0Nyw1LjQyNCAgIGwtNzMuMDg4LDczLjA5Yy0zLjYxOCwzLjYxOS01LjQyNCw3LjkwMi01LjQyNCwxMi44NTFjMCw0Ljk0NiwxLjgwNyw5LjIyOSw1LjQyNCwxMi44NDVjMy42MTksMy42MTcsNy45MDEsNS40MjYsMTIuODUsNS40MjYgICBoMzYuNTQ1djI5Mi4zNThoLTM2LjU0MmMtNC45NTIsMC05LjIzNSwxLjgwOC0xMi44NSw1LjQyMWMtMy42MTcsMy42MjEtNS40MjQsNy45MDUtNS40MjQsMTIuODU0ICAgYzAsNC45NDUsMS44MDcsOS4yMjcsNS40MjQsMTIuODQ3bDczLjA4OSw3My4wODhjMy42MTcsMy42MTcsNy44OTgsNS40MjQsMTIuODQ3LDUuNDI0YzQuOTUsMCw5LjIzNC0xLjgwNywxMi44NDktNS40MjQgICBsNzMuMDg3LTczLjA4OGMzLjYxMy0zLjYyLDUuNDIxLTcuOTAxLDUuNDIxLTEyLjg0N2MwLTQuOTQ4LTEuODA4LTkuMjMyLTUuNDIxLTEyLjg1NCAgIEMzMzguMTQyLDQwMy44MDIsMzMzLjg1Nyw0MDEuOTk0LDMyOC45MDYsNDAxLjk5NHoiIGZpbGw9IiM2NjY2NjYiLz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8L3N2Zz4K);
      background-repeat: no-repeat;
      background-position: center;
      -webkit-transform: rotate(-45deg);
      -moz-transform: rotate(-45deg);
      -ms-transform: rotate(-45deg);
      -o-transform: rotate(-45deg);
      transform: rotate(-45deg); }
    .grid-stack > .grid-stack-item > .ui-resizable-se {
      -webkit-transform: rotate(45deg);
      -moz-transform: rotate(45deg);
      -ms-transform: rotate(45deg);
      -o-transform: rotate(45deg);
      transform: rotate(45deg); }
    .grid-stack > .grid-stack-item > .ui-resizable-e {
      cursor: ew-resize;
      width: 5px;
      left: 5px;
      right: auto;
      top: 0px;
      bottom: 0px; }
    .grid-stack > .grid-stack-item > .ui-resizable-w {
      cursor: ew-resize;
      width: 5px;
      right: 5px;
      left: auto;
      top: 0px;
      bottom: 0px; }
    .grid-stack > .grid-stack-item.ui-draggable-dragging > .ui-resizable-handle {
      display: none !important; }
    .grid-stack > .grid-stack-item[data-gs-width='1'] {
      width: 8.33333%; }
    .grid-stack > .grid-stack-item[data-gs-x='1'] {
      right: 8.33333%; }
    .grid-stack > .grid-stack-item[data-gs-min-width='1'] {
      min-width: 8.33333%; }
    .grid-stack > .grid-stack-item[data-gs-max-width='1'] {
      max-width: 8.33333%; }
    html[dir="rtl"] .grid-stack > .grid-stack-item[data-gs-x='1'] {
      left: 8.33333%;
      right: auto; }
    .grid-stack > .grid-stack-item[data-gs-width='2'] {
      width: 16.66667%; }
    .grid-stack > .grid-stack-item[data-gs-x='2'] {
      right: 16.66667%; }
    .grid-stack > .grid-stack-item[data-gs-min-width='2'] {
      min-width: 16.66667%; }
    .grid-stack > .grid-stack-item[data-gs-max-width='2'] {
      max-width: 16.66667%; }
    html[dir="rtl"] .grid-stack > .grid-stack-item[data-gs-x='2'] {
      left: 16.66667%;
      right: auto; }
    .grid-stack > .grid-stack-item[data-gs-width='3'] {
      width: 25%; }
    .grid-stack > .grid-stack-item[data-gs-x='3'] {
      right: 25%; }
    .grid-stack > .grid-stack-item[data-gs-min-width='3'] {
      min-width: 25%; }
    .grid-stack > .grid-stack-item[data-gs-max-width='3'] {
      max-width: 25%; }
    html[dir="rtl"] .grid-stack > .grid-stack-item[data-gs-x='3'] {
      left: 25%;
      right: auto; }
    .grid-stack > .grid-stack-item[data-gs-width='4'] {
      width: 33.33333%; }
    .grid-stack > .grid-stack-item[data-gs-x='4'] {
      right: 33.33333%; }
    .grid-stack > .grid-stack-item[data-gs-min-width='4'] {
      min-width: 33.33333%; }
    .grid-stack > .grid-stack-item[data-gs-max-width='4'] {
      max-width: 33.33333%; }
    html[dir="rtl"] .grid-stack > .grid-stack-item[data-gs-x='4'] {
      left: 33.33333%;
      right: auto; }
    .grid-stack > .grid-stack-item[data-gs-width='5'] {
      width: 41.66667%; }
    .grid-stack > .grid-stack-item[data-gs-x='5'] {
      right: 41.66667%; }
    .grid-stack > .grid-stack-item[data-gs-min-width='5'] {
      min-width: 41.66667%; }
    .grid-stack > .grid-stack-item[data-gs-max-width='5'] {
      max-width: 41.66667%; }
    html[dir="rtl"] .grid-stack > .grid-stack-item[data-gs-x='5'] {
      left: 41.66667%;
      right: auto; }
    .grid-stack > .grid-stack-item[data-gs-width='6'] {
      width: 50%; }
    .grid-stack > .grid-stack-item[data-gs-x='6'] {
      right: 50%; }
    .grid-stack > .grid-stack-item[data-gs-min-width='6'] {
      min-width: 50%; }
    .grid-stack > .grid-stack-item[data-gs-max-width='6'] {
      max-width: 50%; }
    html[dir="rtl"] .grid-stack > .grid-stack-item[data-gs-x='6'] {
      left: 50%;
      right: auto; }
    .grid-stack > .grid-stack-item[data-gs-width='7'] {
      width: 58.33333%; }
    .grid-stack > .grid-stack-item[data-gs-x='7'] {
      right: 58.33333%; }
    .grid-stack > .grid-stack-item[data-gs-min-width='7'] {
      min-width: 58.33333%; }
    .grid-stack > .grid-stack-item[data-gs-max-width='7'] {
      max-width: 58.33333%; }
    html[dir="rtl"] .grid-stack > .grid-stack-item[data-gs-x='7'] {
      left: 58.33333%;
      right: auto; }
    .grid-stack > .grid-stack-item[data-gs-width='8'] {
      width: 66.66667%; }
    .grid-stack > .grid-stack-item[data-gs-x='8'] {
      right: 66.66667%; }
    .grid-stack > .grid-stack-item[data-gs-min-width='8'] {
      min-width: 66.66667%; }
    .grid-stack > .grid-stack-item[data-gs-max-width='8'] {
      max-width: 66.66667%; }
    html[dir="rtl"] .grid-stack > .grid-stack-item[data-gs-x='8'] {
      left: 66.66667%;
      right: auto; }
    .grid-stack > .grid-stack-item[data-gs-width='9'] {
      width: 75%; }
    .grid-stack > .grid-stack-item[data-gs-x='9'] {
      right: 75%; }
    .grid-stack > .grid-stack-item[data-gs-min-width='9'] {
      min-width: 75%; }
    .grid-stack > .grid-stack-item[data-gs-max-width='9'] {
      max-width: 75%; }
    html[dir="rtl"] .grid-stack > .grid-stack-item[data-gs-x='9'] {
      left: 75%;
      right: auto; }
    .grid-stack > .grid-stack-item[data-gs-width='10'] {
      width: 83.33333%; }
    .grid-stack > .grid-stack-item[data-gs-x='10'] {
      right: 83.33333%; }
    .grid-stack > .grid-stack-item[data-gs-min-width='10'] {
      min-width: 83.33333%; }
    .grid-stack > .grid-stack-item[data-gs-max-width='10'] {
      max-width: 83.33333%; }
    html[dir="rtl"] .grid-stack > .grid-stack-item[data-gs-x='10'] {
      left: 83.33333%;
      right: auto; }
    .grid-stack > .grid-stack-item[data-gs-width='11'] {
      width: 91.66667%; }
    .grid-stack > .grid-stack-item[data-gs-x='11'] {
      right: 91.66667%; }
    .grid-stack > .grid-stack-item[data-gs-min-width='11'] {
      min-width: 91.66667%; }
    .grid-stack > .grid-stack-item[data-gs-max-width='11'] {
      max-width: 91.66667%; }
    html[dir="rtl"] .grid-stack > .grid-stack-item[data-gs-x='11'] {
      left: 91.66667%;
      right: auto; }
    .grid-stack > .grid-stack-item[data-gs-width='12'] {
      width: 100%; }
    .grid-stack > .grid-stack-item[data-gs-x='12'] {
      right: 100%; }
    .grid-stack > .grid-stack-item[data-gs-min-width='12'] {
      min-width: 100%; }
    .grid-stack > .grid-stack-item[data-gs-max-width='12'] {
      max-width: 100%; }
    html[dir="rtl"] .grid-stack > .grid-stack-item[data-gs-x='12'] {
      left: 100%;
      right: auto; }
  .grid-stack.grid-stack-animate,
  .grid-stack.grid-stack-animate .grid-stack-item {
    -webkit-transition: right 0.3s, top 0.3s, height 0.3s, width 0.3s;
    -moz-transition: right 0.3s, top 0.3s, height 0.3s, width 0.3s;
    -ms-transition: right 0.3s, top 0.3s, height 0.3s, width 0.3s;
    -o-transition: right 0.3s, top 0.3s, height 0.3s, width 0.3s;
    transition: right 0.3s, top 0.3s, height 0.3s, width 0.3s; }
  .grid-stack.grid-stack-animate .grid-stack-item.ui-draggable-dragging,
  .grid-stack.grid-stack-animate .grid-stack-item.ui-resizable-resizing,
  .grid-stack.grid-stack-animate .grid-stack-item.grid-stack-placeholder {
    -webkit-transition: right 0s, top 0s, height 0s, width 0s;
    -moz-transition: right 0s, top 0s, height 0s, width 0s;
    -ms-transition: right 0s, top 0s, height 0s, width 0s;
    -o-transition: right 0s, top 0s, height 0s, width 0s;
    transition: right 0s, top 0s, height 0s, width 0s; }
  .grid-stack.grid-stack-one-column-mode {
    height: auto !important; }
    .grid-stack.grid-stack-one-column-mode > .grid-stack-item {
      position: relative !important;
      width: auto !important;
      right: 0 !important;
      top: auto !important;
      margin-bottom: 20px;
      max-width: none !important; }
      .grid-stack.grid-stack-one-column-mode > .grid-stack-item > .ui-resizable-handle {
        display: none; }

ul[id^="sub-accordion-panel-hfg"] > li.hfg-section-active {
  order: 0; }

ul[id^="sub-accordion-panel-hfg"] > li.hfg-section-inactive {
  order: 1;
  opacity: 0.5; }

#customize-theme-controls ul.customize-pane-child.accordion-sub-container[id^="sub-accordion-panel-hfg"] {
  flex-direction: column;
  display: flex; }
