<?php 
$strings['what-religion-do-you-have-name']=__(' What religion do you have?', 'lovestory');
$strings['what-language-do-you-speak-name']=__(' What language do you speak?', 'lovestory');
$strings['what-are-your-eating-habits-name']=__('What are your eating habits?', 'lovestory');
$strings['what-is-your-ethnic-background-name']=__(' What is your ethnic background?', 'lovestory');
$strings['what-is-your-zodiac-sign-name']=__(' What is your zodiac sign?', 'lovestory');
$strings['how-tall-are-you-name']=__(' How tall are you?', 'lovestory');
$strings['how-heavy-do-you-weigh-name']=__('How heavy do you weigh?', 'lovestory');
$strings['what-color-eyes-do-you-have-name']=__(' What color eyes do you have?', 'lovestory');
$strings['whats-your-skin-colour-name']=__(' What’s your skin colour?', 'lovestory');
$strings['what-hair-color-do-you-have-name']=__(' What hair color do you have?', 'lovestory');
$strings['do-you-have-piercings-name']=__(' Do you have piercings', 'lovestory');
$strings['do-you-have-piercings-options']=__('Yes,No', 'lovestory');
$strings['do-you-have-tattoos-name']=__(' Do you have tattoos?', 'lovestory');
$strings['do-you-have-tattoos-options']=__('Yes,No', 'lovestory');
$strings['what-is-your-marital-status-name']=__(' What is your marital status?', 'lovestory');
$strings['what-is-your-marital-status-options']=__('Married, Widowed, Divorced, Single', 'lovestory');
$strings['do-you-have-children-name']=__(' Do you have children?', 'lovestory');
$strings['do-you-have-children-options']=__('Yes,No', 'lovestory');
$strings['do-you-have-childrens-wish-name']=__('Do you have Children’s wish?', 'lovestory');
$strings['do-you-have-childrens-wish-options']=__('Yes,No', 'lovestory');
$strings['what-is-your-education-name']=__(' What is your education?', 'lovestory');
$strings['what-is-your-monthly-income-in-usd-name']=__(' What is your monthly income in USD', 'lovestory');
$strings['what-is-your-monthly-income-in-usd-options']=__(' I prefer not to say that, Less than 5000, More than 5000', 'lovestory');
$strings['what-kind-of-work-do-you-do-name']=__('What kind of work do you do?', 'lovestory');
$strings['do-you-have-a-drivers-license-name']=__(' Do you have a driver’s license?', 'lovestory');
$strings['do-you-have-a-drivers-license-options']=__('Yes,No', 'lovestory');
$strings['do-you-have-your-own-car-name']=__(' Do you have your own car?', 'lovestory');
$strings['do-you-have-your-own-car-options']=__('Yes,No', 'lovestory');
$strings['do-you-smoke-name']=__('Do you smoke?', 'lovestory');
$strings['do-you-smoke-options']=__(' Yes, No, Sometimes, I can’t take it', 'lovestory');
$strings['do-you-use-alcohol-name']=__(' Do you use alcohol?', 'lovestory');
$strings['do-you-use-alcohol-options']=__('Yes, No, Sometimes, During the week and weekend', 'lovestory');
$strings['are-you-going-out-name']=__(' Are you going out?', 'lovestory');
$strings['are-you-going-out-options']=__(' Never, Sometimes, Regularly, Every weekend', 'lovestory');
$strings['what-kind-of-relationship-are-you-looking-for-name']=__('What kind of relationship are you looking for?', 'lovestory');
$strings['what-kind-of-relationship-are-you-looking-for-options']=__(' Relationship with marriage potential, Relationship and then we’ll see, friendship and then we’ll see, friendship only, Date for a fee, One night sex for a fee, Paid sex forever', 'lovestory');
$strings['what-ethnic-background-should-your-partner-have-name']=__(' What ethnic background should your partner have?', 'lovestory');
$strings['which-religion-should-your-partner-have-name']=__('Which religion should your partner have?', 'lovestory');
$strings['how-old-should-your-partner-be-name']=__(' How old should your partner be?', 'lovestory');
$strings['how-long-should-your-partner-be-name']=__('How long should your partner be?', 'lovestory');
$strings['which-physique-should-you-partner-have-name']=__('Which physique should you partner have?', 'lovestory');
$strings['which-physique-should-you-partner-have-options']=__(' Normal, Athletic, Large, Chubby, Heavy, It doesn’t matter', 'lovestory');
$strings['do-you-object-if-your-partner-has-children-name']=__(' Do you object if your partner has children?', 'lovestory');
$strings['do-you-object-if-your-partner-has-children-options']=__(' Yes, No, I’ll tell you later', 'lovestory');
$strings['where-are-you-looking-for-your-partner-name']=__('Where are you looking for your partner?', 'lovestory');
$strings['where-are-you-looking-for-your-partner-options']=__(' Only in my country, Only abroad, In my country and abroad', 'lovestory');