<div class="scp-root">
<h2>Sincotechs Live Room</h2>
<button class="scp-btn" onclick="startCam(1)">Start My Camera</button>
<div class="scp-grid">
  <div id="slot-1" class="scp-slot"><div class="scp-slot-label">Slot 1</div></div>
  <div id="slot-2" class="scp-slot"><div class="scp-slot-label">Slot 2</div></div>
  <div id="slot-3" class="scp-slot"><div class="scp-slot-label">Slot 3</div></div>
  <div id="slot-4" class="scp-slot"><div class="scp-slot-label">Slot 4</div></div>
</div>
<div class="scp-panel">
  <h3>Active Session</h3>
  <p id="scp-session-info"></p>
  <button class="scp-btn" onclick="endSession()">End Session</button>
</div>
<div class="scp-panel">
  <h3>Models / Users</h3>
  <div id="scp-users"></div>
</div>
<div class="scp-panel">
  <h3>Rooms</h3>
  <div id="scp-rooms"></div>
</div>
<p style="text-align:center;font-size:11px;color:#777;margin-top:10px;">© Sincotechs – All rights reserved.</p>
</div>