.scp-root{background:#111;color:#fff;padding:10px;font-family:system-ui;}
.scp-grid{display:flex;flex-wrap:wrap;height:320px;margin-bottom:10px;}
.scp-slot{flex:1 1 50%;border:1px solid #333;background:#000;min-height:150px;position:relative;}
.scp-slot-label{position:absolute;top:5px;left:5px;background:#000a;padding:3px 6px;font-size:11px;}
.scp-panel{background:#1b1b1b;padding:10px;margin-top:10px;}
.scp-btn{background:#222;border:1px solid #444;color:#ddd;padding:6px 10px;font-size:12px;border-radius:3px;cursor:pointer;}
.scp-btn:hover{border-color:#f2c94c;color:#f2c94c;}
.scp-row{margin-bottom:6px;font-size:13px;}
